.tox {
  box-shadow: none;
  box-sizing: content-box;
  cursor: auto;
  font-style: normal;
  font-weight: normal;
  line-height: normal;
  -webkit-tap-highlight-color: transparent;
  -webkit-text-decoration: none;
  text-decoration: none;
  text-shadow: none;
  text-transform: none;
  vertical-align: initial;
  white-space: normal;
}
.tox *:not(svg):not(rect) {
  box-sizing: inherit;
  color: inherit;
  cursor: inherit;
  direction: inherit;
  font-family: inherit;
  font-size: inherit;
  font-style: inherit;
  font-weight: inherit;
  line-height: inherit;
  -webkit-tap-highlight-color: inherit;
  text-align: inherit;
  text-decoration: inherit;
  text-shadow: inherit;
  text-transform: inherit;
  vertical-align: inherit;
  white-space: inherit;
}
.tox *:not(svg):not(rect) {
  /* stylelint-disable-line no-duplicate-selectors */
  background: transparent;
  border: 0;
  box-shadow: none;
  float: none;
  height: auto;
  margin: 0;
  max-width: none;
  outline: 0;
  padding: 0;
  position: static;
  width: auto;
}
.tox:not([dir=rtl]) {
  direction: ltr;
  text-align: left;
}
.tox[dir=rtl] {
  direction: rtl;
  text-align: right;
}
.tox-tinymce *:focus,
.tox-tinymce-aux *:focus {
  outline: none;
}
button::-moz-focus-inner {
  border: 0;
}
@keyframes tox-rotation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(360deg);
  }
}
@keyframes tox-bouncing-dots {
  0%,
  80%,
  100% {
    transform: scale(0);
  }
  40% {
    transform: scale(1);
  }
}
.tox {
  color: var(--tox-private-color-black, #2A3746);
  font-family: var(--tox-private-font-stack, -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Oxygen-Sans, Ubuntu, Cantarell, "Helvetica Neue", sans-serif);
  font-size: var(--tox-private-font-size-base, 16px);
}
.tox-tinymce {
  border: 1px solid #000000;
  border-radius: 0;
  box-shadow: none;
  box-sizing: border-box;
  display: flex;
  flex-direction: column;
  font-family: var(--tox-private-font-stack, -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Oxygen-Sans, Ubuntu, Cantarell, "Helvetica Neue", sans-serif);
  overflow: hidden;
  position: relative;
  visibility: inherit !important;
}
.tox.tox-tinymce-inline {
  border: none;
  box-shadow: none;
  overflow: initial;
}
.tox.tox-tinymce-inline .tox-editor-container {
  overflow: initial;
}
.tox.tox-tinymce-inline .tox-editor-header {
  background-color: #222f3e;
  border: 1px solid #000000;
  border-radius: 0;
  box-shadow: none;
  overflow: hidden;
}
.tox-tinymce-aux {
  font-family: var(--tox-private-font-stack, -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Oxygen-Sans, Ubuntu, Cantarell, "Helvetica Neue", sans-serif);
  z-index: var(--tox-private-z-index-sink, 1300);
}
.tox[dir=rtl] .tox-icon--flip svg {
  transform: rotateY(180deg);
}
.tox .tox-editor-container {
  display: flex;
  flex: 1 1 auto;
  flex-direction: column;
  overflow: hidden;
}
.tox .tox-editor-header {
  display: grid;
  grid-template-columns: 1fr min-content;
  z-index: 2;
}
.tox:not(.tox-tinymce-inline) .tox-editor-header {
  background-color: #222f3e;
  border-bottom: none;
  box-shadow: none;
  padding: 4px 0;
}
.tox:not(.tox-tinymce-inline) .tox-editor-header:not(.tox-editor-dock-transition) {
  transition: box-shadow 0.5s;
}
.tox:not(.tox-tinymce-inline).tox-tinymce--toolbar-bottom .tox-editor-header {
  border-top: 1px solid #000000;
  box-shadow: none;
}
.tox:not(.tox-tinymce-inline).tox-tinymce--toolbar-sticky-on .tox-editor-header {
  background-color: #222f3e;
  box-shadow: 0 4px 4px -3px rgba(0, 0, 0, 0.25);
  padding: 4px 0;
}
.tox:not(.tox-tinymce-inline).tox-tinymce--toolbar-sticky-on.tox-tinymce--toolbar-bottom .tox-editor-header {
  box-shadow: 0 4px 4px -3px rgba(0, 0, 0, 0.25);
}
.tox.tox:not(.tox-tinymce-inline) .tox-editor-header.tox-editor-header--empty {
  background: none;
  border: none;
  box-shadow: none;
  padding: 0;
}
.tox-editor-dock-fadeout {
  opacity: 0;
  visibility: hidden;
}
.tox-editor-dock-fadein {
  opacity: 1;
  visibility: visible;
}
.tox-editor-dock-transition {
  transition: visibility 0s linear 0.25s, opacity 0.25s ease;
}
.tox-editor-dock-transition.tox-editor-dock-fadein {
  transition-delay: 0s;
}
.tox .accessibility-issue__header {
  align-items: center;
  display: flex;
  margin-bottom: 4px;
}
.tox #accessibility-issue__subheader {
  font-size: 16px;
  color: #fff;
}
.tox .accessbility-sr-only {
  position: absolute;
  clip: rect(1px, 1px, 1px, 1px);
  clip-path: inset(0 0 99.9% 99.9%);
  overflow: hidden;
  height: 1px;
  width: 1px;
  padding: 0;
  border: 0;
}
.tox .accessibility-issue__description {
  align-items: stretch;
  border-radius: 3px;
  justify-content: space-between;
}
.tox .accessibility-issue__description > div {
  padding-bottom: 4px;
}
.tox .accessibility-issue__description > div > div {
  align-items: center;
  display: flex;
  margin-bottom: 4px;
}
.tox .accessibility-issue__description > div > div .tox-icon svg {
  display: block;
}
.tox #accessibility-issue__contentID {
  margin-top: 8px;
  margin-bottom: 8px;
}
.tox #accessibility-issue__contentID span:first-child {
  font-weight: bold;
}
.tox #accessibility-issue__document {
  padding-bottom: 8px;
}
.tox .accessibility-issue__repair {
  margin-top: 8px;
}
.tox .accessibility-issue__repair .tox-form__group .tox-form__group--error {
  color: #eb9999;
}
.tox .tox-dialog__body-content .accessibility-issue--info .accessibility-issue__description {
  background-color: #22374a;
  color: #fff;
}
.tox .tox-dialog__body-content .accessibility-issue--info .tox-form__group h2 {
  font-size: 14px;
  color: #a6cae2;
}
.tox .tox-dialog__body-content .accessibility-issue--info .tox-icon.accessibility-issue__icon svg {
  fill: #a6cae2;
}
.tox .tox-dialog__body-content .accessibility-issue--info a.tox-button--naked.tox-button--icon {
  background-color: #207ab7;
  color: #fff;
}
.tox .tox-dialog__body-content .accessibility-issue--info a.tox-button--naked.tox-button--icon:hover,
.tox .tox-dialog__body-content .accessibility-issue--info a.tox-button--naked.tox-button--icon:focus {
  background-color: #1c6ca1;
}
.tox .tox-dialog__body-content .accessibility-issue--info a.tox-button--naked.tox-button--icon:active {
  background-color: #185d8c;
}
.tox .tox-dialog__body-content .accessibility-issue--warn .accessibility-issue__description {
  background-color: #383f38;
  color: #fff;
}
.tox .tox-dialog__body-content .accessibility-issue--warn .tox-form__group h2 {
  font-size: 14px;
  color: #ffeb99;
}
.tox .tox-dialog__body-content .accessibility-issue--warn .tox-icon.accessibility-issue__icon svg {
  fill: #ffeb99;
}
.tox .tox-dialog__body-content .accessibility-issue--warn a.tox-button--naked.tox-button--icon {
  background-color: #FFE89D;
  color: #2A3746;
}
.tox .tox-dialog__body-content .accessibility-issue--warn a.tox-button--naked.tox-button--icon:hover,
.tox .tox-dialog__body-content .accessibility-issue--warn a.tox-button--naked.tox-button--icon:focus {
  background-color: #F2D574;
  color: #2A3746;
}
.tox .tox-dialog__body-content .accessibility-issue--warn a.tox-button--naked.tox-button--icon:active {
  background-color: #E8C657;
  color: #2A3746;
}
.tox .tox-dialog__body-content .accessibility-issue--error .accessibility-issue__description {
  background-color: #332a38;
  color: #fff;
}
.tox .tox-dialog__body-content .accessibility-issue--error .tox-form__group h2 {
  font-size: 14px;
  color: #eb9999;
}
.tox .tox-dialog__body-content .accessibility-issue--error .tox-icon.accessibility-issue__icon svg {
  fill: #eb9999;
}
.tox .tox-dialog__body-content .accessibility-issue--error a.tox-button--naked.tox-button--icon {
  background-color: #F2BFBF;
  color: #2A3746;
}
.tox .tox-dialog__body-content .accessibility-issue--error a.tox-button--naked.tox-button--icon:hover,
.tox .tox-dialog__body-content .accessibility-issue--error a.tox-button--naked.tox-button--icon:focus {
  background-color: #E9A4A4;
  color: #2A3746;
}
.tox .tox-dialog__body-content .accessibility-issue--error a.tox-button--naked.tox-button--icon:active {
  background-color: #EE9494;
  color: #2A3746;
}
.tox .tox-dialog__body-content .accessibility-issue--success .accessibility-issue__description {
  background-color: rgba(120, 171, 70, 0.5);
  color: #fff;
}
.tox .tox-dialog__body-content .accessibility-issue--success .accessibility-issue__description > *:last-child {
  display: none;
}
.tox .tox-dialog__body-content .accessibility-issue--success .tox-form__group h2 {
  color: #fff;
}
.tox .tox-dialog__body-content .accessibility-issue--success .tox-icon.accessibility-issue__icon svg {
  fill: #fff;
}
.tox .tox-dialog__body-content .accessibility-issue__header .tox-form__group h1,
.tox .tox-dialog__body-content .tox-form__group .accessibility-issue__description h2 {
  margin-top: 0;
}
.tox:not([dir=rtl]) .tox-dialog__body-content .accessibility-issue__header .tox-button {
  margin-left: 4px;
}
.tox:not([dir=rtl]) .tox-dialog__body-content .accessibility-issue__header > *:nth-last-child(2) {
  margin-left: auto;
}
.tox:not([dir=rtl]) .tox-dialog__body-content .accessibility-issue__description {
  padding: 8px;
}
.tox[dir=rtl] .tox-dialog__body-content .accessibility-issue__header .tox-button {
  margin-right: 4px;
}
.tox[dir=rtl] .tox-dialog__body-content .accessibility-issue__header > *:nth-last-child(2) {
  margin-right: auto;
}
.tox[dir=rtl] .tox-dialog__body-content .accessibility-issue__description {
  padding: 4px 8px 4px 4px;
}
.tox .mce-codemirror {
  background: #fff;
  bottom: 0;
  font-size: 13px;
  left: 0;
  position: absolute;
  right: 0;
  top: 0;
  z-index: 1;
}
.tox .mce-codemirror.tox-inline-codemirror {
  margin: 8px;
  position: absolute;
}
.tox .tox-advtemplate .tox-form__grid {
  flex: 1;
}
.tox .tox-advtemplate .tox-form__grid > div:first-child {
  display: flex;
  flex-direction: column;
  width: 30%;
}
.tox .tox-advtemplate .tox-form__grid > div:first-child > div:nth-child(2) {
  flex-basis: 0;
  flex-grow: 1;
  overflow: auto;
}
@media only screen and (max-width: 767px ) {
  body:not(.tox-force-desktop) .tox .tox-advtemplate .tox-form__grid > div:first-child {
    width: 100%;
  }
}
.tox .tox-advtemplate iframe {
  border-color: #000000;
  border-radius: 0;
  border-style: solid;
  border-width: 1px;
  margin: 0 10px;
}
.tox .tox-accordion {
  display: flex;
  flex-direction: column;
  gap: var(--tox-private-pad-sm, 8px);
}
.tox .tox-accordion__item {
  background-color: var(--tox-private-background-color, #222f3e);
  color: var(--tox-private-text-color, #fff);
  border-radius: var(--tox-private-control-border-radius, 3px);
  position: relative;
}
.tox .tox-accordion__item.tox-accordion__item--expanded {
  background-color: var(--tox-private-background-secondary, #2f4055);
}
.tox .tox-accordion__item.tox-accordion__item--expanded .tox-accordion__content--expanded .tox-accordion__content-inner {
  padding-top: 0;
}
.tox .tox-accordion__item::after {
  border-radius: var(--tox-private-control-border-radius, 3px);
  box-shadow: 0 0 0 var(--tox-private-keyboard-focus-outline-width, 0) var(--tox-private-keyboard-focus-outline-color, transparent);
  content: '';
  inset: 0;
  opacity: 0;
  pointer-events: none;
  position: absolute;
}
@media (forced-colors: active) {
  .tox .tox-accordion__item::after {
    border: 2px solid highlight;
  }
}
.tox .tox-accordion__item:focus {
  outline: none;
  z-index: 1;
}
.tox .tox-accordion__item:focus::after {
  opacity: 1;
}
.tox .tox-accordion__heading {
  margin: 0;
  width: 100%;
}
.tox .tox-accordion__heading:focus {
  outline: none;
}
.tox .tox-accordion__header {
  align-items: center;
  border: none;
  border-radius: var(--tox-private-control-border-radius, 3px);
  box-sizing: border-box;
  color: var(--tox-private-text-color, #fff);
  cursor: pointer;
  display: flex;
  font-family: var(--tox-private-font-stack, -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Oxygen-Sans, Ubuntu, Cantarell, "Helvetica Neue", sans-serif);
  font-size: var(--tox-private-font-size-md, 16px);
  font-weight: var(--tox-private-font-weight-bold, bold);
  line-height: var(--tox-private-line-height-base, 1.3);
  outline: none;
  padding: calc(var(--tox-private-pad-sm, 8px) + var(--tox-private-pad-xs, 4px));
  text-align: left;
  width: 100%;
}
.tox .tox-accordion__header::after {
  border-radius: var(--tox-private-control-border-radius, 3px);
  bottom: 0;
  box-shadow: 0 0 0 var(--tox-private-keyboard-focus-outline-width, 0) var(--tox-private-keyboard-focus-outline-color, transparent);
  content: '';
  left: 0;
  opacity: 0;
  pointer-events: none;
  position: absolute;
  right: 0;
  top: 0;
}
@media (forced-colors: active) {
  .tox .tox-accordion__header::after {
    border: 2px solid highlight;
  }
}
.tox .tox-accordion__header:hover:not(.tox-accordion__header--disabled) {
  background-color: var(--tox-private-background-secondary, #2f4055);
}
.tox .tox-accordion__header:focus:not(.tox-accordion__header--disabled) {
  position: relative;
  z-index: 1;
}
.tox .tox-accordion__header:focus:not(.tox-accordion__header--disabled)::after {
  opacity: 1;
}
.tox .tox-accordion__header.tox-accordion__header--disabled {
  cursor: not-allowed;
  opacity: 0.5;
}
.tox .tox-accordion__header.tox-accordion__header--icon-end {
  padding-right: calc(var(--tox-private-pad-sm, 8px) + var(--tox-private-pad-xs, 4px));
}
.tox .tox-accordion__header-icon {
  align-items: center;
  color: var(--tox-private-text-color, #fff);
  display: flex;
  flex-shrink: 0;
  height: calc(var(--tox-private-base-value, 16px) * 1.5);
  justify-content: center;
  width: calc(var(--tox-private-base-value, 16px) * 1.5);
}
.tox .tox-accordion__header-icon svg {
  display: block;
  fill: currentColor;
  height: 100%;
  width: 100%;
  max-height: calc(var(--tox-private-base-value, 16px) * 1.5);
  max-width: calc(var(--tox-private-base-value, 16px) * 1.5);
}
.tox .tox-accordion__header:not(.tox-accordion__header--icon-end) .tox-accordion__header-icon {
  margin-right: var(--tox-private-pad-sm, 8px);
  margin-left: 0;
}
.tox .tox-accordion__header--icon-end .tox-accordion__header-icon {
  margin-left: auto;
}
.tox .tox-accordion__header-text {
  flex: 1;
  min-width: 0;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
}
.tox .tox-accordion__header--icon-end .tox-accordion__header-text {
  flex: 0 1 auto;
  margin-right: var(--tox-private-pad-sm, 8px);
}
.tox .tox-accordion__content {
  border-radius: var(--tox-private-control-border-radius, 3px);
}
.tox .tox-accordion__content.tox-accordion__content--collapsed {
  display: none;
}
.tox .tox-accordion__content.tox-accordion__content--expanded {
  display: block;
}
.tox .tox-accordion__content-inner {
  padding: var(--tox-private-pad-sm, 8px) calc(var(--tox-private-pad-sm, 8px) + var(--tox-private-pad-xs, 4px)) calc(var(--tox-private-pad-sm, 8px) + var(--tox-private-pad-xs, 4px));
}
.tox .tox-accordion__content-inner .tox-form__group:last-child {
  margin-bottom: 0;
}
.tox .tox-accordion__content-inner .tox-form__group > *:not(:first-child) {
  margin-top: calc(var(--tox-private-pad-sm, 8px) + var(--tox-private-pad-xs, 4px));
}
.tox .tox-accordion__content-inner .tox-form__group > .tox-dropdown-content {
  margin-top: 0;
}
.tox .tox-accordion__content-inner .tox-button-group {
  display: flex;
  gap: var(--tox-private-pad-sm, 8px);
}
.tox .tox-accordion__content-inner .tox-accordion__model-button {
  border-radius: var(--tox-private-control-border-radius, 3px);
  align-items: center;
  appearance: none;
  background: none;
  border: none;
  color: inherit;
  cursor: pointer;
  display: flex;
  font-family: inherit;
  font-size: inherit;
  gap: var(--tox-private-pad-xs, 4px);
  margin: 0;
  outline: none;
  padding: 6px calc(var(--tox-private-pad-sm, 8px) + var(--tox-private-pad-xs, 4px));
  position: relative;
}
.tox .tox-accordion__content-inner .tox-accordion__model-button::after {
  border-radius: var(--tox-private-control-border-radius, 3px);
  bottom: 0;
  box-shadow: 0 0 0 var(--tox-private-keyboard-focus-outline-width, 0) var(--tox-private-keyboard-focus-outline-color, transparent);
  content: '';
  left: 0;
  opacity: 0;
  pointer-events: none;
  position: absolute;
  right: 0;
  top: 0;
}
@media (forced-colors: active) {
  .tox .tox-accordion__content-inner .tox-accordion__model-button::after {
    border: 2px solid highlight;
  }
}
.tox .tox-accordion__content-inner .tox-accordion__model-button:focus {
  z-index: 1;
}
.tox .tox-accordion__content-inner .tox-accordion__model-button:focus::after {
  opacity: 1;
}
.tox .tox-accordion .tox-selectfield {
  align-items: center;
  background-color: var(--tox-private-background-color, #222f3e);
  border: 1px solid var(--tox-private-border-color, #000000);
  border-radius: var(--tox-private-control-border-radius, 3px);
  box-sizing: border-box;
  display: flex;
  height: 34px;
  padding: 0 6px;
  position: relative;
  width: 100%;
}
.tox .tox-accordion .tox-selectfield:focus-within {
  box-shadow: 0 0 0 var(--tox-private-keyboard-focus-outline-width, 0) var(--tox-private-keyboard-focus-outline-color, transparent);
  z-index: 1;
}
@media (forced-colors: active) {
  .tox .tox-accordion .tox-selectfield:focus-within {
    border-color: highlight;
    box-shadow: 0 0 0 2px highlight;
  }
}
.tox .tox-accordion .tox-selectfield button {
  appearance: none;
  background: none;
  border: none;
  color: inherit;
  cursor: pointer;
  flex: 1;
  font-family: inherit;
  font-size: inherit;
  line-height: inherit;
  margin: 0;
  outline: none;
  padding: 5px 0;
  text-align: left;
}
.tox .tox-accordion .tox-selectfield .tox-icon {
  display: flex;
  flex-shrink: 0;
  padding: 9px 0;
  pointer-events: none;
}
.tox .tox-accordion .tox-selectfield .tox-icon svg {
  height: var(--tox-private-base-value, 16px);
  width: var(--tox-private-base-value, 16px);
}
.tox[dir=rtl] .tox-accordion__header {
  text-align: right;
}
.tox[dir=rtl] .tox-accordion__header:not(.tox-accordion__header--icon-end) .tox-accordion__header-icon {
  margin-left: var(--tox-private-pad-sm, 8px);
  margin-right: 0;
}
.tox[dir=rtl] .tox-accordion__header--icon-end .tox-accordion__header-icon {
  margin-right: auto;
  margin-left: 0;
}
.tox[dir=rtl] .tox-accordion__header--icon-end .tox-accordion__header-text {
  margin-left: var(--tox-private-pad-sm, 8px);
  margin-right: 0;
}
.tox .tox-alert {
  align-items: flex-start;
  align-self: stretch;
  border-radius: var(--tox-private-panel-border-radius, 3px);
  border-style: solid;
  border-width: 1px;
  box-sizing: border-box;
  color: var(--tox-private-text-color, #fff);
  display: flex;
  font-size: var(--tox-private-font-size-sm, 14px);
  font-weight: var(--tox-private-font-weight-normal, normal);
  gap: var(--tox-private-pad-xs, 4px);
  line-height: var(--tox-private-line-height-base, 1.3);
  padding: var(--tox-private-pad-xs, 4px) var(--tox-private-pad-sm, 8px);
  width: 100%;
}
.tox .tox-alert--error {
  background: linear-gradient(0deg, rgba(from var(--tox-private-background-color, #222f3e) r g b / 0.8) 0%, rgba(from var(--tox-private-background-color, #222f3e) r g b / 0.8) 100%), var(--tox-private-color-error, #c00);
  border-color: var(--tox-private-color-error, #c00);
}
.tox .tox-alert--warning {
  background: linear-gradient(0deg, rgba(from var(--tox-private-background-color, #222f3e) r g b / 0.8) 0%, rgba(from var(--tox-private-background-color, #222f3e) r g b / 0.8) 100%), var(--tox-private-color-warning, #FFCC00);
  border-color: var(--tox-private-color-warning, #FFCC00);
}
.tox .tox-alert__body {
  display: flex;
  flex: 1 0 0;
  flex-direction: column;
  min-width: 0;
}
.tox .tox-alert__content {
  align-items: center;
  display: flex;
  flex: 1 0 0;
  gap: var(--tox-private-pad-sm, 8px);
  padding: var(--tox-private-pad-sm, 8px) 0;
}
.tox .tox-alert__message {
  margin: 0;
  text-align: left;
}
.tox .tox-alert__actions {
  align-items: center;
  display: flex;
  flex-wrap: wrap;
  gap: var(--tox-private-pad-xs, 4px);
  justify-content: flex-start;
}
.tox .tox-anchorbar {
  display: flex;
  flex: 0 0 auto;
}
.tox .tox-bottom-anchorbar {
  display: flex;
  flex: 0 0 auto;
}
.tox .tox-bar {
  display: flex;
  flex: 0 0 auto;
}
.tox .tox-button {
  border-width: var(--tox-private-button-border-width, 1px);
  border-style: var(--tox-private-button-border-style, solid);
  border-radius: var(--tox-private-control-border-radius, 3px);
  font-family: var(--tox-private-font-stack, -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Oxygen-Sans, Ubuntu, Cantarell, "Helvetica Neue", sans-serif);
  font-size: var(--tox-private-button-font-size, 14px);
  font-style: var(--tox-private-button-font-style, normal);
  font-weight: var(--tox-private-button-font-weight, bold);
  line-height: var(--tox-private-control-line-height, 24px);
  padding: var(--tox-private-button-padding-y, 4px) var(--tox-private-button-padding-x, 16px);
  text-align: center;
  -webkit-text-decoration: none;
  text-decoration: none;
  text-transform: none;
  letter-spacing: normal;
  box-shadow: none;
  box-sizing: border-box;
  cursor: pointer;
  outline: none;
  position: relative;
  white-space: nowrap;
  display: inline-flex;
  justify-content: center;
  align-items: center;
  gap: var(--tox-private-pad-xs, 4px);
}
.tox .tox-button::before {
  border-radius: var(--tox-private-control-border-radius, 3px);
  bottom: calc(-1 * var(--tox-private-button-border-width, 1px));
  box-shadow: var(--tox-private-button-focus-outline, inset 0 0 0 1px #fff, 0 0 0 2px #207ab7);
  content: '';
  left: calc(-1 * var(--tox-private-button-border-width, 1px));
  opacity: 0;
  pointer-events: none;
  position: absolute;
  right: calc(-1 * var(--tox-private-button-border-width, 1px));
  top: calc(-1 * var(--tox-private-button-border-width, 1px));
}
.tox .tox-button:focus:not(:disabled) {
  background-color: var(--tox-private-button-focus-background-color, #1c6ca1);
  background-image: none;
  border-color: var(--tox-private-button-focus-border-color, #1c6ca1);
  box-shadow: var(--tox-private-button-focus-box-shadow, none);
  color: var(--tox-private-button-focus-text-color, #fff);
}
.tox .tox-button:focus:not(:disabled)::before {
  opacity: 1;
}
.tox .tox-button.tox-button--icon,
.tox .tox-button:has(.tox-icon:only-child) {
  padding: 4px;
}
.tox .tox-button .tox-icon svg {
  display: block;
  fill: currentColor;
}
.tox .tox-button .tox-icon.tox-icon--success svg {
  fill: var(--tox-private-color-success, #78AB46);
}
.tox .tox-button .tox-icon.tox-icon--error svg {
  fill: var(--tox-private-color-error, #c00);
}
.tox .tox-button--stretch {
  width: 100%;
}
.tox-context-form__group .tox-button--icon,
.tox-context-form__group .tox-button.tox-button--icon {
  margin: 3px 0 2px 0;
  padding: 0;
}
.tox {
  /* TODO: Add `--primary` to class name. Currently, we treat primary as base in alloy */
  /* TODO: Add `--primary` to class name. Currently, we treat primary as base in alloy */
}
.tox .tox-button {
  background-color: var(--tox-private-button-primary-background-color, #207ab7);
  background-image: none;
  background-position: 0 0;
  background-repeat: repeat;
  color: var(--tox-private-button-primary-text-color, #fff);
  border-color: var(--tox-private-button-primary-border-color, #207ab7);
  /* Enabled state */
}
.tox .tox-button[disabled] {
  background-color: var(--tox-private-button-primary-disabled-background-color, #207ab7);
  background-image: none;
  border-color: var(--tox-private-button-primary-disabled-border-color, #207ab7);
  color: var(--tox-private-button-primary-disabled-text-color, rgba(255, 255, 255, 0.5));
  cursor: not-allowed;
}
.tox .tox-button:focus:not(:disabled) {
  background-color: var(--tox-private-button-primary-focus-background-color, #1c6ca1);
  border-color: var(--tox-private-button-primary-focus-border-color, #1c6ca1);
  color: var(--tox-private-button-primary-focus-text-color, #fff);
  background-image: none;
  box-shadow: none;
}
.tox .tox-button:hover:not(:disabled) {
  background-color: var(--tox-private-button-primary-hover-background-color, #1c6ca1);
  border-color: var(--tox-private-button-primary-hover-border-color, #1c6ca1);
  color: var(--tox-private-button-primary-hover-text-color, #fff);
  background-image: none;
  box-shadow: none;
}
.tox .tox-button:active:not(:disabled) {
  background-color: var(--tox-private-button-primary-active-background-color, #185d8c);
  border-color: var(--tox-private-button-primary-active-border-color, #185d8c);
  color: var(--tox-private-button-primary-active-text-color, #fff);
  background-image: none;
  box-shadow: none;
}
.tox .tox-button.tox-button--enabled {
  background-color: var(--tox-private-button-primary-enabled-background-color, #185d8c);
  border-color: var(--tox-private-button-primary-enabled-border-color, #185d8c);
  color: var(--tox-private-button-primary-enabled-text-color, #fff);
  background-image: none;
  box-shadow: none;
}
.tox .tox-button.tox-button--enabled[disabled] {
  color: var(--tox-private-button-primary-disabled-text-color, rgba(255, 255, 255, 0.5));
  cursor: not-allowed;
}
.tox .tox-button.tox-button--enabled:focus:not(:disabled) {
  background-color: var(--tox-private-button-primary-enabled-focus-background-color, #154f76);
  border-color: var(--tox-private-button-primary-enabled-focus-border-color, #154f76);
  color: var(--tox-private-button-primary-enabled-focus-text-color, #fff);
  background-image: none;
  box-shadow: none;
}
.tox .tox-button.tox-button--enabled:hover:not(:disabled) {
  background-color: var(--tox-private-button-primary-enabled-hover-background-color, #154f76);
  border-color: var(--tox-private-button-primary-enabled-hover-border-color, #154f76);
  color: var(--tox-private-button-primary-enabled-hover-text-color, #fff);
  background-image: none;
  box-shadow: none;
}
.tox .tox-button.tox-button--enabled:active:not(:disabled) {
  background-color: var(--tox-private-button-primary-enabled-active-background-color, #114060);
  border-color: var(--tox-private-button-primary-enabled-active-border-color, #114060);
  color: var(--tox-private-button-primary-enabled-active-text-color, #fff);
  background-image: none;
  box-shadow: none;
}
.tox .tox-button--secondary {
  background-color: var(--tox-private-button-secondary-background-color, #3d546f);
  border-color: var(--tox-private-button-secondary-border-color, #3d546f);
  color: var(--tox-private-button-secondary-text-color, #fff);
  border-style: solid;
  border-width: 1px;
  background-image: none;
  background-position: 0 0;
  background-repeat: repeat;
  border-radius: 3px;
  box-shadow: none;
  font-size: 14px;
  font-style: normal;
  font-weight: bold;
  letter-spacing: normal;
  outline: none;
  padding: 4px 16px;
  -webkit-text-decoration: none;
  text-decoration: none;
  text-transform: none;
  /* Enabled state */
}
.tox .tox-button--secondary[disabled] {
  background-color: var(--tox-private-button-secondary-disabled-background-color, #3d546f);
  background-image: none;
  border-color: var(--tox-private-button-secondary-disabled-border-color, #3d546f);
  color: var(--tox-private-button-secondary-disabled-text-color, rgba(255, 255, 255, 0.5));
  cursor: not-allowed;
}
.tox .tox-button--secondary:focus:not(:disabled) {
  background-color: var(--tox-private-button-secondary-focus-background-color, #34485f);
  border-color: var(--tox-private-button-secondary-focus-border-color, #34485f);
  color: var(--tox-private-button-secondary-focus-text-color, #fff);
  background-image: none;
  box-shadow: none;
}
.tox .tox-button--secondary:hover:not(:disabled) {
  background-color: var(--tox-private-button-secondary-hover-background-color, #34485f);
  border-color: var(--tox-private-button-secondary-hover-border-color, #34485f);
  color: var(--tox-private-button-secondary-hover-text-color, #fff);
  background-image: none;
  box-shadow: none;
}
.tox .tox-button--secondary:active:not(:disabled) {
  background-color: var(--tox-private-button-secondary-active-background-color, #2b3b4e);
  border-color: var(--tox-private-button-secondary-active-border-color, #2b3b4e);
  color: var(--tox-private-button-secondary-active-text-color, #fff);
  background-image: none;
  box-shadow: none;
}
.tox .tox-button--secondary.tox-button--enabled {
  background-color: var(--tox-private-button-secondary-enabled-background-color, #6ea9d0);
  border-color: var(--tox-private-button-secondary-enabled-border-color, #6ea9d0);
  color: var(--tox-private-button-secondary-enabled-text-color, #fff);
  background-image: none;
  box-shadow: none;
}
.tox .tox-button--secondary.tox-button--enabled[disabled] {
  color: var(--tox-private-button-secondary-disabled-text-color, rgba(255, 255, 255, 0.5));
  cursor: not-allowed;
}
.tox .tox-button--secondary.tox-button--enabled:focus:not(:disabled) {
  background-color: var(--tox-private-button-secondary-enabled-focus-background-color, #5b9dca);
  border-color: var(--tox-private-button-secondary-enabled-focus-border-color, #5b9dca);
  color: var(--tox-private-button-secondary-enabled-focus-text-color, #fff);
  background-image: none;
  box-shadow: none;
}
.tox .tox-button--secondary.tox-button--enabled:hover:not(:disabled) {
  background-color: var(--tox-private-button-secondary-enabled-hover-background-color, #5b9dca);
  border-color: var(--tox-private-button-secondary-enabled-hover-border-color, #5b9dca);
  color: var(--tox-private-button-secondary-enabled-hover-text-color, #fff);
  background-image: none;
  box-shadow: none;
}
.tox .tox-button--secondary.tox-button--enabled:active:not(:disabled) {
  background-color: var(--tox-private-button-secondary-enabled-active-background-color, #4792c4);
  border-color: var(--tox-private-button-secondary-enabled-active-border-color, #4792c4);
  color: var(--tox-private-button-secondary-enabled-active-text-color, #fff);
  background-image: none;
  box-shadow: none;
}
.tox .tox-button--naked {
  background-color: transparent;
  border-color: transparent;
  box-shadow: unset;
  color: var(--tox-private-button-naked-text-color, #fff);
  /* Enabled state */
}
.tox .tox-button--naked[disabled] {
  background-color: #3d546f;
  border-color: #3d546f;
  color: var(--tox-private-button-naked-disabled-text-color, rgba(255, 255, 255, 0.5));
  cursor: not-allowed;
}
.tox .tox-button--naked:focus:not(:disabled) {
  background-color: var(--tox-private-button-naked-focus-background-color, #34485f);
  border-color: var(--tox-private-button-naked-focus-border-color, #34485f);
  color: var(--tox-private-button-naked-focus-text-color, #fff);
  box-shadow: none;
}
.tox .tox-button--naked:hover:not(:disabled) {
  background-color: var(--tox-private-button-naked-hover-background-color, #34485f);
  border-color: var(--tox-private-button-naked-hover-background-color, #34485f);
  color: var(--tox-private-button-naked-hover-text-color, #fff);
  box-shadow: none;
}
.tox .tox-button--naked:active:not(:disabled) {
  background-color: var(--tox-private-button-naked-active-background-color, #2b3b4e);
  border-color: var(--tox-private-button-naked-active-border-color, #2b3b4e);
  color: var(--tox-private-button-naked-active-text-color, #fff);
  box-shadow: none;
}
.tox .tox-button--naked.tox-button--enabled {
  background-color: var(--tox-private-button-naked-enabled-background-color, #346085);
  border-color: var(--tox-private-button-naked-enabled-border-color, #346085);
  color: var(--tox-private-button-naked-enabled-text-color, #fff);
  box-shadow: unset;
}
.tox .tox-button--naked.tox-button--enabled[disabled] {
  color: var(--tox-private-button-naked-disabled-text-color, rgba(255, 255, 255, 0.5));
  cursor: not-allowed;
}
.tox .tox-button--naked.tox-button--enabled:focus:not(:disabled) {
  background-color: var(--tox-private-button-naked-enabled-focus-background-color, #2d5373);
  border-color: var(--tox-private-button-naked-enabled-focus-border-color, #2d5373);
  color: var(--tox-private-button-naked-enabled-focus-text-color, #fff);
  box-shadow: unset;
}
.tox .tox-button--naked.tox-button--enabled:hover:not(:disabled) {
  background-color: var(--tox-private-button-naked-enabled-hover-background-color, #2d5373);
  border-color: var(--tox-private-button-naked-enabled-hover-border-color, #2d5373);
  color: var(--tox-private-button-naked-enabled-hover-text-color, #fff);
  box-shadow: unset;
}
.tox .tox-button--naked.tox-button--enabled:active:not(:disabled) {
  background-color: var(--tox-private-button-naked-enabled-active-background-color, #264560);
  border-color: var(--tox-private-button-naked-enabled-active-border-color, #264560);
  color: var(--tox-private-button-naked-enabled-active-text-color, #fff);
  box-shadow: unset;
}
.tox .tox-button--secondary--outline {
  background-color: transparent;
  border-color: var(--tox-private-button-secondary-outline-border-color, #3d546f);
  color: var(--tox-private-button-secondary-outline-text-color, #fff);
}
.tox .tox-button--secondary--outline:focus:not(:disabled) {
  background-color: var(--tox-private-button-secondary-outline-focus-background-color, #34485f);
  border-color: var(--tox-private-button-secondary-outline-focus-border-color, #34485f);
  color: var(--tox-private-button-secondary-outline-focus-text-color, #fff);
}
.tox .tox-button--secondary--outline:hover:not(:disabled) {
  background-color: var(--tox-private-button-secondary-outline-hover-background-color, #3d546f);
  border-color: var(--tox-private-button-secondary-outline-hover-border-color, #34485f);
  color: var(--tox-private-button-secondary-outline-hover-text-color, #fff);
}
.tox .tox-button--secondary--outline:active:not(:disabled) {
  background-color: var(--tox-private-button-secondary-outline-active-background-color, #34485f);
  border-color: var(--tox-private-button-secondary-outline-active-border-color, #34485f);
  color: var(--tox-private-button-secondary-outline-active-text-color, #fff);
}
.tox .tox-button--secondary--outline[disabled] {
  background-color: var(--tox-private-button-secondary-outline-disabled-background-color, transparent);
  border-color: var(--tox-private-button-secondary-outline-disabled-border-color, #3d546f);
  color: var(--tox-private-button-secondary-outline-disabled-text-color, rgba(255, 255, 255, 0.5));
}
.tox .tox-checkbox {
  align-items: center;
  border-radius: var(--tox-private-checkbox-border-radius, 3px);
  cursor: pointer;
  display: flex;
  height: var(--tox-private-control-height, 36px);
  min-width: var(--tox-private-control-height, 36px);
}
.tox .tox-checkbox__input {
  /* Hide from view but visible to screen readers */
  height: 1px;
  overflow: hidden;
  position: absolute;
  top: auto;
  width: 1px;
}
.tox .tox-checkbox__icons {
  display: flex;
  align-items: center;
  justify-content: center;
  box-sizing: content-box;
  padding: var(--tox-private-pad-xs, calc(4px - 1px));
  border-radius: var(--tox-private-checkbox-border-radius, 3px);
  box-shadow: 0 0 0 2px transparent;
  height: var(--tox-private-control-line-height, 24px);
  aspect-ratio: 1;
}
.tox .tox-checkbox__icons .tox-checkbox-icon__unchecked svg {
  display: block;
  fill: var(--tox-private-checkbox-unselected-color, rgba(255, 255, 255, 0.2));
}
@media (forced-colors: active) {
  .tox .tox-checkbox__icons .tox-checkbox-icon__unchecked svg {
    fill: currentColor !important;
  }
}
.tox .tox-checkbox__icons .tox-checkbox-icon__indeterminate svg {
  display: none;
  fill: var(--tox-private-checkbox-indeterminate-color, #207ab7);
}
.tox .tox-checkbox__icons .tox-checkbox-icon__checked svg {
  display: none;
  fill: var(--tox-private-checkbox-selected-color, #207ab7);
}
.tox .tox-checkbox--disabled {
  color: var(--tox-private-checkbox-disabled-text-color, rgba(255, 255, 255, 0.5));
  cursor: not-allowed;
}
.tox .tox-checkbox--disabled .tox-checkbox__icons .tox-checkbox-icon__checked svg {
  fill: var(--tox-private-checkbox-disabled-text-color, rgba(255, 255, 255, 0.5));
}
.tox .tox-checkbox--disabled .tox-checkbox__icons .tox-checkbox-icon__unchecked svg {
  fill: var(--tox-private-checkbox-disabled-text-color, rgba(255, 255, 255, 0.5));
}
.tox .tox-checkbox--disabled .tox-checkbox__icons .tox-checkbox-icon__indeterminate svg {
  fill: var(--tox-private-checkbox-disabled-text-color, rgba(255, 255, 255, 0.5));
}
.tox input.tox-checkbox__input:checked + .tox-checkbox__icons .tox-checkbox-icon__unchecked svg {
  display: none;
}
.tox input.tox-checkbox__input:checked + .tox-checkbox__icons .tox-checkbox-icon__checked svg {
  display: block;
}
.tox input.tox-checkbox__input:indeterminate + .tox-checkbox__icons .tox-checkbox-icon__unchecked svg {
  display: none;
}
.tox input.tox-checkbox__input:indeterminate + .tox-checkbox__icons .tox-checkbox-icon__indeterminate svg {
  display: block;
}
.tox input.tox-checkbox__input:focus + .tox-checkbox__icons {
  box-shadow: var(--tox-private-checkbox-focus-box-shadow, inset 0 0 0 1px #207ab7);
}
.tox:not([dir=rtl]) .tox-checkbox__label {
  margin-left: var(--tox-private-pad-xs, 4px);
}
.tox:not([dir=rtl]) .tox-checkbox__input {
  left: -10000px;
}
.tox:not([dir=rtl]) .tox-bar .tox-checkbox {
  margin-left: var(--tox-private-pad-xs, 4px);
}
.tox[dir=rtl] .tox-checkbox__label {
  margin-right: var(--tox-private-pad-xs, 4px);
}
.tox[dir=rtl] .tox-checkbox__input {
  right: -10000px;
}
.tox[dir=rtl] .tox-bar .tox-checkbox {
  margin-right: var(--tox-private-pad-xs, 4px);
}
.tox .tox-collection--toolbar .tox-collection__group {
  display: flex;
  padding: 0;
}
.tox .tox-collection--grid .tox-collection__group {
  display: flex;
  flex-wrap: wrap;
  max-height: 208px;
  overflow-x: hidden;
  overflow-y: auto;
  padding: 0;
}
.tox .tox-collection--list .tox-collection__group {
  border-bottom-width: 0;
  border-color: #1a1a1a;
  border-left-width: 0;
  border-right-width: 0;
  border-style: solid;
  border-top-width: 1px;
  padding: 4px 0;
  display: flex;
  flex-direction: column;
}
.tox .tox-collection--list .tox-collection__group:first-child {
  border-top-width: 0;
}
.tox .tox-collection__group-heading {
  background-color: #333333;
  color: #fff;
  cursor: default;
  font-size: 12px;
  font-style: normal;
  font-weight: normal;
  margin-bottom: 4px;
  margin-top: -4px;
  padding: 4px 8px;
  text-transform: none;
  -webkit-touch-callout: none;
  -webkit-user-select: none;
          user-select: none;
}
.tox .tox-collection__item {
  align-items: center;
  border-radius: 3px;
  color: #fff;
  display: flex;
  -webkit-touch-callout: none;
  -webkit-user-select: none;
          user-select: none;
}
.tox .tox-image-selector-menu .tox-collection__item-image-selector,
.tox .tox-image-selector-menu .tox-collection__item {
  flex-direction: column;
}
.tox .tox-image-selector-menu .tox-collection__item-image-selector .tox-collection__item-icon,
.tox .tox-image-selector-menu .tox-collection__item .tox-collection__item-icon,
.tox .tox-image-selector-menu .tox-collection__item-image-selector .tox-collection__item-image,
.tox .tox-image-selector-menu .tox-collection__item .tox-collection__item-image,
.tox .tox-image-selector-menu .tox-collection__item-image-selector .tox-collection__item-checkmark,
.tox .tox-image-selector-menu .tox-collection__item .tox-collection__item-checkmark {
  flex-grow: 1;
}
.tox .tox-image-selector-menu .tox-collection__item-image-selector label,
.tox .tox-image-selector-menu .tox-collection__item label {
  width: 48px;
  white-space: nowrap;
  overflow: hidden;
  font-size: 12px;
  color: #fff;
  text-align: center;
  align-self: flex-end;
}
.tox .tox-image-selector-menu .tox-collection__item-checkmark {
  height: 24px;
  width: 24px;
  position: absolute;
  top: 50%;
  left: 50%;
  transform: translate(-50%, -50%);
}
.tox .tox-image-selector-menu .tox-collection__item-checkmark svg path {
  fill: #207ab7;
  stroke: #207ab7;
}
.tox .tox-image-selector-menu .tox-image-selector__row .tox-collection__item-image-selector.tox-collection__item--active:not(.tox-collection__item--state-disabled) {
  background-color: #222f3e;
}
.tox .tox-image-selector-menu .tox-image-selector__row .tox-collection__item-image-selector.tox-collection__item--enabled:not(.tox-collection__item--state-disabled) {
  z-index: 2;
  background-color: #222f3e;
  opacity: 0.8;
  background-clip: content-box;
}
.tox .tox-collection--list .tox-collection__item {
  padding: 4px 8px;
}
.tox .tox-collection--toolbar .tox-collection__item {
  border-radius: 3px;
  padding: 4px;
}
.tox .tox-collection--grid .tox-collection__item {
  border-radius: 3px;
  padding: 4px;
}
.tox .tox-collection--list .tox-collection__item--enabled:not(.tox-collection__item--state-disabled) {
  background-color: #2b3b4e;
  color: #fff;
}
.tox .tox-collection--list .tox-collection__item--active:not(.tox-collection__item--state-disabled) {
  background-color: #4a5562;
  color: #fff;
}
@media (forced-colors: active) {
  .tox .tox-collection--list .tox-collection__item--active:not(.tox-collection__item--state-disabled) {
    border: solid 1px;
  }
}
.tox .tox-collection--grid .tox-collection__item--enabled:not(.tox-collection__item--state-disabled) {
  background-color: #757d87;
  color: #fff;
}
.tox .tox-collection--grid .tox-collection__item--active:not(.tox-collection__item--state-disabled) {
  background-color: #4a5562;
  color: #fff;
  position: relative;
  z-index: 1;
}
.tox .tox-collection--grid .tox-collection__item--active:not(.tox-collection__item--state-disabled):focus::after {
  border-radius: 3px;
  bottom: 0;
  box-shadow: 0 0 0 0 transparent inset;
  content: '';
  left: 0;
  position: absolute;
  right: 0;
  top: 0;
}
@media (forced-colors: active) {
  .tox .tox-collection--grid .tox-collection__item--active:not(.tox-collection__item--state-disabled):focus::after {
    border: 2px solid highlight;
  }
}
.tox .tox-collection--toolbar .tox-collection__item--enabled:not(.tox-collection__item--state-disabled) {
  background-color: #757d87;
  color: #fff;
}
@media (forced-colors: active) {
  .tox .tox-collection--toolbar .tox-collection__item--enabled:not(.tox-collection__item--state-disabled) {
    border-radius: 3px;
    outline: solid 1px;
  }
}
.tox .tox-collection--toolbar .tox-collection__item--active:not(.tox-collection__item--state-disabled) {
  color: #fff;
  background-color: #2b3b4e;
  position: relative;
}
.tox .tox-collection--toolbar .tox-collection__item--active:not(.tox-collection__item--state-disabled):hover {
  background-color: #4a5562;
  color: #fff;
}
.tox .tox-collection--toolbar .tox-collection__item--active:not(.tox-collection__item--state-disabled):focus {
  background-color: #4a5562;
  color: #fff;
}
.tox .tox-collection--toolbar .tox-collection__item--active:not(.tox-collection__item--state-disabled):focus::after {
  border-radius: 3px;
  bottom: 0;
  box-shadow: 0 0 0 0 transparent ;
  content: '';
  left: 0;
  position: absolute;
  right: 0;
  top: 0;
}
@media (forced-colors: active) {
  .tox .tox-collection--toolbar .tox-collection__item--active:not(.tox-collection__item--state-disabled):focus::after {
    border: 2px solid highlight;
  }
}
@media (forced-colors: active) {
  .tox .tox-collection--toolbar .tox-collection__item--active:not(.tox-collection__item--state-disabled):hover {
    border-radius: 3px;
    outline: solid 1px;
  }
}
.tox .tox-collection__item-image {
  border: 1px solid #000000;
  border-radius: 3px;
  display: flex;
  flex-direction: column;
  justify-content: center;
  margin-bottom: 4px;
  position: relative;
}
.tox .tox-collection__item-icon,
.tox .tox-collection__item-checkmark {
  align-items: center;
  display: flex;
  height: 24px;
  justify-content: center;
  width: 24px;
}
.tox .tox-collection__item-icon svg,
.tox .tox-collection__item-checkmark svg {
  fill: currentColor;
}
.tox .tox-collection--toolbar-lg .tox-collection__item-icon {
  height: 48px;
  width: 48px;
}
.tox .tox-collection__item-label {
  color: currentColor;
  display: inline-block;
  flex: 1;
  font-size: 14px;
  font-style: normal;
  font-weight: normal;
  line-height: 24px;
  max-width: 100%;
  text-transform: none;
  word-break: break-all;
}
.tox .tox-collection__item-accessory {
  color: currentColor;
  display: inline-block;
  font-size: 14px;
  height: 24px;
  line-height: 24px;
  text-transform: none;
}
.tox .tox-collection__item-caret {
  align-items: center;
  display: flex;
  min-height: 24px;
}
.tox .tox-collection__item-caret::after {
  content: '';
  font-size: 0;
  min-height: inherit;
}
.tox .tox-collection__item-caret svg {
  fill: currentColor;
}
.tox .tox-collection__item--state-disabled {
  background-color: transparent;
  color: rgba(255, 255, 255, 0.5);
  cursor: not-allowed;
}
.tox .tox-collection__item--state-disabled .tox-collection__item-caret svg {
  fill: rgba(255, 255, 255, 0.5);
}
.tox .tox-collection--list .tox-collection__item:not(.tox-collection__item--enabled) .tox-collection__item-checkmark svg {
  display: none;
}
.tox .tox-collection--list .tox-collection__item:not(.tox-collection__item--enabled) .tox-collection__item-accessory + .tox-collection__item-checkmark {
  display: none;
}
.tox .tox-collection--horizontal {
  background-color: #2b3b4e;
  border: 1px solid #1a1a1a;
  border-radius: 3px;
  box-shadow: 0 0 2px 0 rgba(42, 55, 70, 0.2), 0 4px 8px 0 rgba(42, 55, 70, 0.15);
  display: flex;
  flex: 0 0 auto;
  flex-shrink: 0;
  flex-wrap: nowrap;
  margin-bottom: 0;
  overflow-x: auto;
  padding: 0;
}
.tox .tox-collection--horizontal .tox-collection__group {
  align-items: center;
  display: flex;
  flex-wrap: nowrap;
  margin: 0;
  padding: 0 4px;
}
.tox .tox-collection--horizontal .tox-collection__item {
  height: 34px;
  margin: 3px 0 2px 0;
  padding: 0 4px;
}
.tox .tox-collection--horizontal .tox-collection__item-label {
  white-space: nowrap;
}
.tox .tox-collection--horizontal .tox-collection__item-caret {
  margin-left: 4px;
}
.tox .tox-collection__item-container {
  display: flex;
}
.tox .tox-collection__item-container--row {
  align-items: center;
  flex: 1 1 auto;
  flex-direction: row;
}
.tox .tox-collection__item-container--row.tox-collection__item-container--align-left {
  margin-right: auto;
}
.tox .tox-collection__item-container--row.tox-collection__item-container--align-right {
  justify-content: flex-end;
  margin-left: auto;
}
.tox .tox-collection__item-container--row.tox-collection__item-container--valign-top {
  align-items: flex-start;
  margin-bottom: auto;
}
.tox .tox-collection__item-container--row.tox-collection__item-container--valign-middle {
  align-items: center;
}
.tox .tox-collection__item-container--row.tox-collection__item-container--valign-bottom {
  align-items: flex-end;
  margin-top: auto;
}
.tox .tox-collection__item-container--column {
  align-self: center;
  flex: 1 1 auto;
  flex-direction: column;
}
.tox .tox-collection__item-container--column.tox-collection__item-container--align-left {
  align-items: flex-start;
}
.tox .tox-collection__item-container--column.tox-collection__item-container--align-right {
  align-items: flex-end;
}
.tox .tox-collection__item-container--column.tox-collection__item-container--valign-top {
  align-self: flex-start;
}
.tox .tox-collection__item-container--column.tox-collection__item-container--valign-middle {
  align-self: center;
}
.tox .tox-collection__item-container--column.tox-collection__item-container--valign-bottom {
  align-self: flex-end;
}
.tox:not([dir=rtl]) .tox-collection--horizontal .tox-collection__group:not(:last-of-type) {
  border-right: 1px solid #000000;
}
.tox:not([dir=rtl]) .tox-collection--list .tox-collection__item > *:not(:first-child) {
  margin-left: 8px;
}
.tox:not([dir=rtl]) .tox-collection--list .tox-collection__item > .tox-collection__item-label:first-child {
  margin-left: 4px;
}
.tox:not([dir=rtl]) .tox-collection__item-accessory {
  margin-left: 16px;
  text-align: right;
}
.tox:not([dir=rtl]) .tox-collection .tox-collection__item-caret {
  margin-left: 16px;
}
.tox[dir=rtl] .tox-collection--horizontal .tox-collection__group:not(:last-of-type) {
  border-left: 1px solid #000000;
}
.tox[dir=rtl] .tox-collection--list .tox-collection__item > *:not(:first-child) {
  margin-right: 8px;
}
.tox[dir=rtl] .tox-collection--list .tox-collection__item > .tox-collection__item-label:first-child {
  margin-right: 4px;
}
.tox[dir=rtl] .tox-collection__item-accessory {
  margin-right: 16px;
  text-align: left;
}
.tox[dir=rtl] .tox-collection .tox-collection__item-caret {
  margin-right: 16px;
  transform: rotateY(180deg);
}
.tox[dir=rtl] .tox-collection--horizontal .tox-collection__item-caret {
  margin-right: 4px;
}
@media (forced-colors: active) {
  .tox .tox-hue-slider,
  .tox .tox-rgb-form .tox-rgba-preview {
    background-color: currentColor !important;
    border: 1px solid highlight !important;
    forced-color-adjust: none;
  }
}
.tox .tox-color-picker-container {
  display: flex;
  flex-direction: row;
  height: 225px;
  margin: 0;
}
.tox .tox-sv-palette {
  box-sizing: border-box;
  display: flex;
  height: 100%;
}
.tox .tox-sv-palette-spectrum {
  height: 100%;
}
.tox .tox-sv-palette,
.tox .tox-sv-palette-spectrum {
  width: 225px;
}
.tox .tox-sv-palette-thumb {
  background: none;
  border: 1px solid black;
  border-radius: 50%;
  box-sizing: content-box;
  height: 12px;
  position: absolute;
  width: 12px;
}
.tox .tox-sv-palette-inner-thumb {
  border: 1px solid white;
  border-radius: 50%;
  height: 10px;
  position: absolute;
  width: 10px;
}
.tox .tox-hue-slider {
  box-sizing: border-box;
  height: 100%;
  width: 25px;
}
.tox .tox-hue-slider-spectrum {
  background: linear-gradient(to bottom, #f00, #ff0080, #f0f, #8000ff, #00f, #0080ff, #0ff, #00ff80, #0f0, #80ff00, #ff0, #ff8000, #f00);
  height: 100%;
  width: 100%;
}
.tox .tox-hue-slider,
.tox .tox-hue-slider-spectrum {
  width: 20px;
}
.tox .tox-hue-slider-spectrum:focus,
.tox .tox-sv-palette-spectrum:focus {
  outline: #08f solid;
}
.tox .tox-hue-slider-thumb {
  background: white;
  border: 1px solid black;
  box-sizing: content-box;
  height: 4px;
  width: 100%;
}
.tox .tox-rgb-form {
  display: flex;
  flex-direction: column;
  justify-content: space-between;
}
.tox .tox-rgb-form div {
  align-items: center;
  display: flex;
  justify-content: space-between;
  margin-bottom: 5px;
  width: inherit;
}
.tox .tox-rgb-form input {
  min-width: 6em;
}
.tox .tox-rgb-form input.tox-invalid {
  /* Need !important to override Chrome's focus styling unfortunately */
  border: 1px solid #f00 !important;
  box-shadow: 0 0 0 1px #f00;
}
.tox .tox-rgb-container {
  position: relative;
}
.tox .tox-rgb-form .tox-invalid-icon {
  align-content: center;
  align-items: center;
  display: none;
  height: 100%;
  position: absolute;
  right: 0;
  top: 0;
}
.tox .tox-rgb-form .tox-invalid-icon .tox-control-wrap__status-icon-invalid {
  margin: 0;
}
.tox .tox-rgb-warning-note {
  background-color: #442632;
  border: 1px solid #55212b;
  border-radius: 3px;
  color: #e68080;
  padding: 3px;
}
.tox input.tox-invalid + .tox-invalid-icon {
  display: flex;
}
.tox .tox-rgb-form .tox-rgba-preview {
  border: 1px solid black;
  flex-grow: 2;
  margin-bottom: 0;
}
.tox:not([dir=rtl]) .tox-sv-palette {
  margin-right: 15px;
}
.tox:not([dir=rtl]) .tox-hue-slider {
  margin-right: 15px;
}
.tox:not([dir=rtl]) .tox-hue-slider-thumb {
  margin-left: -1px;
}
.tox:not([dir=rtl]) .tox-rgb-form label {
  margin-right: 0.5em;
}
.tox[dir=rtl] .tox-sv-palette {
  margin-left: 15px;
}
.tox[dir=rtl] .tox-hue-slider {
  margin-left: 15px;
}
.tox[dir=rtl] .tox-hue-slider-thumb {
  margin-right: -1px;
}
.tox[dir=rtl] .tox-rgb-form label {
  margin-left: 0.5em;
}
.tox .tox-toolbar .tox-swatches,
.tox .tox-toolbar__primary .tox-swatches,
.tox .tox-toolbar__overflow .tox-swatches {
  margin: 2px 0 3px 4px;
}
.tox .tox-collection--list .tox-collection__group .tox-swatches-menu {
  border: 0;
  margin: -4px 0;
}
.tox .tox-swatches__row {
  display: flex;
}
@media (forced-colors: active) {
  .tox .tox-swatches__row {
    forced-color-adjust: none;
  }
}
.tox .tox-swatch {
  height: 30px;
  transition: transform 0.15s, box-shadow 0.15s;
  width: 30px;
}
.tox .tox-swatch:hover,
.tox .tox-swatch:focus {
  box-shadow: 0 0 0 1px rgba(127, 127, 127, 0.3) inset;
  transform: scale(0.8);
}
.tox .tox-swatch--remove {
  align-items: center;
  display: flex;
  justify-content: center;
}
.tox .tox-swatch--remove svg path {
  stroke: #e74c3c;
}
.tox .tox-swatches__picker-btn {
  align-items: center;
  background-color: transparent;
  border: 0;
  cursor: pointer;
  display: flex;
  height: 30px;
  justify-content: center;
  outline: none;
  padding: 0;
  width: 30px;
}
.tox .tox-swatches__picker-btn svg {
  fill: #fff;
  height: 24px;
  width: 24px;
}
.tox .tox-swatches__picker-btn:hover {
  background: #4a5562;
}
.tox div.tox-swatch:not(.tox-swatch--remove) svg {
  display: none;
  fill: #fff;
  height: 24px;
  margin: calc((30px - 24px) / 2) calc((30px - 24px) / 2);
  width: 24px;
}
.tox div.tox-swatch:not(.tox-swatch--remove) svg path {
  fill: #fff;
  paint-order: stroke;
  stroke: #222f3e;
  stroke-width: 2px;
}
.tox div.tox-swatch:not(.tox-swatch--remove).tox-collection__item--enabled svg {
  display: block;
}
.tox:not([dir=rtl]) .tox-swatches__picker-btn {
  margin-left: auto;
}
.tox[dir=rtl] .tox-swatches__picker-btn {
  margin-right: auto;
}
.tox {
  /* Animation for deleting a comment */
  /* A comment fades to 0 when it is being deleted, then is removed */
}
.tox .tox-comment {
  background: #222f3e;
  border: 1px solid #222f3e;
  border-radius: 3px;
  padding: 8px;
  padding-bottom: 16px;
  position: relative;
}
.tox .tox-comment:hover {
  box-shadow: 0 4px 8px 0 rgba(42, 55, 70, 0.1);
}
.tox .tox-comment.tox-comment--selected {
  background-color: #555542;
  border: 1px solid #ffcf30;
  box-shadow: 0 4px 8px 0 rgba(42, 55, 70, 0.1);
}
.tox .tox-comment.tox-comment--selected:focus {
  border: 2px solid transparent;
  margin: -1px;
}
.tox .tox-comment.tox-comment--selected:focus:not(:first-child) {
  margin-top: 7px;
}
.tox .tox-comment.tox-comment--selected .tox-comment__single {
  margin-bottom: 12px;
}
.tox .tox-comment.tox-comment--selected .tox-comment__single:focus {
  position: relative;
}
.tox .tox-comment.tox-comment--selected .tox-comment__single:focus::after {
  top: -9px;
  pointer-events: none;
  position: absolute;
  content: "";
  display: block;
  bottom: -9px;
  left: -9px;
  right: -9px;
  border-radius: 3px;
  border: 2px solid transparent;
}
.tox .tox-comment.tox-comment--selected .tox-comment__single:focus:last-of-type:has(textarea):after {
  bottom: calc((12px + 16px + 1px) * -1);
}
.tox .tox-comment__header {
  align-items: center;
  color: #fff;
  display: flex;
  justify-content: space-between;
}
.tox .tox-comment__date {
  color: #fff;
  font-size: 12px;
  line-height: 18px;
}
.tox .tox-comment__body {
  color: #fff;
  font-size: 16px;
  font-style: normal;
  font-weight: normal;
  line-height: 1.3;
  margin-top: 8px;
  position: relative;
  text-transform: initial;
  transition: max-height 0.5s cubic-bezier(0, 1, 0, 1);
  white-space: pre-wrap;
  /* We remove the transitions when wanting to measure and jump straight to collapsed or expanded */
}
.tox .tox-comment__body.tox-comment__body--expanded {
  max-height: 100em;
  transition: max-height 1s ease-in-out;
}
.tox .tox-comment__body.tox-comment__body--pending {
  transition: max-height 0s;
}
.tox .tox-comment__body p {
  margin: 0;
}
.tox .tox-comment__body textarea {
  resize: none;
  white-space: normal;
  width: 100%;
  font-size: 16px;
}
.tox .tox-comment__loading-text {
  align-items: center;
  color: #fff;
  display: flex;
  flex-direction: column;
  position: relative;
}
.tox .tox-comment__loading-text > div {
  padding-bottom: 16px;
}
.tox .tox-comment__overlaytext {
  bottom: 0;
  flex-direction: column;
  font-size: 14px;
  left: 0;
  padding: 1em;
  position: absolute;
  right: 0;
  top: 0;
  z-index: 10;
}
.tox .tox-comment__overlaytext p {
  background-color: #222f3e;
  box-shadow: 0 0 8px 8px #222f3e;
  color: #fff;
  text-align: center;
}
.tox .tox-comment__overlaytext div:nth-of-type(2) {
  font-size: 0.8em;
}
.tox .tox-comment__expander {
  padding-top: 8px;
}
.tox .tox-comment__expander p {
  color: rgba(255, 255, 255, 0.5);
  font-size: 14px;
  font-style: normal;
  /* Need a focus highlight on the show more/less button */
}
.tox .tox-comment__expander p:focus {
  font-weight: bold;
}
.tox .tox-comment__buttonspacing {
  padding-top: 16px;
  text-align: center;
}
.tox .tox-tbtn.tox-comment__mention-btn {
  display: flex;
  width: 34px;
  height: 34px;
  padding: 5px;
  justify-content: center;
  align-items: center;
  margin: 0;
  background-color: transparent;
}
.tox .tox-comment-thread {
  background: #222f3e;
  position: relative;
  border-radius: 3px;
  background-color: transparent;
}
.tox .tox-comment-thread > *:not(:first-child) {
  margin-top: 8px;
}
.tox .tox-comment-thread__overlay::after {
  background: #222f3e;
  bottom: 0;
  content: "";
  display: flex;
  left: 0;
  opacity: 0.9;
  position: absolute;
  right: 0;
  top: 0;
  z-index: 5;
}
.tox .tox-comment__reply {
  display: flex;
  flex-shrink: 0;
  flex-wrap: wrap;
  justify-content: flex-end;
  margin-top: 8px;
}
.tox .tox-comment__reply > *:first-child {
  margin-bottom: 8px;
  width: 100%;
}
.tox .tox-comment__edit {
  display: flex;
  flex-wrap: wrap;
  justify-content: flex-end;
  margin-top: 8px;
}
.tox .tox-comment__gradient::after {
  background: linear-gradient(rgba(34, 47, 62, 0), #222f3e);
  bottom: 0;
  content: "";
  display: block;
  height: 5em;
  margin-top: -40px;
  position: absolute;
  width: 100%;
}
.tox .tox-comment__overlay {
  background: #222f3e;
  bottom: 0;
  display: flex;
  flex-direction: column;
  flex-grow: 1;
  left: 0;
  opacity: 0.9;
  position: absolute;
  right: 0;
  text-align: center;
  top: 0;
  z-index: 5;
}
.tox .tox-comment__busy-spinner {
  align-items: center;
  background-color: #222f3e;
  bottom: 0;
  display: flex;
  justify-content: center;
  left: 0;
  position: absolute;
  right: 0;
  top: 0;
  z-index: 20;
}
.tox .tox-comment__scroll {
  display: flex;
  flex-direction: column;
  flex-shrink: 1;
  overflow: auto;
  padding: 12px;
  scroll-behavior: smooth;
}
.tox .tox-comment__scroll:has(textarea:focus) {
  scroll-behavior: auto;
}
.tox .tox-comment--disappearing {
  transition: opacity 0.5s ease;
}
.tox .tox-comment[data-transitioning-destination="deleting"] {
  opacity: 0;
}
.tox .tox-ring-loader {
  width: 10px;
  height: 10px;
  border: 1px solid #FFF;
  border-bottom-color: transparent;
  border-radius: 50%;
  display: inline-block;
  box-sizing: border-box;
  animation: tox-rotation 1s linear infinite;
}
.tox:not([dir=rtl]) .tox-comment__edit {
  margin-left: 8px;
}
.tox:not([dir=rtl]) .tox-comment__buttonspacing > *:last-child,
.tox:not([dir=rtl]) .tox-comment__edit > *:last-child,
.tox:not([dir=rtl]) .tox-comment__reply > *:last-child {
  margin-left: 8px;
}
.tox[dir=rtl] .tox-comment__edit {
  margin-right: 8px;
}
.tox[dir=rtl] .tox-comment__buttonspacing > *:last-child,
.tox[dir=rtl] .tox-comment__edit > *:last-child,
.tox[dir=rtl] .tox-comment__reply > *:last-child {
  margin-right: 8px;
}
.tox .tox-user {
  align-items: center;
  display: flex;
}
.tox .tox-user__avatar svg {
  fill: rgba(255, 255, 255, 0.5);
}
.tox .tox-user__avatar img {
  border-radius: 50%;
  height: 36px;
  object-fit: cover;
  vertical-align: middle;
  width: 36px;
}
.tox .tox-user__name {
  color: #fff;
  font-size: 14px;
  font-style: normal;
  font-weight: bold;
  line-height: 18px;
  text-transform: none;
}
.tox:not([dir=rtl]) .tox-user__avatar svg,
.tox:not([dir=rtl]) .tox-user__avatar img {
  margin-right: 8px;
}
.tox:not([dir=rtl]) .tox-user__avatar + .tox-user__name {
  margin-left: 8px;
}
.tox[dir=rtl] .tox-user__avatar svg,
.tox[dir=rtl] .tox-user__avatar img {
  margin-left: 8px;
}
.tox[dir=rtl] .tox-user__avatar + .tox-user__name {
  margin-right: 8px;
}
.tox {
  /* .tox-dialog-blocker-wrap {
    //
  } */
}
.tox .tox-dialog-wrap {
  align-items: center;
  bottom: 0;
  display: flex;
  justify-content: center;
  left: 0;
  position: fixed;
  right: 0;
  top: 0;
  z-index: 1100;
}
.tox .tox-dialog-wrap__backdrop {
  background-color: rgba(34, 47, 62, 0.75);
  bottom: 0;
  left: 0;
  position: absolute;
  right: 0;
  top: 0;
  z-index: 1;
}
.tox .tox-dialog-wrap__backdrop--opaque {
  background-color: #222f3e;
}
.tox .tox-dialog {
  background-color: #2b3b4e;
  border-color: #000000;
  border-radius: 3px;
  border-style: solid;
  border-width: 1px;
  box-shadow: 0 16px 16px -10px rgba(42, 55, 70, 0.15), 0 0 40px 1px rgba(42, 55, 70, 0.15);
  display: flex;
  flex-direction: column;
  max-height: 100%;
  max-width: 480px;
  overflow: hidden;
  position: relative;
  width: 95vw;
  z-index: 2;
}
@media only screen and (max-width: 767px ) {
  body:not(.tox-force-desktop) .tox .tox-dialog {
    align-self: flex-start;
    margin: 8px auto;
    max-height: calc(100vh - 8px * 2);
    width: calc(100vw - 16px);
  }
}
.tox .tox-dialog-inline {
  z-index: 1100;
}
.tox .tox-dialog__header {
  align-items: center;
  background-color: #2b3b4e;
  border-bottom: none;
  color: #fff;
  display: flex;
  font-size: 16px;
  justify-content: space-between;
  padding: 8px 16px 0 16px;
  position: relative;
}
.tox .tox-dialog__header .tox-button {
  z-index: 1;
}
.tox .tox-dialog__draghandle {
  cursor: grab;
  height: 100%;
  left: 0;
  position: absolute;
  top: 0;
  width: 100%;
}
.tox .tox-dialog__draghandle:active {
  cursor: grabbing;
}
.tox .tox-dialog__dismiss {
  margin-left: auto;
}
.tox .tox-dialog__title {
  font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Oxygen-Sans, Ubuntu, Cantarell, "Helvetica Neue", sans-serif;
  font-size: 20px;
  font-style: normal;
  font-weight: normal;
  line-height: 1.3;
  margin: 0;
  text-transform: none;
}
.tox .tox-dialog__body {
  color: #fff;
  display: flex;
  flex: 1;
  font-size: 16px;
  font-style: normal;
  font-weight: normal;
  line-height: 1.3;
  min-width: 0;
  text-align: left;
  text-transform: none;
}
@media only screen and (max-width: 767px ) {
  body:not(.tox-force-desktop) .tox .tox-dialog__body {
    flex-direction: column;
  }
}
.tox .tox-dialog__body-nav {
  align-items: flex-start;
  display: flex;
  flex-direction: column;
  flex-shrink: 0;
  padding: 16px 16px;
}
@media only screen and (min-width: 768px ) {
  .tox .tox-dialog__body-nav {
    max-width: 11em;
  }
}
@media only screen and (max-width: 767px ) {
  body:not(.tox-force-desktop) .tox .tox-dialog__body-nav {
    flex-direction: row;
    -webkit-overflow-scrolling: touch;
    overflow-x: auto;
    padding-bottom: 0;
  }
}
.tox .tox-dialog__body-nav-item {
  border-bottom: 2px solid transparent;
  color: rgba(255, 255, 255, 0.5);
  display: inline-block;
  flex-shrink: 0;
  font-size: 14px;
  line-height: 1.3;
  margin-bottom: 8px;
  max-width: 13em;
  -webkit-text-decoration: none;
  text-decoration: none;
}
.tox .tox-dialog__body-nav-item:focus {
  background-color: rgba(32, 122, 183, 0.1);
}
.tox .tox-dialog__body-nav-item--active {
  border-bottom: 2px solid #90bddb;
  color: #90bddb;
}
@media (forced-colors: active) {
  .tox .tox-dialog__body-nav-item--active {
    border-bottom: 2px solid highlight;
    color: highlight;
  }
}
.tox .tox-dialog__body-content {
  box-sizing: border-box;
  display: flex;
  flex: 1;
  flex-direction: column;
  max-height: min(650px, calc(100vh - 110px));
  overflow: auto;
  -webkit-overflow-scrolling: touch;
  padding: 16px 16px;
}
.tox .tox-dialog__body-content > * {
  margin-bottom: 0;
  margin-top: 16px;
}
.tox .tox-dialog__body-content > *:first-child {
  margin-top: 0;
}
.tox .tox-dialog__body-content > *:last-child {
  margin-bottom: 0;
}
.tox .tox-dialog__body-content > *:only-child {
  margin-bottom: 0;
  margin-top: 0;
}
.tox .tox-dialog__body-content a {
  color: #90bddb;
  cursor: pointer;
  -webkit-text-decoration: underline;
  text-decoration: underline;
}
.tox .tox-dialog__body-content a:hover,
.tox .tox-dialog__body-content a:focus {
  color: #428fc2;
  -webkit-text-decoration: underline;
  text-decoration: underline;
}
.tox .tox-dialog__body-content a:focus-visible {
  border-radius: 1px;
  outline: 2px solid #90bddb;
  outline-offset: 2px;
}
.tox .tox-dialog__body-content a:active {
  color: #33739e;
  -webkit-text-decoration: underline;
  text-decoration: underline;
}
.tox .tox-dialog__body-content svg {
  fill: #fff;
}
.tox .tox-dialog__body-content strong {
  font-weight: bold;
}
.tox .tox-dialog__body-content ul {
  list-style-type: disc;
}
.tox .tox-dialog__body-content ul,
.tox .tox-dialog__body-content ol,
.tox .tox-dialog__body-content dd {
  padding-inline-start: 2.5rem;
}
.tox .tox-dialog__body-content ul,
.tox .tox-dialog__body-content ol,
.tox .tox-dialog__body-content dl {
  margin-bottom: 16px;
}
.tox .tox-dialog__body-content ul,
.tox .tox-dialog__body-content ol,
.tox .tox-dialog__body-content dl,
.tox .tox-dialog__body-content dd,
.tox .tox-dialog__body-content dt {
  display: block;
  margin-inline-end: 0;
  margin-inline-start: 0;
}
.tox .tox-dialog__body-content .tox-form__group h1 {
  color: #fff;
  font-size: 20px;
  font-style: normal;
  font-weight: bold;
  letter-spacing: normal;
  margin-bottom: 16px;
  margin-top: 2rem;
  text-transform: none;
}
.tox .tox-dialog__body-content .tox-form__group h2 {
  color: #fff;
  font-size: 16px;
  font-style: normal;
  font-weight: bold;
  letter-spacing: normal;
  margin-bottom: 16px;
  margin-top: 2rem;
  text-transform: none;
}
.tox .tox-dialog__body-content .tox-form__group p {
  margin-bottom: 16px;
}
.tox .tox-dialog__body-content .tox-form__group h1:first-child,
.tox .tox-dialog__body-content .tox-form__group h2:first-child,
.tox .tox-dialog__body-content .tox-form__group p:first-child {
  margin-top: 0;
}
.tox .tox-dialog__body-content .tox-form__group h1:last-child,
.tox .tox-dialog__body-content .tox-form__group h2:last-child,
.tox .tox-dialog__body-content .tox-form__group p:last-child {
  margin-bottom: 0;
}
.tox .tox-dialog__body-content .tox-form__group h1:only-child,
.tox .tox-dialog__body-content .tox-form__group h2:only-child,
.tox .tox-dialog__body-content .tox-form__group p:only-child {
  margin-bottom: 0;
  margin-top: 0;
}
.tox .tox-dialog__body-content .tox-form__group .tox-label.tox-label--center {
  text-align: center;
}
.tox .tox-dialog__body-content .tox-form__group .tox-label.tox-label--end {
  text-align: end;
}
.tox .tox-dialog--width-lg {
  height: 650px;
  max-width: 1200px;
}
.tox .tox-dialog--fullscreen {
  height: 100%;
  max-width: 100%;
}
.tox .tox-dialog--fullscreen .tox-dialog__body-content {
  max-height: 100%;
}
.tox .tox-dialog--width-md {
  max-width: 800px;
}
.tox .tox-dialog--width-md .tox-dialog__body-content {
  overflow: auto;
}
.tox .tox-dialog__body-content--centered {
  text-align: center;
}
.tox .tox-dialog__footer {
  align-items: center;
  background-color: #2b3b4e;
  border-top: 1px solid #000000;
  display: flex;
  justify-content: space-between;
  padding: 8px 16px;
}
.tox .tox-dialog__footer-start,
.tox .tox-dialog__footer-end {
  display: flex;
}
.tox .tox-dialog__busy-spinner {
  align-items: center;
  background-color: rgba(34, 47, 62, 0.75);
  bottom: 0;
  display: flex;
  justify-content: center;
  left: 0;
  position: absolute;
  right: 0;
  top: 0;
  z-index: 3;
}
.tox .tox-dialog__table {
  border-collapse: collapse;
  width: 100%;
}
.tox .tox-dialog__table thead th {
  font-weight: bold;
  padding-bottom: 8px;
}
.tox .tox-dialog__table thead th:first-child {
  padding-right: 8px;
}
.tox .tox-dialog__table tbody tr {
  border-bottom: 1px solid #000000;
}
.tox .tox-dialog__table tbody tr:last-child {
  border-bottom: none;
}
.tox .tox-dialog__table td {
  padding-bottom: 8px;
  padding-top: 8px;
}
.tox .tox-dialog__table td:first-child {
  padding-right: 8px;
}
.tox .tox-dialog__iframe {
  min-height: 200px;
}
.tox .tox-dialog__iframe.tox-dialog__iframe--opaque {
  background: #fff;
}
.tox .tox-navobj-bordered {
  position: relative;
}
.tox .tox-navobj-bordered::before {
  border: 1px solid #000000;
  border-radius: 3px;
  content: '';
  inset: 0;
  opacity: 1;
  pointer-events: none;
  position: absolute;
  z-index: 1;
}
.tox .tox-navobj-bordered iframe {
  border-radius: 3px;
}
.tox .tox-navobj-bordered-focus.tox-navobj-bordered::before {
  border-color: #207ab7;
  box-shadow: none;
  outline: 2px solid rgba(32, 122, 183, 0.25);
}
.tox .tox-dialog__popups {
  position: absolute;
  width: 100%;
  z-index: 1100;
}
.tox .tox-dialog__body-iframe {
  display: flex;
  flex: 1;
  flex-direction: column;
}
.tox .tox-dialog__body-iframe .tox-navobj {
  display: flex;
  flex: 1;
}
.tox .tox-dialog__body-iframe .tox-navobj :nth-child(2) {
  flex: 1;
  height: 100%;
}
.tox .tox-dialog-dock-fadeout {
  opacity: 0;
  visibility: hidden;
}
.tox .tox-dialog-dock-fadein {
  opacity: 1;
  visibility: visible;
}
.tox .tox-dialog-dock-transition {
  transition: visibility 0s linear 0.3s, opacity 0.3s ease;
}
.tox .tox-dialog-dock-transition.tox-dialog-dock-fadein {
  transition-delay: 0s;
}
@media only screen and (max-width: 767px ) {
  body:not(.tox-force-desktop) .tox:not([dir=rtl]) .tox-dialog__body-nav {
    margin-right: 0;
  }
}
@media only screen and (max-width: 767px ) {
  body:not(.tox-force-desktop) .tox:not([dir=rtl]) .tox-dialog__body-nav-item:not(:first-child) {
    margin-left: 8px;
  }
}
.tox:not([dir=rtl]) .tox-dialog__footer .tox-dialog__footer-start > *,
.tox:not([dir=rtl]) .tox-dialog__footer .tox-dialog__footer-end > * {
  margin-left: 8px;
}
.tox[dir=rtl] .tox-dialog__body {
  text-align: right;
}
@media only screen and (max-width: 767px ) {
  body:not(.tox-force-desktop) .tox[dir=rtl] .tox-dialog__body-nav {
    margin-left: 0;
  }
}
@media only screen and (max-width: 767px ) {
  body:not(.tox-force-desktop) .tox[dir=rtl] .tox-dialog__body-nav-item:not(:first-child) {
    margin-right: 8px;
  }
}
.tox[dir=rtl] .tox-dialog__footer .tox-dialog__footer-start > *,
.tox[dir=rtl] .tox-dialog__footer .tox-dialog__footer-end > * {
  margin-right: 8px;
}
.tox .tox-dropdown-content {
  box-shadow: 0 0 2px 0 rgba(42, 55, 70, 0.2), 0 4px 8px 0 rgba(42, 55, 70, 0.15);
  position: fixed;
  position-try-fallbacks: flip-block, flip-inline, flip-block flip-inline;
  overflow: auto;
  height: fit-content;
  width: fit-content;
  border-radius: var(--tox-private-panel-border-radius, 3px);
  background-color: var(--tox-private-background-color, #222f3e);
  max-height: 50vh;
}
.tox .tox-dropdown-content .tox-menu {
  width: 100%;
  box-shadow: none;
}
body.tox-dialog__disable-scroll {
  overflow: hidden;
}
.tox .tox-dropzone-container {
  display: flex;
  flex: 1;
}
.tox .tox-dropzone {
  align-items: center;
  background: #fff;
  border: 2px dashed #000000;
  box-sizing: border-box;
  display: flex;
  flex-direction: column;
  flex-grow: 1;
  justify-content: center;
  min-height: 100px;
  padding: 10px;
}
.tox .tox-dropzone p {
  color: rgba(255, 255, 255, 0.5);
  margin: 0 0 16px 0;
}
.tox .tox-edit-area {
  display: flex;
  flex: 1;
  overflow: hidden;
  position: relative;
}
.tox .tox-edit-area::before {
  border: 0 solid transparent;
  border-radius: 4px;
  content: '';
  inset: 0;
  opacity: 0;
  pointer-events: none;
  position: absolute;
  transition: opacity 0.15s;
  z-index: 1;
}
@media (forced-colors: active) {
  .tox .tox-edit-area::before {
    border: 0 solid highlight;
  }
}
.tox .tox-edit-area__iframe {
  background-color: #fff;
  border: 0;
  box-sizing: border-box;
  flex: 1;
  height: 100%;
  position: absolute;
  width: 100%;
}
.tox.tox-edit-focus .tox-edit-area::before {
  opacity: 1;
}
.tox.tox-inline-edit-area {
  border: 1px dotted #000000;
}
.tox .tox-expandable-box {
  border-radius: 6px;
  border: 1px solid var(--tox-private-border-color, #000000);
  display: flex;
  flex-direction: column;
  justify-content: stretch;
  gap: var(--tox-private-pad-sm, 8px);
  padding: var(--tox-private-pad-sm, 8px) var(--tox-private-pad-md, 16px);
}
.tox .tox-expandable-box__content {
  overflow: auto;
}
.tox .tox-expandable-box__content--overflowing {
  position: relative;
  overflow: hidden;
}
.tox .tox-expandable-box__content--overflowing::after {
  content: '';
  position: absolute;
  bottom: 0;
  left: 0;
  right: 0;
  height: min(100px, 100%);
  pointer-events: none;
  background: linear-gradient(to bottom, transparent 50%, var(--tox-private-background-color, #222f3e));
}
.tox .tox-expandable-box__content--expanded {
  max-height: fit-content;
}
.tox .tox-control-wrap {
  flex: 1;
  position: relative;
}
.tox .tox-control-wrap:not(.tox-control-wrap--status-invalid) .tox-control-wrap__status-icon-invalid,
.tox .tox-control-wrap:not(.tox-control-wrap--status-unknown) .tox-control-wrap__status-icon-unknown,
.tox .tox-control-wrap:not(.tox-control-wrap--status-valid) .tox-control-wrap__status-icon-valid {
  display: none;
}
.tox .tox-control-wrap svg {
  display: block;
}
.tox .tox-control-wrap__status-icon-wrap {
  position: absolute;
  top: 50%;
  transform: translateY(-50%);
}
.tox .tox-control-wrap__status-icon-invalid svg {
  fill: #c00;
}
.tox .tox-control-wrap__status-icon-unknown svg {
  fill: orange;
}
.tox .tox-control-wrap__status-icon-valid svg {
  fill: green;
}
.tox:not([dir=rtl]) .tox-control-wrap--status-invalid .tox-textfield,
.tox:not([dir=rtl]) .tox-control-wrap--status-unknown .tox-textfield,
.tox:not([dir=rtl]) .tox-control-wrap--status-valid .tox-textfield {
  padding-right: 32px;
}
.tox:not([dir=rtl]) .tox-control-wrap__status-icon-wrap {
  right: 4px;
}
.tox[dir=rtl] .tox-control-wrap--status-invalid .tox-textfield,
.tox[dir=rtl] .tox-control-wrap--status-unknown .tox-textfield,
.tox[dir=rtl] .tox-control-wrap--status-valid .tox-textfield {
  padding-left: 32px;
}
.tox[dir=rtl] .tox-control-wrap__status-icon-wrap {
  left: 4px;
}
.tox .tox-custom-preview {
  border-color: #000000;
  border-radius: 3px;
  border-style: solid;
  border-width: 1px;
  flex: 1;
  padding: 8px;
}
.tox .tox-autocompleter {
  max-width: 25em;
}
.tox .tox-autocompleter .tox-menu {
  box-sizing: border-box;
  max-width: 25em;
}
.tox .tox-autocompleter .tox-autocompleter-highlight {
  font-weight: bold;
}
.tox .tox-color-input {
  display: flex;
  position: relative;
  z-index: 1;
}
.tox .tox-color-input .tox-textfield {
  z-index: -1;
}
.tox .tox-color-input span {
  border-color: rgba(42 55 3.5%);
  border-radius: 3px;
  border-style: solid;
  border-width: 1px;
  box-shadow: none;
  box-sizing: border-box;
  height: 24px;
  position: absolute;
  top: 6px;
  width: 24px;
}
@media (forced-colors: active) {
  .tox .tox-color-input span {
    border-color: currentColor;
    border-width: 2px !important;
    forced-color-adjust: none;
  }
}
.tox .tox-color-input span:hover:not([aria-disabled=true]),
.tox .tox-color-input span:focus:not([aria-disabled=true]) {
  border-color: #207ab7;
  cursor: pointer;
}
.tox .tox-color-input span::before {
  background-image: linear-gradient(45deg, rgba(255, 255, 255, 0.25) 25%, transparent 25%), linear-gradient(-45deg, rgba(255, 255, 255, 0.25) 25%, transparent 25%), linear-gradient(45deg, transparent 75%, rgba(255, 255, 255, 0.25) 75%), linear-gradient(-45deg, transparent 75%, rgba(255, 255, 255, 0.25) 75%);
  background-position: 0 0, 0 6px, 6px -6px, -6px 0;
  background-size: 12px 12px;
  border: 1px solid #2b3b4e;
  border-radius: 3px;
  box-sizing: border-box;
  content: '';
  height: 24px;
  left: -1px;
  position: absolute;
  top: -1px;
  width: 24px;
  z-index: -1;
}
@media (forced-colors: active) {
  .tox .tox-color-input span::before {
    border: none;
  }
}
.tox .tox-color-input span[aria-disabled=true] {
  cursor: not-allowed;
}
.tox:not([dir=rtl]) .tox-color-input .tox-textfield {
  padding-left: 36px;
}
.tox:not([dir=rtl]) .tox-color-input span {
  left: 6px;
}
.tox[dir="rtl"] .tox-color-input .tox-textfield {
  padding-right: 36px;
}
.tox[dir="rtl"] .tox-color-input span {
  right: 6px;
}
.tox .tox-label,
.tox .tox-toolbar-label {
  color: rgba(255, 255, 255, 0.5);
  display: block;
  font-size: 14px;
  font-style: normal;
  font-weight: normal;
  line-height: 1.3;
  padding: 0 8px 0 0;
  text-transform: none;
  white-space: nowrap;
}
.tox .tox-toolbar-label {
  padding: 0 8px;
}
.tox[dir=rtl] .tox-label {
  padding: 0 0 0 8px;
}
.tox .tox-form {
  display: flex;
  flex: 1;
  flex-direction: column;
}
.tox .tox-form__group {
  box-sizing: border-box;
  margin-bottom: 4px;
}
.tox .tox-form-group--maximize {
  flex: 1;
}
.tox .tox-form__group--error {
  color: #c00;
}
.tox .tox-form__group--collection {
  display: flex;
}
.tox .tox-form__grid {
  display: flex;
  flex-direction: row;
  flex-wrap: wrap;
  justify-content: space-between;
}
.tox .tox-form__grid--2col > .tox-form__group {
  width: calc(50% - (8px / 2));
}
.tox .tox-form__grid--3col > .tox-form__group {
  width: calc(100% / 3 - (8px / 2));
}
.tox .tox-form__grid--4col > .tox-form__group {
  width: calc(25% - (8px / 2));
}
.tox .tox-form__controls-h-stack {
  align-items: center;
  display: flex;
}
.tox .tox-form__group--inline {
  align-items: center;
  display: flex;
}
.tox .tox-form__group--stretched {
  display: flex;
  flex: 1;
  flex-direction: column;
}
.tox .tox-form__group--stretched .tox-textarea {
  flex: 1;
}
.tox .tox-form__group--stretched .tox-navobj {
  display: flex;
  flex: 1;
}
.tox .tox-form__group--stretched .tox-navobj :nth-child(2) {
  flex: 1;
  height: 100%;
}
.tox:not([dir=rtl]) .tox-form__controls-h-stack > *:not(:first-child) {
  margin-left: 4px;
}
.tox[dir=rtl] .tox-form__controls-h-stack > *:not(:first-child) {
  margin-right: 4px;
}
.tox .tox-lock.tox-locked .tox-lock-icon__unlock,
.tox .tox-lock:not(.tox-locked) .tox-lock-icon__lock {
  display: none;
}
.tox .tox-context-form__group .tox-button--icon.tox-lock-context-form-size-input {
  margin-left: 8px;
  margin-right: 8px;
}
.tox .tox-textfield,
.tox .tox-toolbar-textfield,
.tox .tox-listboxfield .tox-listbox--select,
.tox .tox-textarea,
.tox .tox-textarea-wrap .tox-textarea:focus {
  appearance: none;
  background-color: #2b3b4e;
  border-color: #000000;
  border-radius: 3px;
  border-style: solid;
  border-width: 1px;
  box-shadow: none;
  box-sizing: border-box;
  color: #fff;
  font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Oxygen-Sans, Ubuntu, Cantarell, "Helvetica Neue", sans-serif;
  font-size: 16px;
  line-height: 24px;
  margin: 0;
  min-height: 34px;
  outline: none;
  padding: 5px 4.75px;
  resize: none;
  width: 100%;
}
.tox .tox-textfield[disabled],
.tox .tox-toolbar-textfield[disabled],
.tox .tox-textarea[disabled] {
  background-color: #222f3e;
  color: rgba(255, 255, 255, 0.85);
  cursor: not-allowed;
}
.tox .tox-textfield:focus,
.tox .tox-toolbar-textfield:focus,
.tox .tox-listboxfield .tox-listbox--select:focus,
.tox .tox-textarea-wrap:focus-within,
.tox .tox-textarea:focus,
.tox .tox-focusable-wrapper:focus,
.tox .tox-custom-editor:focus-within {
  background-color: #2b3b4e;
  border-color: #207ab7;
  box-shadow: none;
  outline: 2px solid rgba(32, 122, 183, 0.25);
}
.tox .tox-toolbar-textfield {
  max-width: 250px;
  min-height: unset;
  height: 34px;
  margin: 2px 0 3px 0;
}
.tox .tox-naked-btn {
  background-color: transparent;
  border: 0;
  border-color: transparent;
  box-shadow: unset;
  color: #207ab7;
  cursor: pointer;
  display: block;
  margin: 0;
  padding: 0;
}
.tox .tox-naked-btn svg {
  display: block;
  fill: #fff;
}
.tox .tox-textfield-size {
  width: 80px;
}
.tox:not([dir=rtl]) .tox-toolbar-textfield + * {
  margin-left: 4px;
}
.tox[dir=rtl] .tox-toolbar-textfield + * {
  margin-right: 4px;
}
.tox .tox-listboxfield {
  cursor: pointer;
  position: relative;
}
.tox .tox-listboxfield .tox-listbox--select[disabled] {
  background-color: #19232e;
  color: rgba(255, 255, 255, 0.85);
  cursor: not-allowed;
}
.tox .tox-listbox__select-label {
  cursor: default;
  flex: 1;
  margin: 0 4px;
}
.tox .tox-listbox__select-chevron {
  align-items: center;
  display: flex;
  justify-content: center;
  width: 16px;
}
.tox .tox-listbox__select-chevron svg {
  fill: #fff;
}
@media (forced-colors: active) {
  .tox .tox-listbox__select-chevron svg {
    fill: currentColor !important;
  }
}
.tox .tox-listboxfield .tox-listbox--select {
  align-items: center;
  display: flex;
}
.tox:not([dir=rtl]) .tox-listboxfield svg {
  right: 8px;
}
.tox[dir=rtl] .tox-listboxfield svg {
  left: 8px;
}
.tox .tox-selectfield {
  cursor: pointer;
  position: relative;
}
.tox .tox-selectfield select {
  appearance: none;
  background-color: #2b3b4e;
  border-color: #000000;
  border-radius: 3px;
  border-style: solid;
  border-width: 1px;
  box-shadow: none;
  box-sizing: border-box;
  color: #fff;
  font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Oxygen-Sans, Ubuntu, Cantarell, "Helvetica Neue", sans-serif;
  font-size: 16px;
  line-height: 24px;
  margin: 0;
  min-height: 34px;
  outline: none;
  padding: 5px 4.75px;
  resize: none;
  width: 100%;
}
.tox .tox-selectfield select[disabled] {
  background-color: #19232e;
  color: rgba(255, 255, 255, 0.85);
  cursor: not-allowed;
}
.tox .tox-selectfield select::-ms-expand {
  display: none;
}
.tox .tox-selectfield select:focus {
  background-color: #2b3b4e;
  border-color: #207ab7;
  box-shadow: none;
  outline: 2px solid rgba(32, 122, 183, 0.25);
}
.tox .tox-selectfield svg {
  pointer-events: none;
  position: absolute;
  top: 50%;
  transform: translateY(-50%);
}
.tox .tox-selectfield select option:checked {
  background-color: revert;
  color: revert;
}
.tox:not([dir=rtl]) .tox-selectfield select[size="0"],
.tox:not([dir=rtl]) .tox-selectfield select[size="1"] {
  padding-right: 24px;
}
.tox:not([dir=rtl]) .tox-selectfield svg {
  right: 8px;
}
.tox[dir=rtl] .tox-selectfield select[size="0"],
.tox[dir=rtl] .tox-selectfield select[size="1"] {
  padding-left: 24px;
}
.tox[dir=rtl] .tox-selectfield svg {
  left: 8px;
}
.tox .tox-textarea-wrap {
  border-color: #000000;
  border-radius: 3px;
  border-style: solid;
  border-width: 1px;
  display: flex;
  flex: 1;
  overflow: hidden;
}
.tox .tox-textarea {
  appearance: textarea;
  white-space: pre-wrap;
}
.tox .tox-textarea-wrap .tox-textarea {
  border: none;
}
.tox .tox-textarea-wrap .tox-textarea:focus {
  border: none;
}
.tox-fullscreen {
  border: 0;
  height: 100%;
  margin: 0;
  overflow: hidden;
  overscroll-behavior: none;
  padding: 0;
  touch-action: pinch-zoom;
  width: 100%;
}
.tox.tox-tinymce.tox-fullscreen .tox-statusbar__resize-handle {
  display: none;
}
.tox.tox-tinymce.tox-fullscreen,
.tox-shadowhost.tox-fullscreen {
  left: 0;
  position: fixed;
  top: 0;
  z-index: 1200;
}
.tox.tox-tinymce.tox-fullscreen {
  background-color: transparent;
}
.tox-fullscreen .tox.tox-tinymce-aux,
.tox-fullscreen ~ .tox.tox-tinymce-aux {
  z-index: 1201;
}
.tox .tox-help__more-link {
  list-style: none;
  margin-top: 1em;
}
.tox .tox-imagepreview {
  background-color: #666;
  height: 380px;
  overflow: hidden;
  position: relative;
  width: 100%;
}
.tox .tox-imagepreview.tox-imagepreview__loaded {
  overflow: auto;
}
.tox .tox-imagepreview__container {
  display: flex;
  left: 100vw;
  position: absolute;
  top: 100vw;
}
.tox .tox-imagepreview__image {
  background: url(data:image/gif;base64,R0lGODdhDAAMAIABAMzMzP///ywAAAAADAAMAAACFoQfqYeabNyDMkBQb81Uat85nxguUAEAOw==);
}
.tox .tox-image-tools .tox-spacer {
  flex: 1;
}
.tox .tox-image-tools .tox-bar {
  align-items: center;
  display: flex;
  height: 60px;
  justify-content: center;
}
.tox .tox-image-tools .tox-imagepreview,
.tox .tox-image-tools .tox-imagepreview + .tox-bar {
  margin-top: 8px;
}
.tox .tox-image-tools .tox-croprect-block {
  background: black;
  filter: alpha(opacity=50);
  opacity: 0.5;
  position: absolute;
  zoom: 1;
}
.tox .tox-image-tools .tox-croprect-handle {
  border: 2px solid white;
  height: 20px;
  left: 0;
  position: absolute;
  top: 0;
  width: 20px;
}
.tox .tox-image-tools .tox-croprect-handle-move {
  border: 0;
  cursor: move;
  position: absolute;
}
.tox .tox-image-tools .tox-croprect-handle-nw {
  border-width: 2px 0 0 2px;
  cursor: nw-resize;
  left: 100px;
  margin: -2px 0 0 -2px;
  top: 100px;
}
.tox .tox-image-tools .tox-croprect-handle-ne {
  border-width: 2px 2px 0 0;
  cursor: ne-resize;
  left: 200px;
  margin: -2px 0 0 -20px;
  top: 100px;
}
.tox .tox-image-tools .tox-croprect-handle-sw {
  border-width: 0 0 2px 2px;
  cursor: sw-resize;
  left: 100px;
  margin: -20px 2px 0 -2px;
  top: 200px;
}
.tox .tox-image-tools .tox-croprect-handle-se {
  border-width: 0 2px 2px 0;
  cursor: se-resize;
  left: 200px;
  margin: -20px 0 0 -20px;
  top: 200px;
}
.tox .tox-image-selector-loading-spinner-wrapper {
  display: flex;
  justify-content: center;
  align-items: center;
}
.tox .tox-image-selector-loading-spinner {
  position: absolute;
  width: min(24px, 30%);
  aspect-ratio: 1;
  border-radius: 50%;
  border: 3px solid #207ab7;
  border-bottom-color: transparent;
  animation: tox-rotation 1s linear infinite;
}
.tox .tox-toolbar .tox-image-selector,
.tox .tox-toolbar__primary .tox-image-selector,
.tox .tox-toolbar__overflow .tox-image-selector {
  margin: 2px 0 3px 4px;
}
.tox .tox-image-selector-menu {
  border: 0;
  border-radius: 3px;
  margin: -4px 0;
  padding: 4px;
}
.tox .tox-image-selector-menu .tox-collection--list .tox-collection__group {
  border: 0;
  padding: 0;
  margin: -4px 0;
}
.tox .tox-image-selector-menu .tox-collection__item {
  max-width: 48px;
}
.tox .tox-image-selector-menu .tox-collection__item-icon {
  border: 1px solid #000000;
  border-radius: 3px;
  margin-bottom: 4px;
  width: 100%;
}
.tox .tox-image-selector-menu .tox-collection__item-icon svg path {
  stroke: #c00;
}
.tox .tox-image-selector__row {
  display: flex;
}
.tox .tox-image-selector--remove {
  align-items: center;
  display: flex;
  justify-content: center;
}
.tox .tox-image-selector--remove svg path {
  stroke: #c00;
}
.tox .tox-image-selector-image-wrapper {
  width: 46px;
  height: 46px;
  display: flex;
  align-items: center;
  justify-content: center;
}
.tox .tox-image-selector-image-img {
  max-width: 100%;
  max-height: 100%;
}
.tox .tox-image-selector__picker-btn {
  align-items: center;
  background-color: transparent;
  border: 0;
  cursor: pointer;
  display: flex;
  height: 30px;
  justify-content: center;
  outline: none;
  padding: 0;
  width: 30px;
}
.tox .tox-image-selector__picker-btn svg {
  fill: #fff;
  height: 24px;
  width: 24px;
}
.tox .tox-image-selector__picker-btn:hover {
  background: #4a5562;
}
.tox .tox-context-toolbar {
  position: absolute;
  position-try-fallbacks: flip-block, flip-inline, flip-block flip-inline;
  z-index: 1150;
  background-color: var(--tox-private-background-color, #222f3e);
  color: var(--tox-private-text-color, #fff);
  border: 1px solid #364a62;
  border-radius: 6px;
  box-shadow: 0 2px 8px rgba(0, 0, 0, 0.08);
  padding: 8px;
}
.tox .tox-context-toolbar[popover] {
  inset: auto;
  margin: 0;
}
.tox .tox-context-toolbar .tox-toolbar {
  display: flex;
  flex-wrap: nowrap;
  gap: 8px;
}
.tox .tox-context-toolbar .tox-toolbar__group {
  display: flex;
  flex-wrap: nowrap;
  flex-shrink: 0;
  gap: 8px;
  align-items: center;
  padding: 0;
}
.tox .tox-insert-table-picker {
  background-color: #222f3e;
  display: flex;
  flex-wrap: wrap;
  width: 170px;
}
.tox .tox-insert-table-picker > div {
  border-color: #000000;
  border-style: solid;
  border-width: 0 1px 1px 0;
  box-sizing: border-box;
  height: 17px;
  width: 17px;
}
.tox .tox-collection--list .tox-collection__group .tox-insert-table-picker {
  margin: 0 -4px;
}
.tox .tox-insert-table-picker .tox-insert-table-picker__selected {
  background-color: rgba(32, 122, 183, 0.5);
  border-color: rgba(32, 122, 183, 0.5);
}
@media (forced-colors: active) {
  .tox .tox-insert-table-picker .tox-insert-table-picker__selected {
    border-color: Highlight;
    filter: contrast(50%);
  }
}
.tox .tox-insert-table-picker__label {
  color: #fff;
  display: block;
  font-size: 14px;
  padding: 4px;
  text-align: center;
  width: 100%;
}
.tox:not([dir=rtl]) .tox-insert-table-picker > div:nth-child(10n) {
  border-right: 0;
}
.tox[dir=rtl] .tox-insert-table-picker > div:nth-child(10n+1) {
  border-right: 0;
}
.tox-mentions__card-common {
  z-index: 1200;
}
.tox.tox-mentions__card {
  background: #222f3e;
  border: 1px solid #000000;
  display: flex;
  padding: 4px 8px;
}
.tox.tox-mentions__card .tox-mentions__container {
  display: flex;
  flex-direction: column;
  align-self: center;
  margin: 0 4px;
}
.tox .tox-mentions__avatar {
  width: 42px;
  height: 42px;
  border-radius: 50%;
  margin-right: 4px;
}
.tox .tox-mentions__username {
  font-size: 14px;
  line-height: 21px;
  color: #fff;
}
.tox .tox-mentions__description {
  font-size: 12px;
  line-height: 21px;
  color: rgba(255, 255, 255, 0.5);
}
.tox .tox-collection__item--active .tox-mentions__username,
.tox .tox-collection__item--active .tox-mentions__description {
  color: inherit;
}
.tox {
  /* stylelint-disable */
  /* stylelint-enable */
}
.tox .tox-menu {
  background-color: #2b3b4e;
  border: 1px solid #000000;
  border-radius: 3px;
  box-shadow: 0 4px 8px 0 rgba(42, 55, 70, 0.1);
  display: inline-block;
  overflow: hidden;
  vertical-align: top;
  z-index: 1150;
}
.tox .tox-menu.tox-collection.tox-collection--list {
  padding: 0 0;
}
.tox .tox-menu.tox-collection.tox-collection--toolbar {
  padding: 4px;
}
.tox .tox-menu.tox-collection.tox-collection--grid {
  padding: 4px;
}
@media only screen and (min-width: 768px ) {
  .tox .tox-menu .tox-collection__item-label {
    overflow-wrap: break-word;
    word-break: normal;
  }
  .tox .tox-dialog__popups .tox-menu .tox-collection__item-label {
    word-break: break-all;
  }
}
.tox .tox-menu__label h1,
.tox .tox-menu__label h2,
.tox .tox-menu__label h3,
.tox .tox-menu__label h4,
.tox .tox-menu__label h5,
.tox .tox-menu__label h6,
.tox .tox-menu__label p,
.tox .tox-menu__label blockquote,
.tox .tox-menu__label code {
  margin: 0;
}
.tox .tox-menubar {
  background: url("data:image/svg+xml;charset=utf8,%3Csvg height='39px' viewBox='0 0 40 39px' width='40' xmlns='http://www.w3.org/2000/svg'%3E%3Crect x='0' y='38px' width='100' height='1' fill='%23000000'/%3E%3C/svg%3E") left 0 top 0 #222f3e;
  background-color: #222f3e;
  display: flex;
  flex: 0 0 auto;
  flex-shrink: 0;
  flex-wrap: wrap;
  grid-column: 1 / -1;
  grid-row: 1;
  padding: 0 4px 0 4px;
}
.tox .tox-promotion + .tox-menubar {
  grid-column: 1;
}
.tox .tox-promotion {
  background: url("data:image/svg+xml;charset=utf8,%3Csvg height='39px' viewBox='0 0 40 39px' width='40' xmlns='http://www.w3.org/2000/svg'%3E%3Crect x='0' y='38px' width='100' height='1' fill='%23000000'/%3E%3C/svg%3E") left 0 top 0 #222f3e;
  background-color: #222f3e;
  grid-column: 2;
  grid-row: 1;
  padding-inline-end: 8px;
  padding-inline-start: 4px;
  padding-top: 5px;
}
.tox .tox-promotion-link {
  align-items: unsafe center;
  background-color: #E8F1F8;
  border-radius: 5px;
  color: #086BE6;
  cursor: pointer;
  display: flex;
  font-size: 14px;
  height: 26.6px;
  padding: 4px 8px;
  white-space: nowrap;
}
.tox .tox-promotion-link:hover {
  background-color: #B4D7FF;
}
.tox .tox-promotion-link:focus {
  background-color: #D9EDF7;
}
/* Deprecated. Remove in next major release */
.tox .tox-mbtn {
  align-items: center;
  background: #222f3e;
  border: 0;
  border-radius: 3px;
  box-shadow: none;
  color: #fff;
  display: flex;
  flex: 0 0 auto;
  font-size: 14px;
  font-style: normal;
  font-weight: normal;
  height: 34px;
  justify-content: center;
  margin: 2px 0 3px 0;
  outline: none;
  padding: 0 4px;
  text-transform: none;
  width: auto;
}
.tox .tox-mbtn[disabled] {
  background-color: #222f3e;
  border: 0;
  box-shadow: none;
  color: rgba(255, 255, 255, 0.5);
  cursor: not-allowed;
}
.tox .tox-mbtn:focus:not(:disabled) {
  background: #4a5562;
  border: 0;
  box-shadow: none;
  color: #fff;
  position: relative;
  z-index: 1;
}
.tox .tox-mbtn:focus:not(:disabled)::after {
  pointer-events: none;
  border-radius: 3px;
  bottom: 0;
  box-shadow: 0 0 0 0 transparent ;
  content: '';
  left: 0;
  position: absolute;
  right: 0;
  top: 0;
}
@media (forced-colors: active) {
  .tox .tox-mbtn:focus:not(:disabled)::after {
    border: 2px solid highlight;
  }
}
.tox .tox-mbtn--active,
.tox .tox-mbtn:not(:disabled).tox-mbtn--active:focus {
  background: #757d87;
  border: 0;
  box-shadow: none;
  color: #fff;
}
.tox .tox-mbtn:hover:not(:disabled):not(.tox-mbtn--active) {
  background: #4a5562;
  border: 0;
  box-shadow: none;
  color: #fff;
}
.tox .tox-mbtn__select-label {
  cursor: default;
  font-weight: normal;
  margin: 0 4px;
}
.tox .tox-mbtn[disabled] .tox-mbtn__select-label {
  cursor: not-allowed;
}
.tox .tox-mbtn__select-chevron {
  align-items: center;
  display: flex;
  justify-content: center;
  width: 16px;
  display: none;
}
.tox .tox-notification {
  border-radius: 3px;
  border-style: solid;
  border-width: 1px;
  box-shadow: none;
  box-sizing: border-box;
  display: grid;
  font-size: 14px;
  font-weight: normal;
  grid-template-columns: minmax(40px, 1fr) auto minmax(40px, 1fr);
  margin-left: auto;
  margin-right: auto;
  margin-top: 4px;
  opacity: 0;
  padding: 4px;
  transition: transform 100ms ease-in, opacity 150ms ease-in;
  width: max-content;
}
.tox .tox-notification a {
  cursor: pointer;
  -webkit-text-decoration: underline;
  text-decoration: underline;
}
.tox .tox-notification p {
  font-size: 14px;
  font-weight: normal;
}
.tox .tox-notification:focus {
  border-color: #207ab7;
  box-shadow: none;
}
.tox .tox-notification--in {
  opacity: 1;
}
.tox .tox-notification--success {
  background-color: #334840;
  border-color: #3c5440;
  color: #fff;
}
.tox .tox-notification--success p {
  color: #fff;
}
.tox .tox-notification--success a {
  color: #b5d199;
}
.tox .tox-notification--success a:hover,
.tox .tox-notification--success a:focus {
  color: #82b153;
  -webkit-text-decoration: underline;
  text-decoration: underline;
}
.tox .tox-notification--success a:focus-visible {
  border-radius: 1px;
  outline: 2px solid #b5d199;
  outline-offset: 2px;
}
.tox .tox-notification--success a:active {
  color: #689041;
  -webkit-text-decoration: underline;
  text-decoration: underline;
}
.tox .tox-notification--success svg {
  fill: #fff;
}
.tox .tox-notification--error {
  background-color: #442632;
  border-color: #55212b;
  color: #fff;
}
.tox .tox-notification--error p {
  color: #fff;
}
.tox .tox-notification--error a {
  color: #e68080;
}
.tox .tox-notification--error a:hover,
.tox .tox-notification--error a:focus {
  color: #d42b2b;
  -webkit-text-decoration: underline;
  text-decoration: underline;
}
.tox .tox-notification--error a:focus-visible {
  border-radius: 1px;
  outline: 2px solid #e68080;
  outline-offset: 2px;
}
.tox .tox-notification--error a:active {
  color: #aa2222;
  -webkit-text-decoration: underline;
  text-decoration: underline;
}
.tox .tox-notification--error svg {
  fill: #fff;
}
.tox .tox-notification--warn,
.tox .tox-notification--warning {
  background-color: #222f3e;
  border-color: #000000;
  color: #fff0b3;
}
.tox .tox-notification--warn p,
.tox .tox-notification--warning p {
  color: #fff0b3;
}
.tox .tox-notification--warn a,
.tox .tox-notification--warning a {
  color: #ffcc00;
}
.tox .tox-notification--warn a:hover,
.tox .tox-notification--warning a:hover,
.tox .tox-notification--warn a:focus,
.tox .tox-notification--warning a:focus {
  color: #997a00;
  -webkit-text-decoration: underline;
  text-decoration: underline;
}
.tox .tox-notification--warn a:focus-visible,
.tox .tox-notification--warning a:focus-visible {
  border-radius: 1px;
  outline: 2px solid #ffcc00;
  outline-offset: 2px;
}
.tox .tox-notification--warn a:active,
.tox .tox-notification--warning a:active {
  color: #665200;
  -webkit-text-decoration: underline;
  text-decoration: underline;
}
.tox .tox-notification--warn svg,
.tox .tox-notification--warning svg {
  fill: #fff0b3;
}
.tox .tox-notification--info {
  background-color: #254161;
  border-color: #264972;
  color: #fff;
}
.tox .tox-notification--info p {
  color: #fff;
}
.tox .tox-notification--info a {
  color: #83b7f3;
}
.tox .tox-notification--info a:hover,
.tox .tox-notification--info a:focus {
  color: #2681ea;
  -webkit-text-decoration: underline;
  text-decoration: underline;
}
.tox .tox-notification--info a:focus-visible {
  border-radius: 1px;
  outline: 2px solid #83b7f3;
  outline-offset: 2px;
}
.tox .tox-notification--info a:active {
  color: #1368c9;
  -webkit-text-decoration: underline;
  text-decoration: underline;
}
.tox .tox-notification--info svg {
  fill: #fff;
}
.tox .tox-notification__body {
  align-self: center;
  color: #fff;
  font-size: 14px;
  grid-column-end: 3;
  grid-column-start: 2;
  grid-row-end: 2;
  grid-row-start: 1;
  text-align: center;
  white-space: normal;
  word-break: break-all;
  word-break: break-word;
}
.tox .tox-notification__body > * {
  margin: 0;
}
.tox .tox-notification__body > * + * {
  margin-top: 1rem;
}
.tox .tox-notification__icon {
  align-self: center;
  grid-column-end: 2;
  grid-column-start: 1;
  grid-row-end: 2;
  grid-row-start: 1;
  justify-self: end;
}
.tox .tox-notification__icon svg {
  display: block;
}
.tox .tox-notification__dismiss {
  align-self: start;
  grid-column-end: 4;
  grid-column-start: 3;
  grid-row-end: 2;
  grid-row-start: 1;
  justify-self: end;
}
.tox .tox-notification .tox-progress-bar {
  grid-column-end: 4;
  grid-column-start: 1;
  grid-row-end: 3;
  grid-row-start: 2;
  justify-self: center;
}
.tox .tox-notification-container-dock-fadeout {
  opacity: 0;
  visibility: hidden;
}
.tox .tox-notification-container-dock-fadein {
  opacity: 1;
  visibility: visible;
}
.tox .tox-notification-container-dock-transition {
  transition: visibility 0s linear 0.3s, opacity 0.3s ease;
}
.tox .tox-notification-container-dock-transition.tox-notification-container-dock-fadein {
  transition-delay: 0s;
}
.tox .tox-onboarding-overlay {
  height: 100%;
  background-color: #17202a;
  position: absolute;
  top: 0;
  left: 0;
  right: 0;
  z-index: 1302;
  overflow: auto;
  display: grid;
  justify-content: center;
  align-items: center;
}
.tox .tox-onboarding-dialog {
  max-width: 512px;
  background-color: #222f3e;
  display: flex;
  flex-direction: column;
  box-shadow: 0 16px 16px -10px rgba(42, 55, 70, 0.15), 0 0 40px 1px rgba(42, 55, 70, 0.15);
  border-radius: 12px;
  margin: 8px;
}
.tox .tox-onboarding-dialog .tox-onboarding-header {
  color: #fff;
  display: flex;
  justify-content: center;
  align-items: center;
  font-size: 20px;
  margin: 24px 0 8px;
}
.tox .tox-onboarding-dialog .tox-onboarding-step {
  display: grid;
  grid-template-columns: min-content 1fr min-content;
  align-items: center;
  margin: 0 24px;
}
.tox .tox-onboarding-dialog .tox-onboarding-step:not(:last-child) {
  border-bottom: 1px solid #000000;
}
.tox .tox-onboarding-dialog .tox-onboarding-step--number {
  width: 24px;
  aspect-ratio: 1;
  border-radius: 50%;
  border: 1px solid #00AD0E;
  display: flex;
  justify-content: center;
  align-items: center;
  font-size: 12px;
  font-weight: bold;
  color: #00AD0E;
}
.tox .tox-onboarding-dialog .tox-onboarding-step--body {
  padding: 24px 0 24px 16px;
}
.tox .tox-onboarding-dialog .tox-onboarding-step--body-header {
  color: #fff;
  font-size: 14px;
  font-weight: bold;
  margin-bottom: 4px;
}
.tox .tox-onboarding-dialog .tox-onboarding-step--body-details {
  color: rgba(255, 255, 255, 0.5);
  font-size: 14px;
}
.tox .tox-onboarding-dialog .tox-onboarding-step--action {
  padding-left: 24px;
}
.tox .tox-onboarding-dialog .tox-onboarding-footer {
  background-color: #2b3b4e;
  display: flex;
  justify-content: space-between;
  align-items: center;
  padding: 16px 24px;
  border-bottom-left-radius: 12px;
  border-bottom-right-radius: 12px;
}
.tox .tox-onboarding-dialog .tox-onboarding-footer p {
  display: flex;
  align-items: center;
  justify-content: center;
  gap: 4px;
  font-size: 14px;
  color: rgba(255, 255, 255, 0.5);
}
.tox .tox-onboarding-dialog svg {
  width: 24px;
  fill: rgba(255, 255, 255, 0.5);
}
.tox .tox-promotion-dialog .tox-promotion-dialog-plugin {
  display: grid;
  align-items: center;
  grid-template-columns: min-content 1fr min-content;
  border-bottom: 1px solid #000000;
  padding: 24px 0;
  margin: 0 16px;
}
.tox .tox-promotion-dialog .tox-promotion-dialog-plugin--body {
  margin: 0 16px;
}
.tox .tox-promotion-dialog .tox-promotion-dialog-plugin--body .tox-promotion-dialog-plugin-header {
  color: #fff;
  font-size: 14px;
  font-weight: bold;
  margin-bottom: 4px;
}
.tox .tox-promotion-dialog .tox-promotion-dialog-plugin--body .tox-promotion-dialog-plugin-details {
  color: rgba(255, 255, 255, 0.5);
  font-size: 14px;
}
.tox .tox-promotion-dialog .tox-promotion-dialog-plugin--icon {
  display: grid;
  place-content: center;
  width: 56px;
  height: 56px;
  line-height: 24px;
  font-size: 24px;
  border-radius: 12px;
  background: linear-gradient(180deg, #2b3b4e 24%, #202d3b 100%);
  box-shadow: 0px 1px 1px 0px #222f3e12, 0px 3px 6px 0px #222f3e06;
  color: #207ab7;
}
.tox .tox-promotion-dialog--subtitle {
  margin: 16px;
  color: rgba(255, 255, 255, 0.5);
  font-size: 14px;
}
.tox .tox-promotion-dialog--explore {
  text-align: center;
  margin: 16px;
  color: rgba(255, 255, 255, 0.5);
  font-size: 14px;
}
.tox .tox-promotion-dialog--explore a {
  color: #207ab7;
}
.tox .tox-promotion-dialog--footer {
  background-color: #17202a;
  color: rgba(255, 255, 255, 0.5);
  font-size: 12px;
  text-align: center;
  padding: 16px;
}
.tox .tox-promotion-button {
  display: flex;
  align-items: center;
  height: 26.6px;
  line-height: 26.6px;
  font-size: 14px;
  font-weight: bold;
  background-color: #55367A;
  color: #C290FB;
  padding: 8px 16px;
  cursor: pointer;
  white-space: nowrap;
  border-radius: 5px;
}
.tox .tox-promotion-button:focus {
  outline: 1px solid #C290FB;
}
.tox .tox-onboarding-dialog a,
.tox .tox-promotion-dialog--footer a {
  color: rgba(255, 255, 255, 0.5);
  cursor: pointer;
  -webkit-text-decoration: underline;
  text-decoration: underline;
}
.tox .tox-onboarding-dialog a:hover,
.tox .tox-promotion-dialog--footer a:hover,
.tox .tox-onboarding-dialog a:focus,
.tox .tox-promotion-dialog--footer a:focus {
  color: #428fc2;
  -webkit-text-decoration: underline;
  text-decoration: underline;
}
.tox .tox-onboarding-dialog a:focus-visible,
.tox .tox-promotion-dialog--footer a:focus-visible {
  border-radius: 1px;
  outline: 2px solid #90bddb;
  outline-offset: 2px;
}
.tox .tox-onboarding-dialog a:active,
.tox .tox-promotion-dialog--footer a:active {
  color: #33739e;
  -webkit-text-decoration: underline;
  text-decoration: underline;
}
.tox .tox-pop {
  display: inline-block;
  position: relative;
}
.tox .tox-pop--resizing {
  transition: width 0.1s ease;
}
.tox .tox-pop--resizing .tox-toolbar,
.tox .tox-pop--resizing .tox-toolbar__group {
  flex-wrap: nowrap;
}
.tox .tox-pop--transition {
  transition: 0.15s ease;
  transition-property: left, right, top, bottom;
}
.tox .tox-pop--transition::before,
.tox .tox-pop--transition::after {
  transition: all 0.15s, visibility 0s, opacity 0.075s ease 0.075s;
}
.tox .tox-pop__dialog {
  background-color: #222f3e;
  border: 1px solid #000000;
  border-radius: 3px;
  box-shadow: 0 0 2px 0 rgba(42, 55, 70, 0.2), 0 4px 8px 0 rgba(42, 55, 70, 0.15);
  min-width: 0;
  overflow: hidden;
}
.tox .tox-pop__dialog > *:not(.tox-toolbar) {
  margin: 4px 4px 4px 8px;
}
.tox .tox-pop__dialog .tox-toolbar {
  background-color: transparent;
  margin-bottom: -1px;
}
.tox .tox-pop::before,
.tox .tox-pop::after {
  border-style: solid;
  content: '';
  display: block;
  height: 0;
  opacity: 1;
  position: absolute;
  width: 0;
}
@media (forced-colors: active) {
  .tox .tox-pop::before,
  .tox .tox-pop::after {
    content: none;
  }
}
.tox .tox-pop.tox-pop--inset::before,
.tox .tox-pop.tox-pop--inset::after {
  opacity: 0;
  transition: all 0s 0.15s, visibility 0s, opacity 0.075s ease;
}
.tox .tox-pop.tox-pop--bottom::before,
.tox .tox-pop.tox-pop--bottom::after {
  left: 50%;
  top: 100%;
}
.tox .tox-pop.tox-pop--bottom::after {
  border-color: #222f3e transparent transparent transparent;
  border-width: 8px;
  margin-left: -8px;
  margin-top: -1px;
}
.tox .tox-pop.tox-pop--bottom::before {
  border-color: #000000 transparent transparent transparent;
  border-width: 9px;
  margin-left: -9px;
}
.tox .tox-pop.tox-pop--top::before,
.tox .tox-pop.tox-pop--top::after {
  left: 50%;
  top: 0;
  transform: translateY(-100%);
}
.tox .tox-pop.tox-pop--top::after {
  border-color: transparent transparent #222f3e transparent;
  border-width: 8px;
  margin-left: -8px;
  margin-top: 1px;
}
.tox .tox-pop.tox-pop--top::before {
  border-color: transparent transparent #000000 transparent;
  border-width: 9px;
  margin-left: -9px;
}
.tox .tox-pop.tox-pop--left::before,
.tox .tox-pop.tox-pop--left::after {
  left: 0;
  top: calc(50% - 1px);
  transform: translateY(-50%);
}
.tox .tox-pop.tox-pop--left::after {
  border-color: transparent #222f3e transparent transparent;
  border-width: 8px;
  margin-left: -15px;
}
.tox .tox-pop.tox-pop--left::before {
  border-color: transparent #000000 transparent transparent;
  border-width: 10px;
  margin-left: -19px;
}
.tox .tox-pop.tox-pop--right::before,
.tox .tox-pop.tox-pop--right::after {
  left: 100%;
  top: calc(50% + 1px);
  transform: translateY(-50%);
}
.tox .tox-pop.tox-pop--right::after {
  border-color: transparent transparent transparent #222f3e;
  border-width: 8px;
  margin-left: -1px;
}
.tox .tox-pop.tox-pop--right::before {
  border-color: transparent transparent transparent #000000;
  border-width: 10px;
  margin-left: -1px;
}
.tox .tox-pop.tox-pop--align-left::before,
.tox .tox-pop.tox-pop--align-left::after {
  left: 20px;
}
.tox .tox-pop.tox-pop--align-right::before,
.tox .tox-pop.tox-pop--align-right::after {
  left: calc(100% - 20px);
}
.tox .tox-sidebar-wrap {
  display: flex;
  flex-direction: row;
  flex-grow: 1;
  min-height: 0;
}
.tox .tox-sidebar {
  background-color: var(--tox-private-sidebar-background-color, #34485f);
  display: flex;
  flex-direction: row;
  justify-content: flex-end;
}
.tox .tox-sidebar__slider {
  display: flex;
  overflow: hidden;
}
.tox .tox-sidebar__pane-container {
  display: flex;
}
.tox .tox-sidebar__pane {
  display: flex;
}
.tox .tox-sidebar--sliding-closed {
  opacity: 0;
}
.tox .tox-sidebar--sliding-open {
  opacity: 1;
}
.tox .tox-sidebar--sliding-growing,
.tox .tox-sidebar--sliding-shrinking {
  transition: width 0.5s ease, opacity 0.5s ease;
}
.tox .tox-sidebar-content {
  display: flex;
  flex-direction: column;
  position: relative;
  height: 100%;
  min-width: 300px;
  max-width: 300px;
  width: 300px;
  border-left: 1px solid var(--tox-private-separator-color, #000000);
}
.tox .tox-sidebar-content--wide {
  min-width: 440px;
  max-width: 440px;
  width: 440px;
}
.tox .tox-sidebar-content__header {
  align-items: center;
  display: flex;
  justify-content: space-between;
  border-bottom: var(--tox-private-tinymceai-border-width, 1px) solid var(--tox-private-neutral-20, #0e141a);
  padding: var(--tox-private-pad-sm, 8px) 12px;
  background: var(--tox-private-background-color, #222f3e);
  z-index: 1;
}
.tox .tox-sidebar-content__header .tox-sidebar-content__header-close-button {
  margin-left: auto;
}
.tox .tox-sidebar-content__title {
  font-size: var(--tox-private-font-size-lg, 20px);
  font-weight: var(--tox-private-font-weight-normal, normal);
  padding: var(--tox-private-pad-sm, 8px) 0 var(--tox-private-pad-sm, 8px) 0;
  color: var(--tox-private-text-color, #fff);
  line-height: 28px;
}
.tox .tox-floating-sidebar {
  --tox-private-floating-sidebar-width: min(380px, 90vw);
  --tox-private-floating-sidebar-height: 80vh;
  position: fixed;
  z-index: var(--tox-private-z-index-floatingsidebar, 1050);
  box-shadow: var(--tox-private-floating-sidebar-box-shadow, 0 0 40px 1px rgba(42, 55, 70, 0.15), 0 16px 16px -10px rgba(42, 55, 70, 0.15));
  width: var(--tox-private-floating-sidebar-width);
  height: var(--tox-private-floating-sidebar-height);
  background-color: var(--tox-private-floating-sidebar-background-color, #34485f);
  border-radius: var(--tox-private-panel-border-radius, 3px);
  overflow: hidden;
}
.tox .tox-floating-sidebar:not(.tox .tox-floating-sidebar--open) {
  display: none;
}
.tox .tox-floating-sidebar--open {
  display: block;
}
.tox .tox-floating-sidebar__content-wrapper {
  width: 100%;
  height: 100%;
  display: flex;
  flex-direction: column;
}
.tox .tox-floating-sidebar__header {
  position: relative;
}
.tox .tox-floating-sidebar .tox-ai__scroll:has(.tox-card-list) {
  background-color: inherit;
}
.tox .tox-ai .tox-expandable-box {
  padding: var(--tox-private-pad-sm, 8px) calc(var(--tox-private-pad-md, 16px) * 0.75);
}
.tox .tox-ai .tox-expandable-box:focus-visible:not(:disabled) {
  outline: 2px solid var(--tox-private-color-tint, #207ab7);
  outline-offset: var(--tox-private-tinymceai-border-width, 1px);
  box-shadow: 0 0 0 1px var(--tox-private-color-white, #fff);
  border-radius: var(--tox-private-control-border-radius, 3px);
}
.tox .tox-ai .tox-sidebar-content__header {
  border: var(--tox-private-tinymceai-focus-border-width, 2px) solid var(--tox-private-background-color, #222f3e);
  padding: calc(var(--tox-private-pad-sm, 8px) - var(--tox-private-tinymceai-focus-border-width, 2px)) calc(12px - var(--tox-private-tinymceai-focus-border-width, 2px));
  border-bottom: 1px solid var(--tox-private-separator-color, #000000);
}
.tox .tox-ai .tox-sidebar-content__header:focus-visible:not(:disabled) {
  border: var(--tox-private-tinymceai-focus-border-width, 2px) solid var(--tox-private-color-tint, #207ab7);
  border-radius: var(--tox-private-control-border-radius, 3px);
}
.tox .tox-ai .tox-sidebar-content__loader {
  align-items: center;
  display: flex;
  height: 100%;
  justify-content: center;
  width: 100%;
  z-index: 1000;
}
.tox .tox-ai .tox-sidebar-content__title {
  text-overflow: ellipsis;
  overflow: hidden;
  white-space: nowrap;
  margin-right: auto;
}
.tox .tox-ai .tox-sidebar-content__title:focus-visible:not(:disabled) {
  outline: 2px solid var(--tox-private-color-tint, #207ab7);
  outline-offset: var(--tox-private-tinymceai-border-width, 1px);
  box-shadow: 0 0 0 1px var(--tox-private-color-white, #fff);
  border-radius: var(--tox-private-control-border-radius, 3px);
}
.tox .tox-ai .tox-sidebar-content__actions {
  display: flex;
  gap: var(--tox-private-pad-sm, 8px);
}
.tox .tox-ai .tox-sidebar-content__actions .tox-ai__complete-review {
  display: flex;
  align-items: center;
  gap: 6px;
  padding-top: var(--tox-private-pad-xs, 4px);
  padding-bottom: var(--tox-private-pad-xs, 4px);
  padding-left: var(--tox-private-pad-md, 16px);
  padding-right: var(--tox-private-pad-md, 16px);
}
.tox .tox-ai .tox-sidebar-content__actions .tox-ai__review-menu-separator {
  border-bottom: 1px solid #1a1a1a;
  height: 0;
  margin: 4px 0;
}
.tox .tox-ai .tox-ai__user-prompt {
  display: flex;
  flex-direction: column;
  margin-left: auto;
  gap: inherit;
  width: 100%;
}
.tox .tox-ai .tox-ai__user-prompt__context {
  margin-left: auto;
  display: flex;
  flex-direction: column;
  gap: inherit;
  align-items: end;
  width: 100%;
}
.tox .tox-ai .tox-ai__user-prompt__context .tox-tag {
  max-width: 100%;
}
.tox .tox-ai .tox-ai__user-prompt__text {
  background-color: var(--tox-private-background-secondary, #2f4055);
  padding: var(--tox-private-pad-sm, 8px) calc(var(--tox-private-pad-md, 16px) * 0.75);
  border-radius: var(--tox-private-control-border-radius, 3px);
  max-width: 80%;
  align-self: flex-end;
  color: var(--tox-private-text-color, #fff);
}
.tox .tox-ai .tox-ai__user-prompt__text:focus-visible:not(:disabled) {
  outline: 2px solid var(--tox-private-color-tint, #207ab7);
  outline-offset: var(--tox-private-tinymceai-border-width, 1px);
  box-shadow: 0 0 0 1px var(--tox-private-color-white, #fff);
  border-radius: var(--tox-private-control-border-radius, 3px);
}
.tox .tox-ai .tox-ai__scroll {
  overflow-y: auto;
  overflow-x: hidden;
  background-color: var(--tox-private-background-color, #222f3e);
  display: flex;
  padding: calc(12px - var(--tox-private-tinymceai-focus-border-width, 2px));
  flex-direction: column;
  align-items: flex-start;
  gap: 12px;
  flex: 1 0 0;
  align-self: stretch;
  border: var(--tox-private-tinymceai-focus-border-width, 2px) solid var(--tox-private-background-color, #222f3e);
}
.tox .tox-ai .tox-ai__scroll:focus-visible:not(:disabled) {
  border: var(--tox-private-tinymceai-focus-border-width, 2px) solid var(--tox-private-color-tint, #207ab7);
  border-radius: var(--tox-private-control-border-radius, 3px);
}
.tox .tox-ai .tox-ai__scroll--review {
  border: none;
}
.tox .tox-ai .tox-ai__scroll--review:not(:has(.tox-sidebar-content__message-text)) {
  background-color: var(--tox-private-background-secondary, #2f4055);
}
.tox .tox-ai .tox-ai__spinner svg {
  fill: var(--tox-private-color-tint, #207ab7);
}
.tox .tox-ai .tox-ai__response {
  width: 100%;
  min-width: 100%;
  max-width: 100%;
}
.tox .tox-ai .tox-ai__response__header {
  display: flex;
  align-items: center;
  gap: var(--tox-private-pad-sm, 8px);
}
.tox .tox-ai .tox-ai__response__header .tox-icon svg {
  fill: var(--tox-private-color-tint, #207ab7);
}
.tox .tox-ai .tox-ai__response-status {
  display: flex;
  color: var(--tox-private-text-color-muted, rgba(255, 255, 255, 0.5));
  font-size: var(--tox-private-font-size-sm, 14px);
  gap: var(--tox-private-pad-xs, 4px);
  line-height: var(--tox-private-tinymceai-response-status-icon-height, max(24px, calc(14px + 4px)));
  padding-top: var(--tox-private-pad-sm, 8px);
}
.tox .tox-ai .tox-ai__response-status svg {
  fill: var(--tox-private-text-color-muted, rgba(255, 255, 255, 0.5));
}
.tox .tox-ai .tox-ai__response-status-icon {
  border-radius: 999px;
  border: 1px solid var(--tox-private-neutral-20, #0e141a);
  background-color: var(--tox-private-background-color, #222f3e);
  height: var(--tox-private-tinymceai-response-status-icon-height, max(24px, calc(14px + 4px)));
  flex: 0 0 24px;
  display: flex;
  align-items: center;
  justify-content: center;
}
.tox .tox-ai .tox-ai__response-status-icon .tox-icon {
  display: contents;
}
.tox .tox-ai :nth-child(2 of .tox-ai__response-status-icon) {
  margin-left: calc((var(--tox-private-pad-sm, 8px) + var(--tox-private-pad-xs, 4px)) * -1);
}
.tox .tox-ai .tox-ai__icon {
  display: flex;
  align-items: center;
  justify-content: center;
}
.tox .tox-ai .tox-ai__response-sources {
  display: flex;
  flex-direction: column;
  gap: var(--tox-private-pad-sm, 8px);
}
.tox .tox-ai .tox-ai__response-sources-header {
  display: block;
}
.tox .tox-ai .tox-ai__response-sources-list {
  display: flex;
  align-items: center;
  gap: var(--tox-private-pad-sm, 8px);
  align-self: stretch;
  flex-wrap: wrap;
}
.tox .tox-ai .tox-ai__response-sources-list .tox-tag {
  border: 1px solid var(--tox-private-separator-color, #000000);
  background-color: transparent;
  max-width: 32%;
  max-height: 24px;
  cursor: pointer;
}
.tox .tox-ai .tox-ai__response-sources-list .tox-tag svg,
.tox .tox-ai .tox-ai__response-sources-list .tox-tag img {
  width: 16px;
  height: 16px;
  min-width: 16px;
  min-height: 16px;
  max-width: 16px;
  max-height: 16px;
}
.tox .tox-ai .tox-ai__response-content {
  padding: var(--tox-private-pad-sm, 8px) 0;
  color: var(--tox-private-text-color, #fff);
  font-feature-settings: 'liga' off, 'clig' off;
  font-size: var(--tox-private-font-size-sm, 14px);
  font-style: normal;
  font-weight: var(--tox-private-font-weight-normal, normal);
  line-height: var(--tox-private-line-height, 18px);
}
.tox .tox-ai .tox-ai__response.tox-ai__response-streaming {
  position: relative;
}
.tox .tox-ai .tox-ai__response.tox-ai__response-streaming .tox-ai__response-status {
  color: var(--tox-private-text-color, #fff);
  font-size: var(--tox-private-font-size-md, 16px);
  line-height: calc(var(--tox-private-font-size-md, 16px) + 4px);
}
.tox .tox-ai .tox-ai__response.tox-ai__response-streaming::after {
  content: '';
  position: absolute;
  bottom: 0;
  left: 0;
  right: 0;
  height: min(100px, 100%);
  pointer-events: none;
  background: linear-gradient(to bottom, transparent 60px, transparent 60px, var(--tox-private-background-color, #222f3e));
}
.tox .tox-ai .tox-ai-error {
  border-radius: var(--tox-private-panel-border-radius, 3px);
  border: 1px solid var(--tox-private-color-error, #c00);
  background: linear-gradient(0deg, rgba(from var(--tox-private-background-color, #222f3e) r g b / 0.9) 0%, rgba(from var(--tox-private-background-color, #222f3e) r g b / 0.9) 100%), var(--tox-private-color-error, #c00);
  padding: var(--tox-private-pad-sm, 8px);
  width: 100%;
  display: flex;
  gap: var(--tox-private-pad-sm, 8px);
  align-items: center;
}
.tox .tox-ai .tox-ai-error__message {
  flex: 1 0 0;
}
.tox .tox-ai .tox-ai-error__icon {
  flex: 0 0 auto;
  align-self: flex-start;
}
.tox .tox-ai .tox-ai__footer {
  padding: calc(12px - var(--tox-private-tinymceai-focus-border-width, 2px));
  gap: var(--tox-private-pad-sm, 8px);
  background-color: var(--tox-private-background-color, #222f3e);
  display: flex;
  flex-direction: column;
  border: var(--tox-private-tinymceai-focus-border-width, 2px) solid var(--tox-private-background-color, #222f3e);
  border-top: 1px solid var(--tox-private-separator-color, #000000);
}
.tox .tox-ai .tox-ai__footer:focus-visible:not(:disabled) {
  border: var(--tox-private-tinymceai-focus-border-width, 2px) solid var(--tox-private-color-tint, #207ab7);
  border-radius: var(--tox-private-control-border-radius, 3px);
}
.tox .tox-ai .tox-ai__context {
  display: flex;
  gap: var(--tox-private-pad-sm, 8px);
  flex-wrap: wrap;
  max-height: calc((2 * (2 * var(--tox-private-pad-xs, 4px) + var(--tox-private-base-value, 16px))) + var(--tox-private-pad-sm, 8px));
}
.tox .tox-ai .tox-ai__context .tox-tag {
  /* Maximum width of tag is half the size of sidebar */
  max-width: calc((100% - var(--tox-private-pad-sm, 8px)) / 2);
}
.tox .tox-ai .tox-ai__context-more {
  display: flex;
  flex-direction: column;
  gap: var(--tox-private-pad-sm, 8px);
  padding: var(--tox-private-pad-sm, 8px);
  overflow: auto;
  max-width: var(--tox-private-tinymceai-context-more-max-width, 320px);
}
.tox .tox-ai .tox-ai__context-more .tox-tag {
  max-width: 100%;
}
.tox .tox-ai .tox-ai__stop-generating {
  display: flex;
  align-items: center;
  gap: 6px;
}
.tox .tox-ai .tox-ai__footer-actions {
  display: flex;
  gap: var(--tox-private-pad-sm, 8px);
}
.tox .tox-ai .tox-ai-model-selection-button {
  display: flex;
  gap: var(--tox-private-pad-xs, 4px);
}
.tox .tox-ai .tox-ai__footer-note {
  align-items: center;
  color: var(--tox-private-text-color-muted, rgba(255, 255, 255, 0.5));
  display: flex;
  font-size: var(--tox-private-font-size-xs, 12px);
  height: 24px;
  justify-content: center;
  letter-spacing: 0px;
  padding-top: var(--tox-private-pad-sm, 8px);
  width: 100%;
}
.tox .tox-ai .tox-ai__models-menu {
  max-width: 350px;
}
.tox .tox-ai .tox-ai__models-menu .tox-menu {
  max-height: inherit;
  overflow: auto;
  padding: var(--tox-private-pad-xs, 4px);
}
.tox .tox-ai .tox-ai__models-menu__item__description {
  display: flex;
  flex-direction: column;
  align-items: start;
}
.tox .tox-ai .tox-ai__models-menu__item__description__title {
  font-weight: var(--tox-private-font-weight-bold, bold);
  font-size: var(--tox-private-font-size-sm, 14px);
  line-height: calc(var(--tox-private-font-size-sm, 14px) * 1.28572);
  padding-bottom: 4px;
}
.tox .tox-ai .tox-ai__models-menu__item__description__content {
  color: var(--tox-private-text-color-muted, rgba(255, 255, 255, 0.5));
  font-size: var(--tox-private-font-size-xs, 12px);
  line-height: calc(var(--tox-private-font-size-xs, 12px) * 1.33333);
}
.tox .tox-ai .tox-collection__item--active:not(.tox-collection__item--state-disabled) .tox-ai__models-menu__item__description__content {
  color: inherit;
}
.tox .tox-ai .tox-collection__item--active:not(.tox-collection__item--state-disabled) .tox-ai__models-menu__item__description__content .tox-ai__models-menu__item__description__ability {
  color: var(--tox-private-color-white, #fff);
}
.tox .tox-ai .tox-collection__item--active:not(.tox-collection__item--state-disabled) .tox-ai__models-menu__item__description__content .tox-ai__models-menu__item__description__content_body {
  color: rgba(from var(--tox-private-color-white, #fff) r g b / 0.7);
}
.tox .tox-ai .tox-ai__models-menu__item__description__ability {
  color: var(--tox-private-text-color, #fff);
  padding-bottom: 4px;
}
.tox .tox-ai .tox-ai__models-menu__item__description__ability__enabled {
  font-weight: var(--tox-private-font-weight-bold, bold);
}
.tox .tox-ai .tox-ai-chat-history-list {
  display: flex;
  flex-direction: column;
  gap: var(--tox-private-pad-sm, 8px);
  padding-top: var(--tox-private-pad-xs, 4px);
  width: 100%;
}
.tox .tox-ai .tox-ai-chat-history-list .tox-collection__group {
  gap: var(--tox-private-pad-sm, 8px);
}
.tox .tox-ai .tox-ai-chat-history-list__title {
  color: var(--tox-private-text-color-muted, rgba(255, 255, 255, 0.5));
  font-size: var(--tox-private-font-size-sm, 14px);
  font-weight: var(--tox-private-font-weight-bold, bold);
  line-height: 18px;
  letter-spacing: 1px;
}
.tox .tox-ai .tox-ai-chat-history-list__item {
  display: flex;
  padding: 12px;
  gap: var(--tox-private-pad-sm, 8px);
  border-radius: var(--tox-private-control-border-radius, 3px);
  cursor: pointer;
}
.tox .tox-ai .tox-ai-chat-history-list__item.tox-ai-chat-history-list__item--active {
  background-color: var(--tox-private-background-secondary, #2f4055);
}
.tox .tox-ai .tox-ai-chat-history-list__item:focus,
.tox .tox-ai .tox-ai-chat-history-list__item:focus-visible {
  background-color: var(--tox-private-background-secondary, #2f4055);
}
.tox .tox-ai .tox-ai-chat-history-list__item.tox-ai-chat-history-list__item-edit-title {
  background-color: var(--tox-private-background-secondary, #2f4055);
  flex-direction: column;
}
.tox .tox-ai .tox-ai-chat-history-list__item-edit-actions {
  display: flex;
  justify-content: flex-end;
  width: 100%;
  gap: var(--tox-private-pad-sm, 8px);
}
.tox .tox-ai .tox-ai-chat-history-list__item-edit-actions .tox-ai__spinner svg {
  fill: rgba(from var(--tox-private-color-white, #fff) r g b / 0.5);
}
.tox .tox-ai .tox-ai-chat-history-list__item-content {
  display: flex;
  flex-direction: column;
  margin-right: auto;
  overflow: hidden;
}
.tox .tox-ai .tox-ai-chat-history-list__item-actions {
  display: flex;
  align-items: center;
  min-width: calc(24px + (var(--tox-private-pad-xs, 4px) + 1px)*2);
}
.tox .tox-ai .tox-ai-chat-history-list__item-content-title {
  color: var(--tox-private-text-color, #fff);
  font-size: var(--tox-private-font-size-base, 16px);
  font-weight: var(--tox-private-font-weight-bold, bold);
  line-height: var(--tox-private-font-size-lg, 20px);
  overflow: hidden;
  text-overflow: ellipsis;
}
.tox .tox-ai .tox-ai-chat-history-list__item-content-date {
  color: var(--tox-private-text-color, #fff);
  font-size: var(--tox-private-font-size-xs, 12px);
  line-height: var(--tox-private-line-height-base, 1.3);
}
.tox .tox-ai .tox-sidebar-content__message {
  align-items: center;
  display: flex;
  flex-direction: column;
  height: 100%;
  justify-content: center;
  gap: var(--tox-private-pad-md, 16px);
  width: 100%;
}
.tox .tox-ai .tox-sidebar-content__message-text {
  text-align: center;
  color: var(--tox-private-text-color, #fff);
  font-size: var(--tox-private-font-size-md, 16px);
  font-weight: var(--tox-private-font-weight-normal, normal);
  line-height: 20px;
}
.tox .tox-ai .tox-sidebar-content__message-action {
  display: flex;
  justify-content: center;
  align-items: center;
  align-self: stretch;
}
.tox .tox-ai-removed-content {
  font-style: italic;
  font-family: var(--tox-private-font-stack, -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Oxygen-Sans, Ubuntu, Cantarell, "Helvetica Neue", sans-serif);
  background-color: var(--tox-private-background-color, #222f3e);
  color: var(--tox-private-text-color-muted, rgba(255, 255, 255, 0.5));
  line-height: var(--tox-private-line-height-base, 1.3);
  margin: 0 1em;
}
.tox .tox-ai-removed-content::before {
  content: "⊘ ";
  font-style: normal;
  font-size: calc(var(--tox-private-line-height-base, 1.3) * 1em);
}
.tox .tox-ai-html-content {
  font-size: var(--tox-private-font-size-md, 16px);
  font-family: var(--tox-private-font-stack, -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Oxygen-Sans, Ubuntu, Cantarell, "Helvetica Neue", sans-serif);
  background-color: var(--tox-private-background-color, #222f3e);
  color: var(--tox-private-text-color, #fff);
  line-height: var(--tox-private-line-height-base, 1.3);
  overflow-x: auto;
  /* Headings */
  /* Paragraphs */
  /* Lists */
  /* Links */
  /* Blockquote */
  /* Inline code */
  /* Code block */
  /* Horizontal rule */
  /* Tables */
  /* --- Inline Markdown Elements --- */
  /* Bold */
  /* Italic */
  /* Strikethrough */
  /* Subscript / Superscript */
  /* Highlight text */
  /* Small text */
  /* Keyboard input */
  /* Images */
}
.tox .tox-ai-html-content:focus-visible:not(:disabled) {
  outline: 2px solid var(--tox-private-color-tint, #207ab7);
  outline-offset: var(--tox-private-tinymceai-html-content-border-width, 1px);
  box-shadow: 0 0 0 1px var(--tox-private-color-white, #fff);
  border-radius: var(--tox-private-control-border-radius, 3px);
}
.tox .tox-ai-html-content h1 {
  font-size: 1.6em;
  font-weight: var(--tox-private-font-weight-bold, bold);
  margin: 0.67em 0;
}
.tox .tox-ai-html-content h2 {
  font-size: 1.4em;
  font-weight: var(--tox-private-font-weight-bold, bold);
  margin: 0.83em 0;
}
.tox .tox-ai-html-content h3 {
  font-size: 1.2em;
  font-weight: var(--tox-private-font-weight-bold, bold);
  margin: 1em 0;
}
.tox .tox-ai-html-content h4,
.tox .tox-ai-html-content h5,
.tox .tox-ai-html-content h6 {
  font-size: 1em;
  font-weight: var(--tox-private-font-weight-bold, bold);
  margin: 0.33em 0;
}
.tox .tox-ai-html-content p {
  margin: var(--tox-private-pad-sm, 8px) 0;
}
.tox .tox-ai-html-content ul,
.tox .tox-ai-html-content ol {
  padding-left: 2em;
  margin: 1em 0;
}
.tox .tox-ai-html-content li:has(input:first-child) {
  list-style-type: none;
}
.tox .tox-ai-html-content a {
  color: var(--tox-private-color-tint, #207ab7);
  -webkit-text-decoration: underline;
  text-decoration: underline;
  cursor: pointer;
}
.tox .tox-ai-html-content a:link:active,
.tox .tox-ai-html-content a:visited:active {
  color: #8864ad;
}
.tox .tox-ai-html-content blockquote {
  border-left: 2px solid var(--tox-private-separator-color, #000000);
  margin-left: 1.5rem;
  padding-left: 1rem;
  font-style: italic;
}
.tox .tox-ai-html-content code {
  font-family: ui-monospace, monospace;
  background: var(--tox-private-separator-color, #000000);
  padding: 0.1em 0.2em;
  border-radius: 4px;
}
.tox .tox-ai-html-content pre code {
  display: block;
  font-family: ui-monospace, monospace;
  background: var(--tox-private-separator-color, #000000);
  border-radius: 4px;
  white-space: pre-wrap;
  margin: 1em 0;
  overflow-wrap: break-word;
}
.tox .tox-ai-html-content hr {
  border: none;
  border-top: 1px solid var(--tox-private-border-color, #000000);
}
.tox .tox-ai-html-content table {
  width: 100%;
  border-collapse: collapse;
  margin: 0.5em 0;
  font-size: 0.95em;
  line-height: 1.45;
}
.tox .tox-ai-html-content table:not([cellpadding]) th,
.tox .tox-ai-html-content table:not([cellpadding]) td {
  padding: 0.4rem;
}
.tox .tox-ai-html-content th,
.tox .tox-ai-html-content td {
  border: 1px solid var(--tox-private-border-color, #000000);
}
.tox .tox-ai-html-content th {
  font-weight: var(--tox-private-font-weight-bold, bold);
  text-align: left;
  white-space: nowrap;
}
.tox .tox-ai-html-content strong,
.tox .tox-ai-html-content b {
  font-weight: var(--tox-private-font-weight-bold, bold);
}
.tox .tox-ai-html-content em,
.tox .tox-ai-html-content i {
  font-style: italic;
}
.tox .tox-ai-html-content del {
  -webkit-text-decoration: line-through;
  text-decoration: line-through;
}
.tox .tox-ai-html-content sup,
.tox .tox-ai-html-content sub {
  font-size: 0.75em;
  line-height: 0;
  vertical-align: baseline;
}
.tox .tox-ai-html-content sup {
  vertical-align: super;
}
.tox .tox-ai-html-content sub {
  vertical-align: sub;
}
.tox .tox-ai-html-content mark {
  background: hsl(from var(--tox-private-color-active, #ffcf30) h s l / 30%);
  padding: 0.05em 0.2em;
  border-radius: 2px;
}
.tox .tox-ai-html-content small {
  font-size: 0.85em;
}
.tox .tox-ai-html-content kbd {
  font-family: ui-monospace, monospace;
  font-size: 0.85em;
  padding: 0.15em 0.4em;
  border-radius: 4px;
  border: 1px solid var(--tox-private-border-color, #000000);
  background: var(--tox-private-separator-color, #000000);
  box-shadow: inset 0 -1px 0 var(--tox-private-border-color, #000000);
}
.tox .tox-ai-html-content img {
  max-width: 100%;
  height: auto;
  vertical-align: middle;
  border-radius: 4px;
}
/* Adding margin to .tox-ai-html-content inside the expandable content */
.tox .tox-expandable-box__content {
  /* separator between sections */
}
.tox .tox-expandable-box__content .tox-ai-html-content + .tox-ai-html-content::before,
.tox .tox-expandable-box__content .tox-ai-removed-content + .tox-ai-html-content::before,
.tox .tox-expandable-box__content .tox-ai-html-content:has(+ .tox-ai-removed-content)::after {
  content: "〰〰";
  color: var(--tox-private-text-color-muted, rgba(255, 255, 255, 0.5));
  text-align: center;
  width: 100%;
  display: block;
}
.tox .tox-ai__preview-host {
  width: 100%;
  height: 100%;
  position: relative;
}
.tox .tox-ai__preview-host .tox-ai__preview-layer {
  position: absolute;
  inset: 0;
  display: flex;
  flex-direction: column;
}
.tox .tox-ai__preview-host .tox-ai__preview-frame-wrap {
  position: relative;
  flex: 1 1 auto;
  min-height: 0;
}
.tox .tox-ai__preview-host .tox-ai__preview-frame-wrap .tox-ai__iframe {
  background-color: #fff;
  border: 0;
  width: 100%;
  height: 100%;
  min-height: 0;
  position: relative;
}
.tox .tox-ai__preview-host .tox-ai__preview-footer {
  flex: 0 0 auto;
  background: var(--tox-private-background-color, #222f3e);
  border-top: 1px solid #364a62;
}
.tox .tox-ai__preview-host .tox-ai__preview-footer .tox-ai__preview-footer-toolbar {
  display: flex;
  justify-content: flex-end;
  gap: 8px;
  padding: 12px 16px;
}
.tox .tox-ai__preview-host:empty {
  pointer-events: none;
}
.tox .tox-ai__preview-overlay {
  position: absolute;
  inset: 0;
  width: 100%;
  height: 100%;
}
.tox .tox-ai__preview-overlay--hidden {
  visibility: hidden;
}
.tox .tox-ai__preview-overlay--pass-through {
  pointer-events: none;
}
.tox .tox-ai__preview-overlay--dim {
  background: rgba(42, 55, 70, 0.2);
}
.tox .tox-ai__preview-overlay--centered {
  display: flex;
  align-items: center;
  justify-content: center;
}
.tox .tox-ai__preview-overlay--clipped {
  overflow: clip;
}
.tox .tox-tinymceai-previewloader {
  display: flex;
  align-items: center;
  gap: var(--tox-private-pad-md, 16px);
  padding: var(--tox-private-pad-sm, 8px);
  border-radius: var(--tox-private-panel-border-radius, 3px);
  box-shadow: var(--tox-private-ai-preview-loader-box-shadow, 0 0 40px 1px rgba(42, 55, 70, 0.15), 0 16px 16px -10px rgba(42, 55, 70, 0.15));
  background-color: var(--tox-private-background-color, #222f3e);
  color: var(--tox-private-text-color, #fff);
  pointer-events: auto;
}
.tox .tox-tinymceai-previewloader__content {
  display: flex;
  align-items: center;
  justify-content: center;
  padding: 0 var(--tox-private-pad-xs, 4px);
  gap: var(--tox-private-pad-sm, 8px);
}
.tox .tox-selector {
  background-color: #4099ff;
  border-color: #4099ff;
  border-style: solid;
  border-width: 1px;
  box-sizing: border-box;
  display: inline-block;
  height: 10px;
  position: absolute;
  width: 10px;
}
.tox.tox-platform-touch .tox-selector {
  height: 12px;
  width: 12px;
}
.tox .tox-skeleton .tox-skeleton__line {
  height: 16px;
  width: 100%;
  background: linear-gradient(to right, rgba(240, 240, 240, 0.5) 8%, rgba(240, 240, 240, 0.7) 18%, rgba(240, 240, 240, 0.5) 33%);
  animation: wave 2s infinite ease-out;
}
.tox .tox-skeleton .tox-skeleton__circle {
  height: 36px;
  width: 36px;
  margin-right: 8px;
  border-radius: 100%;
  background: linear-gradient(to right, rgba(240, 240, 240, 0.5) 8%, rgba(240, 240, 240, 0.7) 18%, rgba(240, 240, 240, 0.5) 33%);
  animation: wave 2s infinite ease-out;
}
@keyframes wave {
  0% {
    background-position: -268px 0;
  }
  100% {
    background-position: 268px 0;
  }
}
.tox .tox-slider {
  align-items: center;
  display: flex;
  flex: 1;
  height: 24px;
  justify-content: center;
  position: relative;
}
.tox .tox-slider__rail {
  background-color: transparent;
  border: 1px solid #000000;
  border-radius: 3px;
  height: 10px;
  min-width: 120px;
  width: 100%;
}
.tox .tox-slider__handle {
  background-color: #207ab7;
  border: 2px solid #185d8c;
  border-radius: 3px;
  box-shadow: none;
  height: 24px;
  left: 50%;
  position: absolute;
  top: 50%;
  transform: translateX(-50%) translateY(-50%);
  width: 14px;
}
.tox .tox-form__controls-h-stack > .tox-slider:not(:first-of-type) {
  margin-inline-start: 8px;
}
.tox .tox-form__controls-h-stack > .tox-form__group + .tox-slider {
  margin-inline-start: 32px;
}
.tox .tox-form__controls-h-stack > .tox-slider + .tox-form__group {
  margin-inline-start: 32px;
}
.tox .tox-toolbar-slider {
  align-items: center;
  display: inline-flex;
  height: 16px;
}
.tox .tox-toolbar-slider__input {
  appearance: none;
  background: #000000;
  border-radius: 16px;
  width: 130px;
  height: 2px;
}
.tox .tox-toolbar-slider__input::-webkit-slider-runnable-track {
  background-color: transparent;
  height: 16px;
}
.tox .tox-toolbar-slider__input::-moz-range-track {
  background-color: transparent;
  height: 16px;
}
.tox .tox-toolbar-slider__input::-webkit-slider-thumb {
  -webkit-appearance: none;
  background-color: #207ab7;
  border-radius: 16px;
  border: none;
  height: 16px;
  width: 16px;
}
.tox .tox-toolbar-slider__input::-moz-range-thumb {
  appearance: none;
  background-color: #207ab7;
  border-radius: 16px;
  border: none;
  height: 16px;
  width: 16px;
}
.tox .tox-toolbar-slider__input:focus-visible {
  outline: none;
}
.tox .tox-toolbar-slider__input:focus::-webkit-slider-thumb {
  background-color: #1c6ca1;
  box-shadow: inset 0 0 0 1px #fff, 0 0 0 2px #207ab7;
}
.tox .tox-toolbar-slider__input:focus::-moz-range-thumb {
  background-color: #1c6ca1;
  box-shadow: inset 0 0 0 1px #fff, 0 0 0 2px #207ab7;
}
.tox .tox-toolbar-slider__input:hover::-webkit-slider-thumb {
  background-color: #1c6ca1;
}
.tox .tox-toolbar-slider__input:hover::-moz-range-thumb {
  background-color: #1c6ca1;
}
.tox .tox-toolbar-slider__input:active::-webkit-slider-thumb {
  background-color: #185d8c;
}
.tox .tox-toolbar-slider__input:active::-moz-range-thumb {
  background-color: #185d8c;
}
.tox .tox-toolbar-slider__input[disabled]::-webkit-slider-thumb {
  background-color: rgba(255, 255, 255, 0.5);
}
.tox .tox-toolbar-slider__input[disabled]::-moz-range-thumb {
  background-color: rgba(255, 255, 255, 0.5);
}
.tox .tox-source-code {
  overflow: auto;
}
.tox .tox-spinner {
  display: flex;
}
.tox .tox-spinner > div {
  animation: tam-bouncing-dots 1.5s ease-in-out 0s infinite both;
  background-color: rgba(255, 255, 255, 0.5);
  border-radius: 100%;
  height: 8px;
  width: 8px;
}
.tox .tox-spinner > div:nth-child(1) {
  animation-delay: -0.32s;
}
.tox .tox-spinner > div:nth-child(2) {
  animation-delay: -0.16s;
}
@keyframes tam-bouncing-dots {
  0%,
  80%,
  100% {
    transform: scale(0);
  }
  40% {
    transform: scale(1);
  }
}
.tox:not([dir=rtl]) .tox-spinner > div:not(:first-child) {
  margin-left: 4px;
}
.tox[dir=rtl] .tox-spinner > div:not(:first-child) {
  margin-right: 4px;
}
.tox .tox-ai__spinner {
  --tox-private-spinner-color: var(--tox-private-color-tint, #207ab7);
  --tox-private-spinner-size: 24px;
  --tox-private-spinner-circle-width: 3px;
  --tox-private-spinner-dot-size: 6px;
  width: var(--tox-private-spinner-size);
  aspect-ratio: 1;
}
.tox .tox-ai__spinner--small {
  --tox-private-spinner-size: 16px;
  --tox-private-spinner-circle-width: 2px;
  --tox-private-spinner-dot-size: 4px;
}
.tox .tox-ai__spinner--circle {
  animation: tox-rotation 1s linear infinite;
  border-radius: 50%;
  background: conic-gradient(var(--tox-private-spinner-color) 0% calc(360deg - 30deg), transparent calc(360deg - 30deg) 100%);
  mask: radial-gradient(calc((var(--tox-private-spinner-size) - var(--tox-private-spinner-circle-width) * 2) / 2), #0000 98%, #000);
}
.tox .tox-ai__spinner--dots {
  display: flex;
  align-items: center;
  justify-content: center;
  gap: 1px;
}
.tox .tox-ai__spinner--dots > div {
  animation: tox-bouncing-dots 1.5s ease-in-out 0s infinite both;
  aspect-ratio: 1;
  width: var(--tox-private-spinner-dot-size);
  background-color: var(--tox-private-spinner-color);
  border-radius: 100%;
}
.tox .tox-ai__spinner--dots > div:nth-child(1) {
  animation-delay: -0.32s;
}
.tox .tox-ai__spinner--dots > div:nth-child(2) {
  animation-delay: -0.16s;
}
.tox .tox-tinymceai__annotation--added,
.tox .tox-tinymceai__annotation--modified,
.tox .tox-tinymceai__annotation--removed {
  padding-block: calc((1lh - 1.1em) / 2);
  -webkit-text-decoration: none;
  text-decoration: none;
  background-repeat: no-repeat;
  text-decoration-thickness: max(1px, 0.07em);
}
.tox .tox-tinymceai__annotation--added__highlight {
  background-position: bottom;
  background-image: linear-gradient(rgba(120, 171, 70, 0.2) calc(100% - 2px), #78AB46 calc(100% - 2px));
}
.tox .tox-tinymceai__annotation--added__selected {
  background-image: none;
  background-color: rgba(120, 171, 70, 0.2);
  box-shadow: 0 2px 0 0 #207ab7, 0 -2px 0 0 #207ab7;
}
.tox .tox-tinymceai__annotation--modified__highlight {
  background-position: bottom;
  background-image: linear-gradient(rgba(32, 122, 183, 0.2) calc(100% - 2px), #207ab7 calc(100% - 2px));
}
.tox .tox-tinymceai__annotation--modified__selected {
  background-image: none;
  background-color: rgba(32, 122, 183, 0.2);
  box-shadow: 0 2px 0 0 #207ab7, 0 -2px 0 0 #207ab7;
}
.tox .tox-tinymceai__annotation--removed__highlight {
  -webkit-text-decoration: line-through;
  text-decoration: line-through;
  background-position: bottom;
  background-image: linear-gradient(rgba(204, 0, 0, 0.2) calc(100% - 2px), #c00 calc(100% - 2px));
}
.tox .tox-tinymceai__annotation--removed__selected {
  -webkit-text-decoration: line-through;
  text-decoration: line-through;
  background-image: none;
  background-color: rgba(204, 0, 0, 0.2);
  box-shadow: 0 2px 0 0 #207ab7, 0 -2px 0 0 #207ab7;
}
.tox ins.tox-tinymceai__annotation--added__selected,
.tox del.tox-tinymceai__annotation--added__selected {
  background-color: transparent;
  box-shadow: none;
  background-position: center;
  background-size: 100% calc(1lh + 3px);
  background-image: linear-gradient(#207ab7 3px, rgba(120, 171, 70, 0.2) 3px, rgba(120, 171, 70, 0.2) calc(100% - 3px), #207ab7 calc(100% - 3px));
}
.tox ins.tox-tinymceai__annotation--modified__selected,
.tox del.tox-tinymceai__annotation--modified__selected {
  background-color: transparent;
  box-shadow: none;
  background-position: center;
  background-size: 100% calc(1lh + 3px);
  background-image: linear-gradient(#207ab7 3px, rgba(32, 122, 183, 0.2) 3px, rgba(32, 122, 183, 0.2) calc(100% - 3px), #207ab7 calc(100% - 3px));
}
.tox ins.tox-tinymceai__annotation--removed__selected,
.tox del.tox-tinymceai__annotation--removed__selected {
  background-color: transparent;
  box-shadow: none;
  background-position: center;
  background-size: 100% calc(1lh + 3px);
  background-image: linear-gradient(#207ab7 3px, rgba(204, 0, 0, 0.2) 3px, rgba(204, 0, 0, 0.2) calc(100% - 3px), #207ab7 calc(100% - 3px));
}
.tox .tox-tinymceai__annotation--added.tox-tinymceai__annotation--added__hidden,
.tox .tox-tinymceai__annotation--modified.tox-tinymceai__annotation--modified__hidden,
.tox .tox-tinymceai__annotation--removed.tox-tinymceai__annotation--removed__hidden {
  display: none;
  -webkit-text-decoration: none;
  text-decoration: none;
}
.tox *:has(> div > iframe).tox-tinymceai__annotation--added,
.tox *:has(> div > iframe).tox-tinymceai__annotation--modified,
.tox *:has(> div > iframe).tox-tinymceai__annotation--removed {
  padding: 7px;
  margin: 5px;
}
.tox img.tox-tinymceai__annotation--added__highlight,
.tox video.tox-tinymceai__annotation--added__highlight,
.tox iframe.tox-tinymceai__annotation--added__highlight {
  outline: 0.25em solid rgba(120, 171, 70, 0.2);
  padding: 0.25em;
  background-image: none;
}
.tox img.tox-tinymceai__annotation--added__selected,
.tox video.tox-tinymceai__annotation--added__selected,
.tox iframe.tox-tinymceai__annotation--added__selected {
  border: 0.25em solid rgba(120, 171, 70, 0.2);
  outline: 0.125em solid #207ab7;
  padding: 0em;
  background-image: none;
}
.tox img.tox-tinymceai__annotation--modified__highlight,
.tox video.tox-tinymceai__annotation--modified__highlight,
.tox iframe.tox-tinymceai__annotation--modified__highlight {
  outline: 0.25em solid rgba(32, 122, 183, 0.2);
  padding: 0.25em;
  background-image: none;
}
.tox img.tox-tinymceai__annotation--modified__selected,
.tox video.tox-tinymceai__annotation--modified__selected,
.tox iframe.tox-tinymceai__annotation--modified__selected {
  border: 0.25em solid rgba(32, 122, 183, 0.2);
  outline: 0.125em solid #207ab7;
  padding: 0em;
  background-image: none;
}
.tox img.tox-tinymceai__annotation--removed__highlight,
.tox video.tox-tinymceai__annotation--removed__highlight,
.tox iframe.tox-tinymceai__annotation--removed__highlight {
  outline: 0.25em solid rgba(204, 0, 0, 0.2);
  padding: 0.25em;
  background-image: none;
}
.tox img.tox-tinymceai__annotation--removed__selected,
.tox video.tox-tinymceai__annotation--removed__selected,
.tox iframe.tox-tinymceai__annotation--removed__selected {
  border: 0.25em solid rgba(204, 0, 0, 0.2);
  outline: 0.125em solid #207ab7;
  padding: 0em;
  background-image: none;
}
.tox div.tox-tinymceai__annotation:has(> hr) {
  background-size: auto;
  padding: 0.25em;
}
.tox div.tox-tinymceai__annotation--removed__highlight > hr {
  border-color: rgba(0, 0, 0, 0.2);
}
.tox div.tox-tinymceai__annotation--added__highlight > hr {
  border-color: rgba(0, 0, 0, 0.2);
}
.tox .mce-pagebreak.tox-tinymceai__annotation--added__selected,
.tox .mce-pagebreak.tox-tinymceai__annotation--removed__selected,
.tox .mce-pagebreak.tox-tinymceai__annotation--modified__selected {
  border: 1px dashed #aaa;
  box-shadow: none;
  background-image: none;
}
.tox .mce-pagebreak.tox-tinymceai__annotation--added__highlight,
.tox .mce-pagebreak.tox-tinymceai__annotation--modified__highlight,
.tox .mce-pagebreak.tox-tinymceai__annotation--removed__highlight {
  padding: 0;
}
.tox .tox-ai__scroll .tox-ai__review-sidebar-container {
  scrollbar-gutter: stable;
  width: 100%;
  height: 100%;
  display: flex;
  flex-direction: column;
  gap: 12px;
}
.tox .tox-ai__scroll .tox-ai__review-sidebar-container .tox-card-list {
  gap: 8px;
}
.tox .tox-ai__scroll .tox-ai__review-sidebar-container .tox-ai__review-initializing {
  padding: var(--tox-private-pad-md, 16px);
}
.tox .tox-ai__scroll .tox-ai__review-sidebar-container .tox-ai__review-description {
  padding-bottom: calc(var(--tox-private-pad-sm, 8px) + var(--tox-private-pad-xs, 4px));
  font-size: var(--tox-private-font-size-sm, 14px);
}
.tox .tox-ai__scroll .tox-ai__review-sidebar-container .tox-ai__review-choose-container {
  padding-bottom: 12px;
}
.tox .tox-ai__scroll .tox-ai__review-sidebar-container .tox-ai__review-custom-input {
  margin-bottom: 12px;
}
.tox .tox-ai__scroll .tox-ai__review-sidebar-container .tox-ai__review-custom-actions {
  display: flex;
  gap: 8px;
}
.tox .tox-ai__scroll .tox-ai__review-sidebar-container .tox-ai__review-input-container {
  margin-bottom: 12px;
}
.tox .tox-ai__scroll .tox-ai__review-sidebar-container .tox-ai__review-input-container button.tox-ai__review-input-button {
  width: 100%;
  background-color: var(--tox-private-background-color, #222f3e);
  display: flex;
  justify-content: space-between;
  align-items: center;
  border: 1px solid #000000;
  border-radius: 3px;
  box-sizing: border-box;
}
.tox .tox-ai__scroll .tox-ai__review-sidebar-container .tox-ai__review-input-container .tox-ai__review-dropdown-content {
  width: anchor-size(width);
}
.tox .tox-statusbar {
  align-items: center;
  background-color: #222f3e;
  border-top: 1px solid #000000;
  color: #fff;
  display: flex;
  flex: 0 0 auto;
  font-size: 12px;
  font-weight: normal;
  height: 18px;
  overflow: hidden;
  padding: 0 8px;
  position: relative;
  text-transform: uppercase;
}
.tox .tox-statusbar__path {
  display: flex;
  flex: 1 1 auto;
  text-overflow: ellipsis;
  white-space: nowrap;
}
.tox .tox-statusbar__right-container {
  display: flex;
  justify-content: flex-end;
  white-space: nowrap;
}
.tox .tox-statusbar__help-text {
  text-align: center;
}
.tox .tox-statusbar__text-container {
  align-items: flex-start;
  display: flex;
  flex: 1 1 auto;
  height: 16px;
  justify-content: space-between;
}
@media only screen and (min-width: 768px ) {
  .tox .tox-statusbar__text-container.tox-statusbar__text-container-3-cols > .tox-statusbar__help-text,
  .tox .tox-statusbar__text-container.tox-statusbar__text-container-3-cols > .tox-statusbar__right-container,
  .tox .tox-statusbar__text-container.tox-statusbar__text-container-3-cols > .tox-statusbar__path {
    flex: 0 0 calc(100% / 3);
  }
}
.tox .tox-statusbar__text-container.tox-statusbar__text-container--flex-end {
  justify-content: flex-end;
}
.tox .tox-statusbar__text-container.tox-statusbar__text-container--flex-start {
  justify-content: flex-start;
}
.tox .tox-statusbar__text-container.tox-statusbar__text-container--space-around {
  justify-content: space-around;
}
.tox .tox-statusbar__path > * {
  display: inline;
  white-space: nowrap;
}
.tox .tox-statusbar__wordcount {
  flex: 0 0 auto;
  margin-left: 1ch;
}
@media only screen and (max-width: 767px ) {
  .tox .tox-statusbar__text-container .tox-statusbar__help-text {
    display: none;
  }
  .tox .tox-statusbar__text-container .tox-statusbar__help-text:only-child {
    display: block;
  }
}
.tox .tox-statusbar a,
.tox .tox-statusbar__path-item,
.tox .tox-statusbar__wordcount {
  color: #fff;
  position: relative;
  -webkit-text-decoration: none;
  text-decoration: none;
}
.tox .tox-statusbar a:hover:not(:disabled):not([aria-disabled=true]),
.tox .tox-statusbar__path-item:hover:not(:disabled):not([aria-disabled=true]),
.tox .tox-statusbar__wordcount:hover:not(:disabled):not([aria-disabled=true]),
.tox .tox-statusbar a:focus:not(:disabled):not([aria-disabled=true]),
.tox .tox-statusbar__path-item:focus:not(:disabled):not([aria-disabled=true]),
.tox .tox-statusbar__wordcount:focus:not(:disabled):not([aria-disabled=true]) {
  color: #fff;
  cursor: pointer;
}
.tox .tox-statusbar a:focus-visible::after,
.tox .tox-statusbar__path-item:focus-visible::after,
.tox .tox-statusbar__wordcount:focus-visible::after {
  border-radius: 3px;
  bottom: 0;
  box-shadow: 0 0 0 0 transparent ;
  content: '';
  left: 0;
  position: absolute;
  right: 0;
  top: 0;
}
@media (forced-colors: active) {
  .tox .tox-statusbar a:focus-visible::after,
  .tox .tox-statusbar__path-item:focus-visible::after,
  .tox .tox-statusbar__wordcount:focus-visible::after {
    border: 2px solid highlight;
  }
}
.tox .tox-statusbar__branding svg {
  fill: rgba(255, 255, 255, 0.8);
  height: 1em;
  margin-left: 0.3em;
  width: auto;
}
@media (forced-colors: active) {
  .tox .tox-statusbar__branding svg {
    fill: currentColor;
  }
}
.tox .tox-statusbar__branding a {
  align-items: center;
  display: inline-flex;
}
.tox .tox-statusbar__branding a:hover:not(:disabled):not([aria-disabled=true]) svg,
.tox .tox-statusbar__branding a:focus:not(:disabled):not([aria-disabled=true]) svg {
  fill: #fff;
}
.tox .tox-statusbar__resize-cursor-default {
  cursor: ns-resize;
}
.tox .tox-statusbar__resize-cursor-both {
  cursor: nwse-resize;
}
.tox .tox-statusbar__resize-handle {
  align-items: flex-end;
  align-self: stretch;
  display: flex;
  flex: 0 0 auto;
  justify-content: flex-end;
  margin-bottom: 3px;
  margin-left: 4px;
  margin-right: calc(3px - 8px);
  margin-top: 3px;
  padding-bottom: 0;
  padding-left: 0;
  padding-right: 0;
  position: relative;
}
.tox .tox-statusbar__resize-handle svg {
  display: block;
  fill: rgba(255, 255, 255, 0.5);
}
.tox .tox-statusbar__resize-handle:hover svg,
.tox .tox-statusbar__resize-handle:focus svg {
  fill: #fff;
}
.tox .tox-statusbar__resize-handle:focus-visible {
  background-color: transparent;
  border-radius: 1px 1px -4px 1px;
  box-shadow: 0 0 0 2px transparent;
}
.tox .tox-statusbar__resize-handle:focus-visible::after {
  border-radius: 3px;
  bottom: 0;
  box-shadow: 0 0 0 0 transparent ;
  content: '';
  left: 0;
  position: absolute;
  right: 0;
  top: 0;
}
@media (forced-colors: active) {
  .tox .tox-statusbar__resize-handle:focus-visible::after {
    border: 2px solid highlight;
  }
}
.tox .tox-statusbar__resize-handle:only-child {
  margin-left: auto;
}
.tox:not([dir=rtl]) .tox-statusbar__path > * {
  margin-right: 4px;
}
.tox:not([dir=rtl]) .tox-statusbar__branding {
  margin-left: 2ch;
}
.tox[dir=rtl] .tox-statusbar {
  flex-direction: row-reverse;
}
.tox[dir=rtl] .tox-statusbar__path > * {
  margin-left: 4px;
}
.tox[dir=rtl] .tox-statusbar__branding svg {
  margin-left: 0;
  margin-right: 0.3em;
}
.tox a.tox-tag {
  cursor: pointer;
}
.tox .tox-tag {
  width: fit-content;
  box-sizing: border-box;
  display: flex;
  padding: var(--tox-private-pad-xs, 4px) 6px;
  position: relative;
  align-items: center;
  gap: var(--tox-private-pad-xs, 4px);
  border-radius: 3px;
  background: hsl(from var(--tox-private-color-tint, #207ab7) h s l / 10%);
  line-height: var(--tox-private-base-value, 16px);
  font-size: var(--tox-private-font-size-xs, 12px);
}
.tox .tox-tag::before {
  border-radius: var(--tox-private-control-border-radius, 3px);
  bottom: calc(-1 * var(--tox-private-tag-border-width, 1px));
  box-shadow: var(--tox-private-tag-focus-outline, inset 0 0 0 1px #fff, 0 0 0 2px #207ab7);
  content: '';
  left: calc(-1 * var(--tox-private-tag-border-width, 1px));
  opacity: 0;
  pointer-events: none;
  position: absolute;
  right: calc(-1 * var(--tox-private-tag-border-width, 1px));
  top: calc(-1 * var(--tox-private-tag-border-width, 1px));
}
.tox .tox-tag:focus:not(:disabled)::before {
  opacity: 1;
}
.tox .tox-tag > * {
  /* 
        If there is not enough space, then do not scale down anything, except for label, which has flex-shrink set to 1.
        In general we expect two small items in tag (icon and close button) and one large (usually label).
      */
  flex-shrink: 0;
}
.tox .tox-tag .tox-icon {
  height: var(--tox-private-base-value, 16px);
  fill: var(--tox-private-text-color, #fff);
}
.tox .tox-tag .tox-tag__label {
  text-overflow: ellipsis;
  overflow: hidden;
  white-space: nowrap;
  /* If there is not enough space, then shrink the label. */
  flex-shrink: 1;
  color: var(--tox-private-text-color, #fff);
}
.tox .tox-tag .tox-tag__close {
  height: var(--tox-private-base-value, 16px);
}
.tox .tox-tag .tox-tag__close .tox-button.tox-button--icon {
  border: 0;
  padding: 0;
  color: var(--tox-private-text-color-muted, rgba(255, 255, 255, 0.5));
}
.tox .tox-tag .tox-tag__close .tox-button.tox-button--icon::before {
  box-shadow: none;
}
.tox .tox-throbber {
  z-index: 1299;
}
.tox .tox-throbber__busy-spinner {
  align-items: center;
  background-color: rgba(34, 47, 62, 0.6);
  bottom: 0;
  display: flex;
  justify-content: center;
  left: 0;
  position: absolute;
  right: 0;
  top: 0;
}
.tox .tox-segmented-control {
  display: inline-flex;
  position: relative;
  border: none;
  border-radius: var(--tox-private-control-border-radius, 3px);
  box-shadow: inset 0 0 0 1px var(--tox-private-segmented-control-border-color, #364a62);
  overflow: hidden;
  padding: var(--tox-private-pad-xs, 4px);
  background-color: var(--tox-private-background-color, #222f3e);
}
.tox .tox-segmented-control__segment {
  flex: 1;
  padding: var(--tox-private-pad-xs, 4px) var(--tox-private-pad-sm, 8px);
  cursor: pointer;
  background: transparent;
  font-size: var(--tox-private-font-size-sm, 14px);
  font-weight: var(--tox-private-font-weight-normal, normal);
  line-height: 16px;
  border: 1px solid transparent;
  border-radius: calc(var(--tox-private-control-border-radius, 3px) - 1px);
  text-align: center;
  white-space: nowrap;
  display: inline-block;
  vertical-align: middle;
  color: var(--tox-private-segmented-control-text-color, #fff);
}
.tox .tox-segmented-control__segment--active {
  border-color: var(--tox-private-segmented-control-active-border-color, #207ab7);
  color: var(--tox-private-segmented-control-active-text-color, #207ab7);
  background-color: var(--tox-private-segmented-control-active-bg-color, rgba(32, 122, 183, 0.1));
}
.tox .tox-segmented-control:not(.tox-segmented-control--disabled) .tox-segmented-control__segment {
  transition: all 0.2s;
}
.tox .tox-segmented-control.tox-segmented-control--disabled .tox-segmented-control__segment {
  opacity: 0.5;
  cursor: not-allowed;
  pointer-events: none;
}
.tox .tox-segmented-control__segment:focus {
  outline: 2px solid var(--tox-private-color-tint, #207ab7);
  outline-offset: 2px;
}
.tox .tox-segmented-control__segment:focus:not(:focus-visible) {
  outline: none;
}
.tox .tox-toggle {
  display: flex;
  align-items: center;
  gap: var(--tox-private-pad-xs, 4px);
  padding: var(--tox-private-pad-xs, 4px);
  font-weight: var(--tox-private-font-weight-normal, normal);
  line-height: var(--tox-private-control-line-height, 24px);
  white-space: nowrap;
  background-color: var(--tox-private-background-color, #222f3e);
  color: var(--tox-private-text-color, #fff);
}
.tox .tox-toggle input {
  position: absolute;
  opacity: 0;
  width: 0;
  height: 0;
}
.tox .tox-toggle__slider {
  position: relative;
  cursor: pointer;
  box-sizing: border-box;
  transition: 0.4s;
  border-radius: 34px;
  width: 28px;
  height: 16px;
  background-color: var(--tox-private-slider-background-color, #222f3e);
  border: 1px solid var(--tox-private-slider-border-color, rgba(255, 255, 255, 0.15));
}
.tox .tox-toggle__slider::before {
  position: absolute;
  content: "";
  height: 12px;
  width: 12px;
  left: 1px;
  bottom: 1px;
  transition: 0.4s;
  border-radius: 50%;
  background-color: var(--tox-private-slider-handle-background-color, #fff);
}
.tox input:checked + .tox-toggle__slider {
  background-color: var(--tox-private-slider-checked-background-color, #207ab7);
  border: 1px solid var(--tox-private-slider-checked-border-color, #207ab7);
}
.tox input:focus + .tox-toggle__slider {
  box-shadow: 0 0 0 1px var(--tox-private-color-white, #fff), 0 0 0 2px var(--tox-private-color-tint, #207ab7);
}
.tox input:checked + .tox-toggle__slider::before {
  transform: translateX(12px);
  background-color: var(--tox-private-slider-checked-handle-background-color, #fff);
}
.tox input:disabled + .tox-toggle__slider::before {
  opacity: 50%;
}
.tox .tox-tbtn {
  align-items: center;
  background: #222f3e;
  border: 0;
  border-radius: 3px;
  box-shadow: none;
  color: #fff;
  display: flex;
  flex: 0 0 auto;
  font-size: 14px;
  font-style: normal;
  font-weight: normal;
  height: 34px;
  justify-content: center;
  margin: 3px 0 2px 0;
  outline: none;
  padding: 0;
  text-transform: none;
  width: 34px;
}
.tox .tox-tbtn .tox-tbtn__icon-wrap {
  pointer-events: none;
}
@media (forced-colors: active) {
  .tox .tox-tbtn:hover,
  .tox .tox-tbtn.tox-tbtn:hover {
    outline: 1px dashed currentColor;
  }
  .tox .tox-tbtn.tox-tbtn--active,
  .tox .tox-tbtn.tox-tbtn--enabled,
  .tox .tox-tbtn.tox-tbtn--enabled:hover,
  .tox .tox-tbtn.tox-tbtn--enabled:focus,
  .tox .tox-tbtn:focus:not(.tox-tbtn--disabled) {
    outline: 1px solid currentColor;
    position: relative;
  }
}
.tox .tox-tbtn svg {
  display: block;
  fill: #fff;
}
@media (forced-colors: active) {
  .tox .tox-tbtn svg {
    fill: currentColor !important;
  }
  .tox .tox-tbtn svg.tox-tbtn--enabled,
  .tox .tox-tbtn svg:focus:not(.tox-tbtn--disabled) {
    fill: currentColor !important;
  }
  .tox .tox-tbtn svg.tox-tbtn--disabled,
  .tox .tox-tbtn svg.tox-tbtn--disabled:hover,
  .tox .tox-tbtn svg .tox-tbtn:disabled,
  .tox .tox-tbtn svg .tox-tbtn:disabled:hover {
    filter: contrast(0%);
  }
}
.tox .tox-tbtn.tox-tbtn-more {
  padding-left: 5px;
  padding-right: 5px;
  width: inherit;
}
.tox .tox-tbtn:focus {
  background: #4a5562;
  border: 0;
  box-shadow: none;
  position: relative;
  z-index: 1;
}
.tox .tox-tbtn:focus::after {
  border-radius: 3px;
  bottom: 0;
  box-shadow: 0 0 0 0 transparent ;
  content: '';
  left: 0;
  position: absolute;
  right: 0;
  top: 0;
}
@media (forced-colors: active) {
  .tox .tox-tbtn:focus::after {
    border: 2px solid highlight;
  }
}
.tox .tox-tbtn:hover {
  background: #4a5562;
  border: 0;
  box-shadow: none;
  color: #fff;
}
.tox .tox-tbtn:hover svg {
  fill: #fff;
}
.tox .tox-tbtn:active {
  background: #757d87;
  border: 0;
  box-shadow: none;
  color: #fff;
}
.tox .tox-tbtn:active svg {
  fill: #fff;
}
.tox .tox-tbtn--disabled .tox-tbtn--enabled svg {
  fill: rgba(255, 255, 255, 0.5);
}
.tox .tox-tbtn--disabled,
.tox .tox-tbtn--disabled:hover,
.tox .tox-tbtn:disabled,
.tox .tox-tbtn:disabled:hover {
  background: #222f3e;
  border: 0;
  box-shadow: none;
  color: rgba(255, 255, 255, 0.5);
  cursor: not-allowed;
}
.tox .tox-tbtn--disabled svg,
.tox .tox-tbtn--disabled:hover svg,
.tox .tox-tbtn:disabled svg,
.tox .tox-tbtn:disabled:hover svg {
  fill: rgba(255, 255, 255, 0.5);
}
.tox .tox-tbtn--active,
.tox .tox-tbtn--enabled,
.tox .tox-tbtn--enabled:hover,
.tox .tox-tbtn--enabled:focus {
  background: #757d87;
  border: 0;
  box-shadow: none;
  color: #fff;
  position: relative;
}
.tox .tox-tbtn--active > *,
.tox .tox-tbtn--enabled > *,
.tox .tox-tbtn--enabled:hover > *,
.tox .tox-tbtn--enabled:focus > * {
  transform: none;
}
.tox .tox-tbtn--active svg,
.tox .tox-tbtn--enabled svg,
.tox .tox-tbtn--enabled:hover svg,
.tox .tox-tbtn--enabled:focus svg {
  fill: #fff;
}
.tox .tox-tbtn--active.tox-tbtn--disabled svg,
.tox .tox-tbtn--enabled.tox-tbtn--disabled svg,
.tox .tox-tbtn--enabled:hover.tox-tbtn--disabled svg,
.tox .tox-tbtn--enabled:focus.tox-tbtn--disabled svg {
  fill: rgba(255, 255, 255, 0.5);
}
.tox .tox-tbtn--enabled:focus::after {
  border-radius: 3px;
  bottom: 0;
  box-shadow: 0 0 0 0 transparent ;
  content: '';
  left: 0;
  position: absolute;
  right: 0;
  top: 0;
}
@media (forced-colors: active) {
  .tox .tox-tbtn--enabled:focus::after {
    border: 2px solid highlight;
  }
}
.tox .tox-tbtn:focus:not(.tox-tbtn--disabled) {
  color: #fff;
}
.tox .tox-tbtn:focus:not(.tox-tbtn--disabled) svg {
  fill: #fff;
}
.tox .tox-tbtn:active > * {
  transform: none;
}
.tox .tox-tbtn--md {
  height: 51px;
  width: 51px;
}
.tox .tox-tbtn--lg {
  flex-direction: column;
  height: 68px;
  width: 68px;
}
.tox .tox-tbtn--return {
  align-self: stretch;
  height: unset;
  width: 16px;
}
.tox .tox-tbtn--labeled {
  padding: 0 4px;
  width: unset;
}
.tox .tox-tbtn__vlabel {
  display: block;
  font-size: 10px;
  font-weight: normal;
  letter-spacing: -0.025em;
  margin-bottom: 4px;
  white-space: nowrap;
}
.tox .tox-label--context-toolbar {
  margin: 6px 1px 5px 0;
  -webkit-touch-callout: none;
  -webkit-user-select: none;
  user-select: none;
}
.tox .tox-number-input {
  background: transparent;
  border-radius: 3px;
  display: flex;
  margin: 3px 0 2px 0;
  position: relative;
  width: auto;
}
.tox .tox-number-input:focus {
  background: #4a5562;
}
.tox .tox-number-input:focus::after {
  border-radius: 3px;
  bottom: 0;
  box-shadow: 0 0 0 0 transparent ;
  content: '';
  left: 0;
  position: absolute;
  right: 0;
  top: 0;
}
@media (forced-colors: active) {
  .tox .tox-number-input:focus::after {
    border: 2px solid highlight;
  }
}
.tox .tox-number-input .tox-input-wrapper {
  display: flex;
  pointer-events: none;
  position: relative;
  text-align: center;
}
.tox .tox-number-input .tox-input-wrapper:focus {
  background-color: #4a5562;
  z-index: 1;
}
.tox .tox-number-input .tox-input-wrapper:focus::after {
  border-radius: 3px;
  bottom: 0;
  box-shadow: 0 0 0 0 transparent ;
  content: '';
  left: 0;
  position: absolute;
  right: 0;
  top: 0;
}
@media (forced-colors: active) {
  .tox .tox-number-input .tox-input-wrapper:focus::after {
    border: 2px solid highlight;
  }
}
.tox .tox-number-input .tox-input-wrapper:has(input:focus)::after {
  border-radius: 3px;
  bottom: 0;
  box-shadow: 0 0 0 0 transparent ;
  content: '';
  left: 0;
  position: absolute;
  right: 0;
  top: 0;
}
@media (forced-colors: active) {
  .tox .tox-number-input .tox-input-wrapper:has(input:focus)::after {
    border: 2px solid highlight;
  }
}
.tox .tox-number-input input {
  border-radius: 3px;
  color: #fff;
  font-size: 14px;
  margin: 2px 0;
  pointer-events: all;
  position: relative;
  width: 60px;
}
.tox .tox-number-input input:hover {
  background: #4a5562;
  color: #fff;
}
.tox .tox-number-input input:focus {
  background-color: #4a5562;
}
.tox .tox-number-input input:disabled {
  background: #222f3e;
  border: 0;
  box-shadow: none;
  color: rgba(255, 255, 255, 0.5);
  cursor: not-allowed;
}
.tox .tox-number-input button {
  color: #fff;
  height: 34px;
  position: relative;
  text-align: center;
  width: 24px;
}
@media (forced-colors: active) {
  .tox .tox-number-input button:hover,
  .tox .tox-number-input button:focus,
  .tox .tox-number-input button:active {
    outline: 1px solid currentColor !important;
  }
}
.tox .tox-number-input button svg {
  display: block;
  fill: #fff;
  margin: 0 auto;
  transform: scale(0.67);
}
@media (forced-colors: active) {
  .tox .tox-number-input button svg,
  .tox .tox-number-input button svg:active,
  .tox .tox-number-input button svg:hover {
    fill: currentColor !important;
  }
  .tox .tox-number-input button svg:disabled {
    filter: contrast(0);
  }
}
.tox .tox-number-input button:focus {
  background: #4a5562;
  z-index: 1;
}
.tox .tox-number-input button:focus::after {
  border-radius: 3px;
  bottom: 0;
  box-shadow: 0 0 0 0 transparent ;
  content: '';
  left: 0;
  position: absolute;
  right: 0;
  top: 0;
}
@media (forced-colors: active) {
  .tox .tox-number-input button:focus::after {
    border: 2px solid highlight;
  }
}
.tox .tox-number-input button:hover {
  background: #4a5562;
  border: 0;
  box-shadow: none;
  color: #fff;
}
.tox .tox-number-input button:hover svg {
  fill: #fff;
}
.tox .tox-number-input button:active {
  background: #757d87;
  border: 0;
  box-shadow: none;
  color: #fff;
}
.tox .tox-number-input button:active svg {
  fill: #fff;
}
.tox .tox-number-input button:disabled {
  background: #222f3e;
  border: 0;
  box-shadow: none;
  color: rgba(255, 255, 255, 0.5);
  cursor: not-allowed;
}
.tox .tox-number-input button:disabled svg {
  fill: rgba(255, 255, 255, 0.5);
}
.tox .tox-number-input button.minus {
  border-radius: 3px 0 0 3px;
}
.tox .tox-number-input button.plus {
  border-radius: 0 3px 3px 0;
}
.tox .tox-number-input:focus:not(:active) > button,
.tox .tox-number-input:focus:not(:active) > .tox-input-wrapper {
  background: #4a5562;
}
.tox .tox-tbtn--select {
  margin: 3px 0 2px 0;
  padding: 0 4px;
  width: auto;
}
.tox .tox-tbtn--bordered,
.tox .tox-tbtn--bordered:focus,
.tox .tox-tbtn--bordered:hover {
  border: 1px solid #000000;
}
.tox .tox-tbtn__select-label {
  cursor: default;
  font-weight: normal;
  height: initial;
  margin: 0 4px;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
}
.tox .tox-tbtn__select-chevron {
  align-items: center;
  display: flex;
  justify-content: center;
  width: 16px;
}
.tox .tox-tbtn__select-chevron svg {
  fill: rgba(255, 255, 255, 0.5);
}
@media (forced-colors: active) {
  .tox .tox-tbtn__select-chevron svg {
    fill: currentColor;
  }
}
.tox .tox-tbtn--bespoke {
  background: transparent;
}
.tox .tox-tbtn--bespoke:focus {
  background: #4a5562;
}
.tox .tox-tbtn--bespoke + .tox-tbtn--bespoke {
  margin-inline-start: 0;
}
.tox .tox-tbtn--bespoke .tox-tbtn__select-label {
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  width: 7em;
}
.tox .tox-tbtn--disabled .tox-tbtn__select-label,
.tox .tox-tbtn--select:disabled .tox-tbtn__select-label {
  cursor: not-allowed;
}
.tox .tox-split-button__main {
  border-radius: 3px 0 0 3px;
  margin-right: 0;
}
.tox .tox-split-button__main:focus {
  border: 0;
  box-shadow: none;
  background: #4a5562;
  color: #fff;
  position: relative;
  z-index: 1;
}
.tox .tox-split-button__main:focus::after {
  border-radius: 3px;
  bottom: 0;
  box-shadow: 0 0 0 0 transparent ;
  content: '';
  left: 0;
  position: absolute;
  right: 0;
  top: 0;
  border-radius: 3px 0 0 3px;
}
@media (forced-colors: active) {
  .tox .tox-split-button__main:focus::after {
    border: 2px solid highlight;
  }
}
.tox .tox-split-button__chevron {
  width: 16px;
  border-radius: 0 3px 3px 0;
  margin-left: 0;
}
.tox .tox-split-button__chevron:focus {
  border: 0;
  box-shadow: none;
  background: #4a5562;
  color: #fff;
  position: relative;
  z-index: 1;
}
.tox .tox-split-button__chevron:focus::after {
  border-radius: 3px;
  bottom: 0;
  box-shadow: 0 0 0 0 transparent ;
  content: '';
  left: 0;
  position: absolute;
  right: 0;
  top: 0;
  border-radius: 0 3px 3px 0;
}
@media (forced-colors: active) {
  .tox .tox-split-button__chevron:focus::after {
    border: 2px solid highlight;
  }
}
.tox .tox-split-button__chevron svg {
  fill: rgba(255, 255, 255, 0.5);
}
@media (forced-colors: active) {
  .tox .tox-split-button__chevron svg {
    fill: currentColor;
  }
}
.tox.tox-platform-touch .tox-split-button__main {
  width: 30px;
}
.tox.tox-platform-touch .tox-split-button__chevron {
  width: 20px;
}
.tox .tox-split-button__main.tox-tbtn--disabled,
.tox .tox-split-button__chevron.tox-tbtn--disabled {
  background: #222f3e;
  box-shadow: none;
  color: rgba(255, 255, 255, 0.5);
}
.tox .tox-split-button__main.tox-tbtn--disabled:hover,
.tox .tox-split-button__chevron.tox-tbtn--disabled:hover {
  background: #222f3e;
  box-shadow: none;
  color: rgba(255, 255, 255, 0.5);
}
.tox .tox-split-button__main.tox-tbtn--disabled:focus,
.tox .tox-split-button__chevron.tox-tbtn--disabled:focus {
  background: #222f3e;
  box-shadow: none;
  color: rgba(255, 255, 255, 0.5);
}
.tox .tox-split-button__main.tox-tbtn--disabled svg .tox-icon-text-color__color,
.tox .tox-split-button__main.tox-tbtn--disabled svg .tox-icon-highlight-bg-color__color {
  opacity: 0.3;
}
.tox .tox-toolbar-overlord {
  background-color: #222f3e;
}
.tox .tox-toolbar,
.tox .tox-toolbar__primary,
.tox .tox-toolbar__overflow {
  background-attachment: local;
  background-color: #222f3e;
  background-image: repeating-linear-gradient(#000000 0 1px, transparent 1px 39px);
  background-position: center top 39px;
  background-repeat: no-repeat;
  background-size: calc(100% - 4px * 2) calc(100% - 39px);
  display: flex;
  flex: 0 0 auto;
  flex-shrink: 0;
  flex-wrap: wrap;
  padding: 0 0px;
  transform: perspective(1px);
}
.tox .tox-toolbar-overlord > .tox-toolbar,
.tox .tox-toolbar-overlord > .tox-toolbar__primary,
.tox .tox-toolbar-overlord > .tox-toolbar__overflow {
  background-position: center top 0px;
  background-size: calc(100% - 4px * 2) calc(100% - 0px);
}
.tox .tox-toolbar__overflow.tox-toolbar__overflow--closed {
  height: 0;
  opacity: 0;
  padding-bottom: 0;
  padding-top: 0;
  visibility: hidden;
}
.tox .tox-toolbar__overflow--growing {
  transition: height 0.3s ease, opacity 0.2s linear 0.1s;
}
.tox .tox-toolbar__overflow--shrinking {
  transition: opacity 0.3s ease, height 0.2s linear 0.1s, visibility 0s linear 0.3s;
}
.tox .tox-toolbar-overlord,
.tox .tox-anchorbar {
  grid-column: 1 / -1;
}
.tox .tox-menubar + .tox-toolbar,
.tox .tox-menubar + .tox-toolbar-overlord {
  border-top: 1px solid #000000;
  margin-top: -1px;
  padding-bottom: 0;
  padding-top: 0;
}
@media (forced-colors: active) {
  .tox .tox-menubar + .tox-toolbar,
  .tox .tox-menubar + .tox-toolbar-overlord {
    outline: 1px solid currentColor;
  }
}
.tox .tox-toolbar--scrolling {
  flex-wrap: nowrap;
  overflow-x: auto;
}
.tox .tox-pop .tox-toolbar {
  border-width: 0;
}
.tox .tox-toolbar--no-divider {
  background-image: none;
}
.tox .tox-toolbar-overlord .tox-toolbar:not(.tox-toolbar--scrolling):first-child,
.tox .tox-toolbar-overlord .tox-toolbar__primary {
  background-position: center top 39px;
}
.tox .tox-editor-header > .tox-toolbar--scrolling,
.tox .tox-toolbar-overlord .tox-toolbar--scrolling:first-child {
  background-image: none;
}
.tox .tox-focusable-wrapper {
  border: 1px solid transparent;
  margin-right: 2px;
  pointer-events: none;
}
.tox .tox-focusable-wrapper .tox-textfield-size {
  pointer-events: all;
}
.tox .tox-focusable-wrapper:focus {
  background-color: #4a5562;
  border-radius: 3px;
  border-style: solid;
  border-width: 1px;
}
.tox.tox-tinymce-aux .tox-toolbar__overflow {
  background-color: #222f3e;
  background-position: center top 43px;
  background-size: calc(100% - 8px * 2) calc(100% - 51px);
  border: none;
  border-radius: 3px;
  box-shadow: 0 0 2px 0 rgba(42, 55, 70, 0.2), 0 4px 8px 0 rgba(42, 55, 70, 0.15);
  overscroll-behavior: none;
  padding: 4px 0;
}
@media (forced-colors: active) {
  .tox.tox-tinymce-aux .tox-toolbar__overflow {
    border: solid;
  }
}
.tox-pop .tox-pop__dialog .tox-toolbar {
  background-position: center top 43px;
  background-size: calc(100% - 4px * 2) calc(100% - 51px);
  padding: 4px 0;
}
.tox-context-form__group {
  display: flex;
  align-items: center;
}
.tox .tox-toolbar__group {
  align-items: center;
  display: flex;
  flex-wrap: wrap;
  margin: 0 0;
  padding: 0 4px 0 4px;
}
.tox .tox-toolbar__group--pull-right {
  margin-left: auto;
}
.tox .tox-toolbar--scrolling .tox-toolbar__group {
  flex-shrink: 0;
  flex-wrap: nowrap;
}
.tox:not([dir=rtl]) .tox-toolbar__group:not(:last-of-type) {
  border-right: 1px solid #000000;
}
.tox[dir=rtl] .tox-toolbar__group:not(:last-of-type) {
  border-left: 1px solid #000000;
}
.tox .tox-toolbar-input-form {
  display: flex;
  align-items: center;
  background-color: var(--tox-private-background-color, #222f3e);
  padding: 0 var(--tox-private-pad-sm, 8px);
}
.tox .tox-tooltip {
  display: inline-block;
  max-width: min(80%, 15em);
  padding: 8px 0 0 0;
  position: relative;
  width: max-content;
  z-index: 1150;
}
.tox .tox-tooltip.tox-tooltip--anchor {
  display: none;
  padding: var(--tox-private-pad-xs, 4px) 0 0;
  position: fixed;
  position-try-fallbacks: flip-block, flip-inline, flip-block flip-inline;
  height: fit-content;
}
.tox .tox-tooltip.tox-tooltip--anchor.tox-tooltip--up {
  position-area: block-end;
}
.tox .tox-tooltip.tox-tooltip--anchor.tox-tooltip--down {
  position-area: block-start;
}
.tox .tox-tooltip.tox-tooltip--anchor.tox-tooltip--left {
  position-area: inline-start;
}
.tox .tox-tooltip.tox-tooltip--anchor.tox-tooltip--right {
  position-area: inline-end;
}
.tox .tox-tooltip__body {
  background-color: #2A3746;
  border-radius: 3px;
  box-shadow: none;
  color: #fff;
  font-size: 12px;
  font-style: normal;
  font-weight: 600;
  overflow-wrap: break-word;
  padding: 4px 6px;
  text-transform: none;
}
@media (forced-colors: active) {
  .tox .tox-tooltip__body {
    outline: outset 1px;
  }
}
.tox .tox-tooltip__arrow {
  position: absolute;
}
.tox .tox-tooltip--down .tox-tooltip__arrow {
  border-left: 8px solid transparent;
  border-right: 8px solid transparent;
  border-top: 8px solid #2A3746;
  bottom: 0;
  left: 50%;
  position: absolute;
  transform: translateX(-50%);
}
.tox .tox-tooltip--up .tox-tooltip__arrow {
  border-bottom: 8px solid #2A3746;
  border-left: 8px solid transparent;
  border-right: 8px solid transparent;
  left: 50%;
  position: absolute;
  top: 0;
  transform: translateX(-50%);
}
.tox .tox-tooltip--right .tox-tooltip__arrow {
  border-bottom: 8px solid transparent;
  border-left: 8px solid #2A3746;
  border-top: 8px solid transparent;
  position: absolute;
  right: 0;
  top: 50%;
  transform: translateY(-50%);
}
.tox .tox-tooltip--left .tox-tooltip__arrow {
  border-bottom: 8px solid transparent;
  border-right: 8px solid #2A3746;
  border-top: 8px solid transparent;
  left: 0;
  position: absolute;
  top: 50%;
  transform: translateY(-50%);
}
.tox .tox-tree {
  display: flex;
  flex-direction: column;
}
.tox .tox-tree .tox-trbtn {
  align-items: center;
  background: transparent;
  border: 0;
  border-radius: 4px;
  box-shadow: none;
  color: #fff;
  display: flex;
  flex: 0 0 auto;
  font-size: 14px;
  font-style: normal;
  font-weight: normal;
  height: 28px;
  margin-bottom: 4px;
  margin-top: 4px;
  outline: none;
  overflow: hidden;
  padding: 0;
  padding-left: 8px;
  text-transform: none;
}
.tox .tox-tree .tox-trbtn .tox-tree__label {
  cursor: default;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
}
.tox .tox-tree .tox-trbtn svg {
  display: block;
  fill: #fff;
}
.tox .tox-tree .tox-trbtn:focus {
  background: #4a5562;
  border: 0;
  box-shadow: none;
}
.tox .tox-tree .tox-trbtn:hover {
  background: #4a5562;
  border: 0;
  box-shadow: none;
  color: #fff;
}
.tox .tox-tree .tox-trbtn:hover svg {
  fill: #fff;
}
.tox .tox-tree .tox-trbtn:active {
  background: #6ea9d0;
  border: 0;
  box-shadow: none;
  color: #fff;
}
.tox .tox-tree .tox-trbtn:active svg {
  fill: #fff;
}
.tox .tox-tree .tox-trbtn--disabled,
.tox .tox-tree .tox-trbtn--disabled:hover,
.tox .tox-tree .tox-trbtn:disabled,
.tox .tox-tree .tox-trbtn:disabled:hover {
  background: transparent;
  border: 0;
  box-shadow: none;
  color: rgba(255, 255, 255, 0.5);
  cursor: not-allowed;
}
.tox .tox-tree .tox-trbtn--disabled svg,
.tox .tox-tree .tox-trbtn--disabled:hover svg,
.tox .tox-tree .tox-trbtn:disabled svg,
.tox .tox-tree .tox-trbtn:disabled:hover svg {
  fill: rgba(255, 255, 255, 0.5);
}
.tox .tox-tree .tox-trbtn--enabled,
.tox .tox-tree .tox-trbtn--enabled:hover {
  background: #6ea9d0;
  border: 0;
  box-shadow: none;
  color: #fff;
}
.tox .tox-tree .tox-trbtn--enabled > *,
.tox .tox-tree .tox-trbtn--enabled:hover > * {
  transform: none;
}
.tox .tox-tree .tox-trbtn--enabled svg,
.tox .tox-tree .tox-trbtn--enabled:hover svg {
  fill: #fff;
}
.tox .tox-tree .tox-trbtn:focus:not(.tox-trbtn--disabled) {
  color: #fff;
}
.tox .tox-tree .tox-trbtn:focus:not(.tox-trbtn--disabled) svg {
  fill: #fff;
}
.tox .tox-tree .tox-trbtn:active > * {
  transform: none;
}
.tox .tox-tree .tox-trbtn--return {
  align-self: stretch;
  height: unset;
  width: 16px;
}
.tox .tox-tree .tox-trbtn--labeled {
  padding: 0 4px;
  width: unset;
}
.tox .tox-tree .tox-trbtn__vlabel {
  display: block;
  font-size: 10px;
  font-weight: normal;
  letter-spacing: -0.025em;
  margin-bottom: 4px;
  white-space: nowrap;
}
.tox .tox-tree .tox-tree--directory {
  display: flex;
  flex-direction: column;
}
.tox .tox-tree .tox-tree--directory .tox-tree--directory__label {
  font-weight: bold;
}
.tox .tox-tree .tox-tree--directory .tox-tree--directory__label .tox-mbtn {
  margin-left: auto;
}
.tox .tox-tree .tox-tree--directory .tox-tree--directory__label .tox-mbtn svg {
  fill: transparent;
}
.tox .tox-tree .tox-tree--directory .tox-tree--directory__label .tox-mbtn.tox-mbtn--active svg,
.tox .tox-tree .tox-tree--directory .tox-tree--directory__label .tox-mbtn:focus svg {
  fill: #fff;
}
.tox .tox-tree .tox-tree--directory .tox-tree--directory__label:hover .tox-mbtn svg,
.tox .tox-tree .tox-tree--directory .tox-tree--directory__label:focus .tox-mbtn svg {
  fill: #fff;
}
.tox .tox-tree .tox-tree--directory .tox-tree--directory__label:hover:has(.tox-mbtn:hover) {
  background-color: transparent;
  color: #fff;
}
.tox .tox-tree .tox-tree--directory .tox-tree--directory__label:hover:has(.tox-mbtn:hover) .tox-chevron svg {
  fill: #fff;
}
.tox .tox-tree .tox-tree--directory .tox-tree--directory__label .tox-chevron {
  margin-right: 6px;
}
.tox .tox-tree .tox-tree--directory .tox-tree--directory__label:has(+ .tox-tree--directory__children--growing) .tox-chevron,
.tox .tox-tree .tox-tree--directory .tox-tree--directory__label:has(+ .tox-tree--directory__children--shrinking) .tox-chevron {
  transition: transform 0.5s ease-in-out;
}
.tox .tox-tree .tox-tree--directory .tox-tree--directory__label:has(+ .tox-tree--directory__children--growing) .tox-chevron,
.tox .tox-tree .tox-tree--directory .tox-tree--directory__label:has(+ .tox-tree--directory__children--open) .tox-chevron {
  transform: rotate(90deg);
}
.tox .tox-tree .tox-tree--leaf__label {
  font-weight: normal;
}
.tox .tox-tree .tox-tree--leaf__label .tox-mbtn {
  margin-left: auto;
}
.tox .tox-tree .tox-tree--leaf__label .tox-mbtn svg {
  fill: transparent;
}
.tox .tox-tree .tox-tree--leaf__label .tox-mbtn.tox-mbtn--active svg,
.tox .tox-tree .tox-tree--leaf__label .tox-mbtn:focus svg {
  fill: #fff;
}
.tox .tox-tree .tox-tree--leaf__label:hover .tox-mbtn svg {
  fill: #fff;
}
.tox .tox-tree .tox-tree--leaf__label:hover:has(.tox-mbtn:hover) {
  background-color: transparent;
  color: #fff;
}
.tox .tox-tree .tox-tree--leaf__label:hover:has(.tox-mbtn:hover) .tox-chevron svg {
  fill: #fff;
}
.tox .tox-tree .tox-icon-custom-state {
  flex-grow: 1;
  display: flex;
  justify-content: flex-end;
}
.tox .tox-tree .tox-tree--directory__children {
  overflow: hidden;
  padding-left: 16px;
}
.tox .tox-tree .tox-tree--directory__children.tox-tree--directory__children--growing,
.tox .tox-tree .tox-tree--directory__children.tox-tree--directory__children--shrinking {
  transition: height 0.5s ease-in-out;
}
.tox .tox-tree .tox-trbtn.tox-tree--leaf__label {
  display: flex;
  justify-content: space-between;
}
[data-mce-name="uploadcare-enhance-filter"] .color-swatch-remove-color path {
  fill: #c00;
  stroke: #c00;
}
.tox .tox-view-wrap,
.tox .tox-view-wrap__slot-container {
  background-color: #222f3e;
  display: flex;
  flex: 1;
  flex-direction: column;
  height: 100%;
}
.tox .tox-view {
  display: flex;
  flex: 1 1 auto;
  flex-direction: column;
  overflow: hidden;
  background-color: #222f3e;
}
.tox .tox-view__header {
  align-items: center;
  display: flex;
  font-size: 16px;
  justify-content: space-between;
  padding: 8px;
  position: relative;
}
.tox .tox-view__label {
  color: #fff;
  font-weight: bold;
  line-height: 24px;
  padding: 4px 16px;
  text-align: center;
  white-space: nowrap;
}
.tox .tox-view__label--normal {
  font-size: 16px;
}
.tox .tox-view__label--large {
  font-size: 20px;
}
.tox .tox-view--mobile.tox-view__header,
.tox .tox-view--mobile.tox-view__toolbar {
  padding: 8px;
}
.tox .tox-view--scrolling {
  flex-wrap: nowrap;
  overflow-x: auto;
}
.tox .tox-view__align-right {
  margin-left: auto;
}
.tox .tox-view__toolbar {
  display: flex;
  flex-direction: row;
  gap: 8px;
  justify-content: space-between;
  overflow-x: auto;
  padding: 8px;
}
.tox .tox-view__toolbar__group {
  display: flex;
  flex-direction: row;
  gap: 12px;
}
.tox .tox-view__header-start,
.tox .tox-view__header-end {
  display: flex;
}
.tox .tox-view__pane {
  height: 100%;
  padding: 8px;
  position: relative;
  width: 100%;
}
.tox .tox-view__pane_panel {
  border: 1px solid #000000;
  border-radius: 3px;
}
.tox:not([dir=rtl]) .tox-view__header .tox-view__header-start > *,
.tox:not([dir=rtl]) .tox-view__header .tox-view__header-end > * {
  margin-left: 8px;
}
.tox[dir=rtl] .tox-view__header .tox-view__header-start > *,
.tox[dir=rtl] .tox-view__header .tox-view__header-end > * {
  margin-right: 8px;
}
.tox .tox-well {
  border: 1px solid #000000;
  border-radius: 3px;
  padding: 8px;
  width: 100%;
}
.tox .tox-well > *:first-child {
  margin-top: 0;
}
.tox .tox-well > *:last-child {
  margin-bottom: 0;
}
.tox .tox-well > *:only-child {
  margin: 0;
}
.tox .tox-custom-editor {
  border: 1px solid #000000;
  border-radius: 3px;
  display: flex;
  flex: 1;
  overflow: hidden;
  position: relative;
}
.tox .tox-view .tox-revisionhistory__pane {
  padding: 0;
  /* Override the default padding of tox-view__pane */
}
.tox .tox-revisionhistory__container {
  display: flex;
  flex-direction: column;
  height: 100%;
}
.tox .tox-revisionhistory {
  background-color: #222f3e;
  border-top: 1px solid rgba(255, 255, 255, 0.15);
  display: flex;
  flex: 1;
  height: 100%;
  overflow-x: auto;
  overflow-y: hidden;
  position: relative;
  width: 100%;
}
.tox .tox-revisionhistory__iframe {
  flex: 1;
}
.tox .tox-revisionhistory__sidebar {
  display: flex;
  flex-direction: column;
  height: 100%;
  min-width: 248px;
  width: 316px;
}
.tox .tox-revisionhistory__sidebar .tox-revisionhistory__sidebar-title {
  background-color: #222f3e;
  box-shadow: 0 4px 8px 0 rgba(34, 47, 62, 0.1);
  color: #fff;
  font-size: 20px;
  font-weight: 400;
  line-height: 28px;
  padding: 12px;
  z-index: 1;
}
.tox .tox-revisionhistory__sidebar .tox-revisionhistory__revisions {
  background-color: #2b3b4e;
  display: flex;
  flex: 1;
  flex-direction: column;
  gap: 12px;
  overflow-y: auto;
  padding: 10px 12px;
}
.tox .tox-revisionhistory__sidebar .tox-revisionhistory__revisions:focus {
  height: 100%;
  position: relative;
  z-index: 1;
}
.tox .tox-revisionhistory__sidebar .tox-revisionhistory__revisions:focus::after {
  bottom: 0;
  box-shadow: 0 0 0 0 transparent ;
  content: '';
  left: 0;
  position: absolute;
  right: 0;
  top: 0;
  border-radius: 3px;
  bottom: 1px;
  left: 1px;
  right: 1px;
  top: 1px;
}
@media (forced-colors: active) {
  .tox .tox-revisionhistory__sidebar .tox-revisionhistory__revisions:focus::after {
    border: 2px solid highlight;
  }
}
.tox .tox-revisionhistory__sidebar .tox-revisionhistory__revisions .tox-revisionhistory__card {
  background-color: #222f3e;
  border: 1px solid rgba(255, 255, 255, 0.15);
  border-radius: 6px;
  color: #fff;
  cursor: pointer;
  display: flex;
  flex-direction: column;
  font-size: 14px;
  padding: 12px;
  width: 100%;
}
.tox .tox-revisionhistory__sidebar .tox-revisionhistory__revisions .tox-revisionhistory__card:hover {
  box-shadow: 0 4px 8px 0 rgba(34, 47, 62, 0.1);
}
.tox .tox-revisionhistory__sidebar .tox-revisionhistory__revisions .tox-revisionhistory__card:focus {
  position: relative;
  z-index: 1;
}
.tox .tox-revisionhistory__sidebar .tox-revisionhistory__revisions .tox-revisionhistory__card:focus::after {
  border-radius: 3px;
  bottom: 0;
  box-shadow: 0 0 0 0 transparent #285ec7;
  content: '';
  left: 0;
  position: absolute;
  right: 0;
  top: 0;
  border-radius: 6px;
  box-shadow: 0 0 0 2px #285ec7;
  box-shadow: 0 0 0 2px #285ec7 !important;
}
@media (forced-colors: active) {
  .tox .tox-revisionhistory__sidebar .tox-revisionhistory__revisions .tox-revisionhistory__card:focus::after {
    border: 2px solid highlight;
  }
}
.tox .tox-revisionhistory__sidebar .tox-revisionhistory__revisions .tox-revisionhistory__card.tox-revisionhistory__card--selected {
  background-color: #1b3b60;
  box-shadow: 0 4px 8px 0 rgba(34, 47, 62, 0.1);
  position: relative;
}
.tox .tox-revisionhistory__sidebar .tox-revisionhistory__revisions .tox-revisionhistory__card.tox-revisionhistory__card--selected::after {
  border-radius: 3px;
  bottom: 0;
  box-shadow: 0 0 0 0 transparent #cea215;
  content: '';
  left: 0;
  position: absolute;
  right: 0;
  top: 0;
  border-radius: 6px;
  box-shadow: 0 0 0 2px #cea215;
}
@media (forced-colors: active) {
  .tox .tox-revisionhistory__sidebar .tox-revisionhistory__revisions .tox-revisionhistory__card.tox-revisionhistory__card--selected::after {
    border: 2px solid highlight;
  }
}
.tox .tox-revisionhistory__sidebar .tox-revisionhistory__revisions .tox-revisionhistory__card-label {
  display: block;
  width: min-content;
  padding: 4px 8px;
  margin-bottom: 8px;
  font-size: 12px;
  font-weight: bold;
  border-radius: 4px;
  background: #555f6b;
}
.tox .tox-revisionhistory__sidebar .tox-revisionhistory__revisions .tox-revisionhistory__card-content {
  display: flex;
  flex-direction: row;
  gap: 8px;
  align-items: center;
}
.tox .tox-revisionhistory__sidebar .tox-revisionhistory__revisions .tox-revisionhistory__card-info {
  display: flex;
  flex-direction: column;
  flex: 1;
}
.tox .tox-revisionhistory__sidebar .tox-revisionhistory__revisions .tox-revisionhistory__card-date-label {
  font-size: 14px;
  font-weight: bold;
  line-height: 18px;
}
.tox .tox-revisionhistory__sidebar .tox-revisionhistory__revisions .tox-revisionhistory__card-author-name {
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  font-size: 12px;
  font-weight: normal;
}
.tox .tox-revisionhistory__sidebar .tox-revisionhistory__revisions .tox-revisionhistory__avatar {
  border-radius: 50%;
  height: 36px;
  object-fit: cover;
  vertical-align: middle;
  width: 36px;
}
.tox .tox-revisionhistory__sidebar .tox-revisionhistory__revisions .tox-revisionhistory__norevision {
  color: rgba(255, 255, 255, 0.5);
  font-size: 16px;
  line-height: 24px;
  padding: 5px 5.5px;
}
.tox .tox-revisionhistory__sidebar .tox-revisionhistory__revisions .tox-revisionhistory__card-check-icon {
  color: #fff;
  height: 24px;
}
.tox .tox-card {
  background-color: #222f3e;
  border-radius: 3px;
  display: flex;
  flex-direction: column;
  gap: 12px;
  cursor: pointer;
  transition: box-shadow 0.15s ease-in-out, border 0.15s ease-in-out;
  border: 0 solid transparent;
}
.tox .tox-card:hover {
  box-shadow: 0 4px 8px 0 rgba(42, 55, 70, 0.1);
}
.tox .tox-card--selected {
  border-color: #207ab7;
}
.tox .tox-card:focus-visible {
  outline: none;
  box-shadow: 0 0 0 0 transparent;
  border-color: transparent;
}
.tox .tox-card--has-decision {
  background-color: #17202a;
}
.tox .tox-card--has-decision:not(.tox-card--selected) {
  border-width: 1px;
  border-color: rgba(255, 255, 255, 0.5);
}
.tox .tox-card--has-decision .tox-card__header {
  font-size: 12px;
}
.tox .tox-card--has-decision .tox-card__body {
  color: rgba(255, 255, 255, 0.5);
}
.tox .tox-card--has-decision .tox-card__actions .tox-button--secondary--outline {
  border-color: #0c1116;
}
.tox .tox-card--has-decision .tox-card__actions .tox-button--secondary--outline:hover:not(:disabled),
.tox .tox-card--has-decision .tox-card__actions .tox-button--secondary--outline:focus:not(:disabled) {
  background-color: #0c1116;
  border-color: #010203;
}
.tox .tox-card--has-decision .tox-card__actions .tox-button--secondary--outline:active:not(:disabled) {
  background-color: #010203;
  border-color: #010203;
}
.tox .tox-card__header {
  padding: 12px;
  padding-bottom: 0;
  color: #fff;
  font-size: 16px;
  font-weight: bold;
  text-transform: uppercase;
  display: flex;
  flex-direction: column;
  gap: 12px;
}
.tox .tox-card__header-label {
  font-size: 12px;
  font-weight: bold;
  text-transform: uppercase;
  color: #fff;
}
.tox .tox-card__body {
  padding: 12px 12px 0 12px;
  color: #fff;
  font-size: 16px;
}
.tox .tox-card__body .tox-expandable-box {
  border: none;
  padding: 0;
  gap: 12px;
}
.tox .tox-card--has-decision .tox .tox-card__body {
  padding: 0 12px 0 12px;
}
.tox .tox-card__highlight {
  padding: 4px 6px;
  border-bottom: 0 solid #207ab7;
}
.tox .tox-card__highlight--added {
  background-color: #334840;
}
.tox .tox-card__highlight--deleted {
  background-color: #442632;
}
.tox .tox-card__highlight--modified {
  background-color: #223e56;
}
.tox .tox-card__actions {
  display: flex;
  gap: 8px;
  padding: 0 12px 12px;
}
.tox .tox-card__actions--space-between {
  justify-content: space-between;
}
.tox .tox-card__actions--flex-start {
  justify-content: flex-start;
}
.tox .tox-card__actions .tox-button,
.tox .tox-card__actions .tox-button--icon,
.tox .tox-card__actions .tox-button:has(.tox-icon:only-child) {
  padding: 4px 16px;
}
.tox .tox-card.tox-skeleton {
  cursor: default;
  pointer-events: none;
  box-shadow: none;
}
.tox .tox-card.tox-skeleton:hover {
  box-shadow: none;
}
.tox .tox-card.tox-skeleton .tox-skeleton__line {
  border-radius: 3px;
  margin: 0;
}
.tox .tox-card.tox-skeleton .tox-card__body {
  display: flex;
  flex-direction: column;
  gap: 4px;
}
.tox .tox-card-list {
  display: flex;
  flex-direction: column;
  gap: 12px;
}
.tox .tox-card-list:focus {
  outline: none;
}
.tox [data-mce-name="suggestededits"] .tox-icon .tox-icon--badge {
  fill: #207ab7;
}
.tox .tox-view .tox-suggestededits__pane {
  padding: 0;
  /* Override the default padding of tox-view__pane */
}
.tox .tox-suggestededits__sink {
  position: relative;
  z-index: 1000;
}
.tox .tox-suggestededits__sink .tox-tiered-menu .tox-collection--list {
  position: absolute;
}
.tox .tox-suggestededits__container {
  height: 100%;
  /* TINY-12393: Improve height calculation */
  display: flex;
  flex-direction: column;
}
.tox .tox-suggestededits__container .tox-suggestededits {
  background-color: #222f3e;
  border-top: 1px solid #000000;
  display: flex;
  flex: 1;
  height: inherit;
  overflow-x: auto;
  overflow-y: hidden;
  position: relative;
}
.tox .tox-suggestededits__container .tox-suggestededits .tox-suggestededits__content {
  flex: 1;
}
.tox .tox-suggestededits__container .tox-suggestededits .tox-suggestededits__model {
  height: 100%;
  position: relative;
}
.tox .tox-suggestededits__container .tox-suggestededits .tox-suggestededits__model .tox-suggestededits__iframe {
  height: 100%;
  width: 100%;
  overflow: scroll;
  background-color: #fff;
}
.tox .tox-suggestededits__container .tox-suggestededits .tox-suggestededits__sidebar {
  background-color: #34485f;
  display: flex;
  flex-direction: column;
  flex: 0 1 auto;
  min-width: 248px;
  width: 316px;
}
.tox .tox-suggestededits__container .tox-suggestededits .tox-suggestededits__sidebar-header {
  padding: 4px 12px;
}
.tox .tox-suggestededits__container .tox-suggestededits .tox-suggestededits__sidebar-content {
  display: flex;
  flex: 1;
  flex-direction: column;
  gap: 12px;
  overflow: auto;
  padding: 6px 12px 12px 12px;
  position: relative;
}
.tox .tox-suggestededits__container .tox-suggestededits .tox-suggestededits__sidebar-content .tox-suggestededits__card {
  background-color: #222f3e;
  border-radius: 6px;
  padding: 6px;
}
.tox .tox-suggestededits__container .tox-suggestededits .tox-suggestededits__sidebar-content .tox-suggestededits__card .tox-suggestededits__card--divider {
  background-color: #34485f;
  height: 1px;
  width: 100%;
}
.tox .tox-suggestededits__container .tox-suggestededits .tox-suggestededits__sidebar-content .tox-suggestededits__card .tox-suggestededits__card--single,
.tox .tox-suggestededits__container .tox-suggestededits .tox-suggestededits__sidebar-content .tox-suggestededits__card .tox-suggestededits__card--editor {
  align-items: flex-start;
  align-self: stretch;
  display: flex;
  flex-direction: column;
  gap: 6px;
  padding: 6px;
}
.tox .tox-suggestededits__container .tox-suggestededits .tox-suggestededits__sidebar-content .tox-suggestededits__card .tox-suggestededits__card--header {
  display: flex;
  flex: auto;
  justify-content: space-between;
  align-items: center;
  gap: 8px;
  width: 100%;
}
.tox .tox-suggestededits__container .tox-suggestededits .tox-suggestededits__sidebar-content .tox-suggestededits__card .tox-suggestededits__card--header .tox-suggestededits__card--user {
  display: flex;
  align-items: center;
  flex: 1 0 0;
  gap: 8px;
}
.tox .tox-suggestededits__container .tox-suggestededits .tox-suggestededits__sidebar-content .tox-suggestededits__card .tox-suggestededits__card--header .tox-suggestededits__card--user .tox-suggestededits__card--avatar {
  height: 24px;
  width: 24px;
}
.tox .tox-suggestededits__container .tox-suggestededits .tox-suggestededits__sidebar-content .tox-suggestededits__card .tox-suggestededits__card--header .tox-suggestededits__card--user .tox-suggestededits__card--avatar .tox-skeleton__circle,
.tox .tox-suggestededits__container .tox-suggestededits .tox-suggestededits__sidebar-content .tox-suggestededits__card .tox-suggestededits__card--header .tox-suggestededits__card--user .tox-suggestededits__card--avatar img {
  height: 24px;
  width: 24px;
}
.tox .tox-suggestededits__container .tox-suggestededits .tox-suggestededits__sidebar-content .tox-suggestededits__card .tox-suggestededits__card--header .tox-suggestededits__card--user .tox-suggestededits__card--details {
  display: flex;
  flex-direction: column;
  justify-content: center;
  align-items: flex-start;
}
.tox .tox-suggestededits__container .tox-suggestededits .tox-suggestededits__sidebar-content .tox-suggestededits__card .tox-suggestededits__card--header .tox-suggestededits__card--user .tox-suggestededits__card--details .tox-suggestededits__card--name {
  color: #fff;
}
.tox .tox-suggestededits__container .tox-suggestededits .tox-suggestededits__sidebar-content .tox-suggestededits__card .tox-suggestededits__card--header .tox-suggestededits__card--feedback-user {
  display: flex;
  align-items: center;
  flex: 1 0 0;
  gap: 8px;
}
.tox .tox-suggestededits__container .tox-suggestededits .tox-suggestededits__sidebar-content .tox-suggestededits__card .tox-suggestededits__card--header .tox-suggestededits__card--feedback-user .tox-suggestededits__card--avatar {
  height: 36px;
  width: 36px;
}
.tox .tox-suggestededits__container .tox-suggestededits .tox-suggestededits__sidebar-content .tox-suggestededits__card .tox-suggestededits__card--header .tox-suggestededits__card--feedback-user .tox-suggestededits__card--details {
  display: flex;
  flex-direction: column;
  justify-content: center;
  align-items: flex-start;
}
.tox .tox-suggestededits__container .tox-suggestededits .tox-suggestededits__sidebar-content .tox-suggestededits__card .tox-suggestededits__card--header .tox-suggestededits__card--feedback-user .tox-suggestededits__card--details .tox-suggestededits__card--name {
  color: #fff;
  font-size: 14px;
  font-weight: bold;
}
.tox .tox-suggestededits__container .tox-suggestededits .tox-suggestededits__sidebar-content .tox-suggestededits__card .tox-suggestededits__card--header .tox-suggestededits__card--feedback-user .tox-suggestededits__card--details .tox-suggestededits__card--timestamp {
  color: #fff;
  font-size: 12px;
  line-height: 18px;
}
.tox .tox-suggestededits__container .tox-suggestededits .tox-suggestededits__sidebar-content .tox-suggestededits__card .tox-suggestededits__card--header .tox-suggestededits__resolution {
  align-items: center;
  border: 0;
  border-radius: 20px;
  height: 20px;
  width: 20px;
  display: flex;
  flex: 0 0 auto;
  justify-content: center;
  text-align: center;
}
.tox .tox-suggestededits__container .tox-suggestededits .tox-suggestededits__sidebar-content .tox-suggestededits__card .tox-suggestededits__card--header .tox-suggestededits__resolution.tox-suggestededits__resolution--accepted .tox-icon svg {
  fill: #78AB46;
}
.tox .tox-suggestededits__container .tox-suggestededits .tox-suggestededits__sidebar-content .tox-suggestededits__card .tox-suggestededits__card--header .tox-suggestededits__resolution.tox-suggestededits__resolution--rejected .tox-icon svg {
  fill: #c00;
}
.tox .tox-suggestededits__container .tox-suggestededits .tox-suggestededits__sidebar-content .tox-suggestededits__card .tox-suggestededits__card--content {
  display: flex;
  flex-direction: column;
  align-self: stretch;
  flex: auto;
  gap: 6px;
  width: 100%;
}
.tox .tox-suggestededits__container .tox-suggestededits .tox-suggestededits__sidebar-content .tox-suggestededits__card .tox-suggestededits__card--content .tox-suggestededits__operations {
  display: flex;
  gap: 8px;
}
.tox .tox-suggestededits__container .tox-suggestededits .tox-suggestededits__sidebar-content .tox-suggestededits__card .tox-suggestededits__card--content .tox-suggestededits__operations .tox-suggestededits__operations-bar {
  align-items: center;
  border-radius: 6px;
  display: flex;
  flex-direction: column;
  font-size: 12px;
  justify-content: space-between;
  width: 6px;
}
.tox .tox-suggestededits__container .tox-suggestededits .tox-suggestededits__sidebar-content .tox-suggestededits__card .tox-suggestededits__card--content .tox-suggestededits__operations .tox-suggestededits__operations-bar--insert {
  background-color: #78AB46;
  width: 100%;
}
.tox .tox-suggestededits__container .tox-suggestededits .tox-suggestededits__sidebar-content .tox-suggestededits__card .tox-suggestededits__card--content .tox-suggestededits__operations .tox-suggestededits__operations-bar--modify {
  background-color: #207ab7;
  width: 100%;
}
.tox .tox-suggestededits__container .tox-suggestededits .tox-suggestededits__sidebar-content .tox-suggestededits__card .tox-suggestededits__card--content .tox-suggestededits__operations .tox-suggestededits__operations-bar--remove {
  background-color: #c00;
  width: 100%;
}
.tox .tox-suggestededits__container .tox-suggestededits .tox-suggestededits__sidebar-content .tox-suggestededits__card .tox-suggestededits__card--content .tox-suggestededits__operations .tox-suggestededits__operations-text {
  color: #fff;
  font-weight: bold;
}
.tox .tox-suggestededits__container .tox-suggestededits .tox-suggestededits__sidebar-content .tox-suggestededits__card .tox-suggestededits__card--content .tox-suggestededits__card--feedback {
  color: #fff;
  width: 100%;
}
.tox .tox-suggestededits__container .tox-suggestededits .tox-suggestededits__sidebar-content .tox-suggestededits__card .tox-suggestededits__card--content .tox-suggestededits__card--textarea {
  border: 2px solid #000000;
  border-radius: 6px;
  color: #fff;
  gap: 8px;
  padding: 5px 6px;
  resize: none;
  width: 100%;
}
.tox .tox-suggestededits__container .tox-suggestededits .tox-suggestededits__sidebar-content .tox-suggestededits__card .tox-suggestededits__card--content .tox-suggestededits__card--textarea:focus {
  border: 2px solid #207ab7;
}
.tox .tox-suggestededits__container .tox-suggestededits .tox-suggestededits__sidebar-content .tox-suggestededits__card .tox-suggestededits__card--footer {
  display: flex;
  flex-direction: column;
  gap: 6px;
  width: 100%;
}
.tox .tox-suggestededits__container .tox-suggestededits .tox-suggestededits__sidebar-content .tox-suggestededits__card .tox-suggestededits__card--footer .tox-suggestededits__card--timestamp {
  color: #fff;
  font-size: 12px;
  line-height: 18px;
}
.tox .tox-suggestededits__container .tox-suggestededits .tox-suggestededits__sidebar-content .tox-suggestededits__card .tox-suggestededits__card--footer .tox-suggestededits__card--timestamp .tox-icon svg {
  fill: #FFFFFF80;
  transform: translate(0px, 8px);
  margin-top: -10px;
}
.tox .tox-suggestededits__container .tox-suggestededits .tox-suggestededits__sidebar-content .tox-suggestededits__card .tox-suggestededits__card--buttons {
  display: flex;
  align-items: center;
  gap: 8px;
  width: 100%;
}
.tox .tox-suggestededits__container .tox-suggestededits .tox-suggestededits__sidebar-content .tox-suggestededits__card .tox-suggestededits__card--buttons.tox-suggestededits__card--review-buttons {
  justify-content: space-between;
  padding: 6px;
}
.tox .tox-suggestededits__container .tox-suggestededits .tox-suggestededits__sidebar-content .tox-suggestededits__card .tox-suggestededits__card--buttons.tox-suggestededits__card--feedback-buttons {
  justify-content: flex-end;
}
.tox .tox-suggestededits__container .tox-suggestededits .tox-suggestededits__sidebar-content .tox-suggestededits__card.tox-suggestededits__card--hidden {
  opacity: 0.5;
}
.tox .tox-suggestededits__container .tox-suggestededits .tox-suggestededits__sidebar-content .tox-suggestededits__card.tox-suggestededits__card--resolved {
  background-color: #243140;
}
.tox .tox-suggestededits__container .tox-suggestededits .tox-suggestededits__sidebar-content .tox-suggestededits__card.tox-suggestededits__card--active:focus,
.tox .tox-suggestededits__container .tox-suggestededits .tox-suggestededits__sidebar-content .tox-suggestededits__card.tox-suggestededits__card--active:focus-visible {
  outline: 2px solid #207ab7;
}
.tox .tox-suggestededits__container .tox-suggestededits .tox-suggestededits__sidebar-content .tox-suggestededits__card.tox-suggestededits__card--active .tox-suggestededits__card--single {
  border-radius: 6px;
}
.tox .tox-suggestededits__container .tox-suggestededits .tox-suggestededits__sidebar-content .tox-suggestededits__card.tox-suggestededits__card--active .tox-suggestededits__card--single:focus,
.tox .tox-suggestededits__container .tox-suggestededits .tox-suggestededits__sidebar-content .tox-suggestededits__card.tox-suggestededits__card--active .tox-suggestededits__card--single:focus-visible {
  outline: 2px solid #207ab7;
}
.tox .tox-suggestededits__container .tox-suggestededits .tox-suggestededits__sidebar-content .tox-suggestededits__card:hover {
  box-shadow: 0 4px 8px 0 #243140;
}
/* stylelint-disable */
.tox {
  /* stylelint-enable */
}
.tox .tox-dialog-loading::before {
  background-color: rgba(0, 0, 0, 0.5);
  content: "";
  height: 100%;
  position: absolute;
  width: 100%;
  z-index: 1000;
}
.tox .tox-tab {
  cursor: pointer;
}
.tox .tox-dialog__content-js {
  display: flex;
  flex: 1;
}
.tox .tox-dialog__body-content .tox-collection {
  display: flex;
  flex: 1;
}
.tox:not(.tox-tinymce-inline) .tox-editor-header {
  background-color: none;
  padding: 0;
}
.tox.tox-tinymce--toolbar-bottom .tox-editor-header,
.tox.tox-tinymce-inline .tox-editor-header {
  margin-bottom: -1px;
}
.tox.tox-tinymce-inline .tox-editor-container {
  overflow: hidden;
}
.tox:not(.tox-tinymce-inline).tox-tinymce--toolbar-bottom .tox-editor-header {
  border-top: none;
  box-shadow: none;
}
.tox.tox.tox-tinymce--toolbar-sticky-on .tox-editor-header {
  background-color: transparent;
  box-shadow: 0 4px 4px -3px rgba(0, 0, 0, 0.25);
  padding: 0;
}
.tox.tox.tox-tinymce--toolbar-sticky-on.tox-tinymce--toolbar-bottom .tox-editor-header {
  box-shadow: 0 4px 4px -3px rgba(0, 0, 0, 0.25);
}
.tox .tox-collection--list .tox-collection__group .tox-insert-table-picker {
  margin: -4px 0;
}
.tox .tox-menu.tox-collection.tox-collection--list {
  padding: 0;
}
.tox .tox-pop {
  box-shadow: none;
}
.tox .tox-tbtn,
.tox .tox-label,
.tox .tox-number-input,
.tox .tox-tbtn--select,
.tox .tox-split-button,
.tox .tox-toolbar-label {
  margin: 2px 0 3px 0;
}
.tox .tox-tbtn--bordered,
.tox .tox-tbtn--bordered:focus,
.tox .tox-tbtn--bordered:hover {
  border: 1px solid #000000;
}
.tox .tox-toolbar,
.tox .tox-toolbar__primary,
.tox .tox-toolbar__overflow {
  background: url("data:image/svg+xml;charset=utf8,%3Csvg height='39px' viewBox='0 0 40 39px' width='40' xmlns='http://www.w3.org/2000/svg'%3E%3Crect x='0' y='38px' width='100' height='1' fill='%23000000'/%3E%3C/svg%3E") left 0 top 0 #222f3e !important;
}
.tox .tox-menubar + .tox-toolbar-overlord {
  border-top: none;
}
.tox .tox-menubar + .tox-toolbar,
.tox .tox-menubar + .tox-toolbar-overlord .tox-toolbar__primary {
  border-top: 1px solid #000000;
  margin-top: -1px;
}
.tox.tox-tinymce-aux .tox-toolbar__overflow {
  border: 1px solid #000000;
  padding: 0;
}
.tox .tox-pop .tox-pop__dialog .tox-toolbar {
  padding: 0;
}
.tox:not(.tox-tinymce-inline) .tox-editor-header:not(:first-child) .tox-menubar {
  border-top: 1px solid #000000;
}
.tox:not(.tox-tinymce-inline) .tox-editor-header:not(:first-child) .tox-toolbar-overlord:first-child .tox-toolbar__primary,
.tox:not(.tox-tinymce-inline) .tox-editor-header:not(:first-child) .tox-toolbar:first-child {
  border-top: 1px solid #000000;
}
.tox .tox-toolbar__group {
  padding: 0 4px 0 4px;
}
.tox .tox-collection__item {
  border-radius: 0;
  cursor: pointer;
}
.tox .tox-statusbar a:hover:not(:disabled):not([aria-disabled=true]),
.tox .tox-statusbar__path-item:hover:not(:disabled):not([aria-disabled=true]),
.tox .tox-statusbar__wordcount:hover:not(:disabled):not([aria-disabled=true]),
.tox .tox-statusbar a:focus:not(:disabled):not([aria-disabled=true]),
.tox .tox-statusbar__path-item:focus:not(:disabled):not([aria-disabled=true]),
.tox .tox-statusbar__wordcount:focus:not(:disabled):not([aria-disabled=true]) {
  color: #fff;
}
.tox .tox-statusbar__branding svg {
  fill: rgba(255, 255, 255, 0.8);
  height: 1em;
  margin-left: 0.3em;
  width: auto;
}
@media (forced-colors: active) {
  .tox .tox-statusbar__branding svg {
    fill: currentColor;
  }
}
.tox .tox-statusbar__branding a {
  align-items: center;
  display: inline-flex;
}
.tox .tox-statusbar__branding a:hover:not(:disabled):not([aria-disabled=true]) svg,
.tox .tox-statusbar__branding a:focus:not(:disabled):not([aria-disabled=true]) svg {
  fill: #fff;
}
.tox:not([dir=rtl]) .tox-statusbar__branding {
  margin-left: 1ch;
}
.tox[dir=rtl] .tox-statusbar__branding svg {
  margin-left: 0;
  margin-right: 0.3em;
}
.tox .tox-statusbar__resize-handle {
  padding-bottom: 0;
  padding-right: 0;
}
.tox .tox-button::before {
  display: none;
}
